% Generated by ADiMat 0.6.0-4975
% Copyright 2009-2013 Johannes Willkomm, Fachgebiet Scientific Computing,
% TU Darmstadt, 64289 Darmstadt, Germany
% Copyright 2001-2008 Andre Vehreschild, Institute for Scientific Computing,
% RWTH Aachen University, 52056 Aachen, Germany.
% Visit us on the web at http://www.adimat.de
% Report bugs to adimat-users@lists.sc.informatik.tu-darmstadt.de
%
%
%                             DISCLAIMER
%
% ADiMat was prepared as part of an employment at the Institute
% for Scientific Computing, RWTH Aachen University, Germany and is
% provided AS IS. NEITHER THE AUTHOR(S), THE GOVERNMENT OF THE FEDERAL
% REPUBLIC OF GERMANY NOR ANY AGENCY THEREOF, NOR THE RWTH AACHEN UNIVERSITY,
% INCLUDING ANY OF THEIR EMPLOYEES OR OFFICERS, MAKES ANY WARRANTY,
% EXPRESS OR IMPLIED, OR ASSUMES ANY LEGAL LIABILITY OR RESPONSIBILITY
% FOR THE ACCURACY, COMPLETENESS, OR USEFULNESS OF ANY INFORMATION OR
% PROCESS DISCLOSED, OR REPRESENTS THAT ITS USE WOULD NOT INFRINGE
% PRIVATELY OWNED RIGHTS.
%
% Global flags were:
% FORWARDMODE -- Apply the forward mode to the files.
% NOOPEROPTIM -- Do not use optimized operators. I.e.:
%		 g_a*b*g_c -/-> mtimes3(g_a, b, g_c)
% NOLOCALCSE  -- Do not use local common subexpression elimination when
%		 canonicalizing the code.
% NOGLOBALCSE -- Prevents the application of global common subexpression
%		 elimination after canonicalizing the code.
% NOPRESCALARFOLDING -- Switch off folding of scalar constants before
%		 augmentation.
% NOPOSTSCALARFOLDING -- Switch off folding of scalar constants after
%		 augmentation.
% NOCONSTFOLDMULT0 -- Switch off folding of product with one factor
%		 being zero: b*0=0.
% FUNCMODE    -- Inputfile is a function (This flag can not be set explicitly).
% NOTMPCLEAR  -- Suppress generation of clear g_* instructions.
% UNBOUND_XML  -- Write list of unbound identifiers in XML format.
% DEPENDENCIES_XML  -- Write list of functions in XML format.
% UNBOUND_ERROR	-- Stop with error if unbound identifiers found (default).
% FUNCTION_LIST_XML	-- Write list of functions to XML file.
% VERBOSITYLEVEL=5
% AD_IVARS= x
% AD_DVARS= fgrad

function [g_fgrad, fgrad]= g_MinpackGL2_G(g_x, x, Prob)
   % MinpackGL2_G: Computes gradient for the 2D Ginzburg Landau (GL2) problem
   %                  from the MINPACK-2 collection.
   % USE:
   %           fgrad = MinpackGL2_G(x,Prob)
   % where
   % x    : vector of length Prob.user.n
   % Prob : structure created by MinpackGL2_Prob with components
   %    Prob.user.nx=nx;         % no. of gridpoints in x-direction
   %    Prob.user.ny=ny;         % no. of gridpoints in y-direction
   %    Prob.user.vornum=vornum; % no. of vortices
   %    Prob.user.tkappa=tkappa; % Ginzburg-Landau constant
   %    Prob.user.hx=hx;         % mesh spacing in x-direction
   %    Prob.user.hy=hy;         % mesh spacing in x-direction
   %    Prob.user.sqn=sqn;       % sqn=nx*ny
   %
   % OUTPUT:
   % fgrad: gradient of objective function
   %
   % See also MinpackGL2_Prob, MinpackGL2_FG, MinpackGL2_F , MinpackGL2_Hv, , MinpackGL2_Sp
   
   % AUTHOR: S.A.Forth & K. Lenton
   % DATE: 7/01/09
   % Copyright 2009-2009: S.A. Forth, Cranfield University 
   % REVISIONS:
   % DATE  WHO   WHAT
   
   % Original Fortran Header comments follow
   %
   %      subroutine dgl2fg(nx,ny,x,f,fgrad,task,w,vornum)
   %      character*(*) task
   %      integer nx, ny, vornum
   %      double precision f
   %      double precision x(4*nx*ny), fgrad(4*nx*ny), w(4*(nx+1)*(ny+1))
   % **********
   %
   % Subroutine dgl2fg
   %
   % This subroutine computes the function and gradient of the
   % Ginzburg-Landau (2-dimensional) superconductivity problem.
   %
   % The subroutine statement is
   %
   %   subroutine dgl2fg(nx,ny,x,f,fgrad,task,w,vornum)
   %
   % where
   %
   %   nx is an integer variable.
   %     On entry nx is the number of grid points in the first
   %        coordinate direction.
   %     On exit nx is unchanged.
   %
   %   ny is an integer variable.
   %     On entry ny is the number of grid points in the second
   %        coordinate direction.
   %     On exit ny is unchanged.
   %
   %   x is a double precision array of dimension 4*nx*ny.
   %     On entry x specifies the vector x if task = 'F', 'G', or 'FG'.
   %        Otherwise x need not be specified.
   %     On exit x is unchanged if task = 'F', 'G', or 'FG'. Otherwise
   %        x is set according to task.
   %
   %   f is a double precision variable.
   %     On entry f need not be specified.
   %     On exit f is set to the function evaluated at x if task = 'F'
   %        or 'FG'.
   %
   %   fgrad is a double precision array of dimension 4*nx*ny.
   %     On entry fgrad need not be specified.
   %     On exit fgrad contains the gradient evaluated at x if
   %        task = 'G' or 'FG'.
   %
   %   task is a character variable.
   %     On entry task specifies the action of the subroutine:
   %
   %        task               action
   %        ----               ------
   %         'F'     Evaluate the function at x.
   %         'G'     Evaluate the gradient at x.
   %         'FG'    Evaluate the function and the gradient at x.
   %         'XS'    Set x to the standard starting point xs.
   %
   %     On exit task is unchanged.
   %
   %   w is a double precision work array of dimension 4*(nx+1)(ny+1).
   %
   %   vornum is an integer variable.
   %     On entry vornum specifies the number of vortices.
   %     On exit vornum is unchanged.
   %
   % MINPACK-2 Project. November 1993.
   % Argonne National Laboratory and University of Minnesota.
   % Brett M. Averick, Paul L. Plassmann, and Stephen J. Wright.
   %
   % **********
   
   % if nargin<2
   %     error('MINPack:GL2:MinpackGL2_FG:nargin',...
   %         'Arguments x and Prob must be supplied')
   % end
   
   %n=length(x);
   nx= Prob.user.nx; 
   ny= Prob.user.ny; 
   
   % check arguments
   % if (n ~= 4*nx*ny)
   %     error('MINPack:GL2:MinpackGL2_FG:n',...
   %         'MINPack:GL2:MinpackGL2_FG:length(x): x not of length 4*nx*ny')
   % end
   
   % extract parameters from Prob structure
   vornum= Prob.user.vornum; 
   tkappa= Prob.user.tkappa; 
   hx= Prob.user.hx; 
   hy= Prob.user.hy; 
   sqn= Prob.user.sqn; 
   
   % w=reshape(x,nx,ny,4);
   % w(nx+1,ny+1,4)=0;
   % x=w(:,:,1);
   % y=w(:,:,2);
   % vpotx=w(:,:,3);
   % vpoty=w(:,:,4);
   g_tmp_x_00000= g_x(1);
   tmp_x_00000= x(1);
   g_dummy= g_tmp_x_00000;
   dummy= tmp_x_00000; 
   tmp_MinpackGL2_G_00000= nx* ny;
   g_Z= call(@reshape, g_x, tmp_MinpackGL2_G_00000, 4);
   Z= reshape(x, tmp_MinpackGL2_G_00000, 4); 
   znx= zeros(nx, 1); znyp1= zeros(1, ny+ 1); 
   g_tmp_Z_00000= g_Z(: , 1);
   tmp_Z_00000= Z(: , 1);
   g_tmp_reshape_00000= call(@reshape, g_tmp_Z_00000, nx, ny);
   tmp_reshape_00000= reshape(tmp_Z_00000, nx, ny);
   g_x= [g_tmp_reshape_00000, g_zeros(size(znx));
      g_zeros(size(znyp1))];
   x= [tmp_reshape_00000, znx;
      znyp1]; 
   g_tmp_Z_00001= g_Z(: , 2);
   tmp_Z_00001= Z(: , 2);
   g_tmp_reshape_00001= call(@reshape, g_tmp_Z_00001, nx, ny);
   tmp_reshape_00001= reshape(tmp_Z_00001, nx, ny);
   g_y= [g_tmp_reshape_00001, g_zeros(size(znx));
      g_zeros(size(znyp1))];
   y= [tmp_reshape_00001, znx;
      znyp1]; 
   g_tmp_Z_00002= g_Z(: , 3);
   tmp_Z_00002= Z(: , 3);
   g_tmp_reshape_00002= call(@reshape, g_tmp_Z_00002, nx, ny);
   tmp_reshape_00002= reshape(tmp_Z_00002, nx, ny);
   g_vpotx= [g_tmp_reshape_00002, g_zeros(size(znx));
      g_zeros(size(znyp1))];
   vpotx= [tmp_reshape_00002, znx;
      znyp1]; 
   g_tmp_Z_00003= g_Z(: , 4);
   tmp_Z_00003= Z(: , 4);
   g_tmp_reshape_00003= call(@reshape, g_tmp_Z_00003, nx, ny);
   tmp_reshape_00003= reshape(tmp_Z_00003, nx, ny);
   g_vpoty= [g_tmp_reshape_00003, g_zeros(size(znx));
      g_zeros(size(znyp1))];
   vpoty= [tmp_reshape_00003, znx;
      znyp1]; 
   
   arg= 2* pi* vornum* (0: ny)/ ny; 
   tmp_MinpackGL2_G_00001= ny+ 1;
   tmp_MinpackGL2_G_00002= 1: tmp_MinpackGL2_G_00001;
   g_tmp_x_00001= g_x(1, tmp_MinpackGL2_G_00002);
   tmp_x_00001= x(1, tmp_MinpackGL2_G_00002);
   g_tmp_MinpackGL2_G_00003= g_tmp_x_00001.* cos(arg);
   tmp_MinpackGL2_G_00003= tmp_x_00001.* cos(arg);
   tmp_MinpackGL2_G_00004= ny+ 1;
   tmp_MinpackGL2_G_00005= 1: tmp_MinpackGL2_G_00004;
   g_tmp_y_00000= g_y(1, tmp_MinpackGL2_G_00005);
   tmp_y_00000= y(1, tmp_MinpackGL2_G_00005);
   g_tmp_MinpackGL2_G_00006= g_tmp_y_00000.* sin(arg);
   tmp_MinpackGL2_G_00006= tmp_y_00000.* sin(arg);
   g_x(nx+ 1, 1: ny+ 1)= g_tmp_MinpackGL2_G_00003- g_tmp_MinpackGL2_G_00006;
   x(nx+ 1, 1: ny+ 1)= tmp_MinpackGL2_G_00003- tmp_MinpackGL2_G_00006; 
   tmp_MinpackGL2_G_00007= ny+ 1;
   tmp_MinpackGL2_G_00008= 1: tmp_MinpackGL2_G_00007;
   g_tmp_x_00002= g_x(1, tmp_MinpackGL2_G_00008);
   tmp_x_00002= x(1, tmp_MinpackGL2_G_00008);
   g_tmp_MinpackGL2_G_00009= g_tmp_x_00002.* sin(arg);
   tmp_MinpackGL2_G_00009= tmp_x_00002.* sin(arg);
   tmp_MinpackGL2_G_00010= ny+ 1;
   tmp_MinpackGL2_G_00011= 1: tmp_MinpackGL2_G_00010;
   g_tmp_y_00001= g_y(1, tmp_MinpackGL2_G_00011);
   tmp_y_00001= y(1, tmp_MinpackGL2_G_00011);
   g_tmp_MinpackGL2_G_00012= g_tmp_y_00001.* cos(arg);
   tmp_MinpackGL2_G_00012= tmp_y_00001.* cos(arg);
   g_y(nx+ 1, 1: ny+ 1)= g_tmp_MinpackGL2_G_00009+ g_tmp_MinpackGL2_G_00012;
   y(nx+ 1, 1: ny+ 1)= tmp_MinpackGL2_G_00009+ tmp_MinpackGL2_G_00012; 
   tmp_MinpackGL2_G_00013= ny+ 1;
   tmp_MinpackGL2_G_00014= 1: tmp_MinpackGL2_G_00013;
   g_tmp_vpotx_00000= g_vpotx(1, tmp_MinpackGL2_G_00014);
   tmp_vpotx_00000= vpotx(1, tmp_MinpackGL2_G_00014);
   g_vpotx(nx+ 1, 1: ny+ 1)= g_tmp_vpotx_00000;
   vpotx(nx+ 1, 1: ny+ 1)= tmp_vpotx_00000; 
   tmp_MinpackGL2_G_00015= ny+ 1;
   tmp_MinpackGL2_G_00016= 1: tmp_MinpackGL2_G_00015;
   g_tmp_vpoty_00000= g_vpoty(1, tmp_MinpackGL2_G_00016);
   tmp_vpoty_00000= vpoty(1, tmp_MinpackGL2_G_00016);
   tmp_MinpackGL2_G_00017= 2* pi* vornum;
   tmp_MinpackGL2_G_00018= ny* hy;
   tmp_MinpackGL2_G_00019= tmp_MinpackGL2_G_00017/ tmp_MinpackGL2_G_00018;
   g_vpoty(nx+ 1, 1: ny+ 1)= g_tmp_vpoty_00000+ g_zeros(size(tmp_MinpackGL2_G_00019));
   vpoty(nx+ 1, 1: ny+ 1)= tmp_vpoty_00000+ tmp_MinpackGL2_G_00019; 
   
   % Top face for order parameter and vector potential.
   tmp_MinpackGL2_G_00020= nx+ 1;
   tmp_MinpackGL2_G_00021= 1: tmp_MinpackGL2_G_00020;
   g_tmp_x_00003= g_x(tmp_MinpackGL2_G_00021, 1);
   tmp_x_00003= x(tmp_MinpackGL2_G_00021, 1);
   g_x(1: nx+ 1, ny+ 1)= g_tmp_x_00003;
   x(1: nx+ 1, ny+ 1)= tmp_x_00003; 
   tmp_MinpackGL2_G_00022= nx+ 1;
   tmp_MinpackGL2_G_00023= 1: tmp_MinpackGL2_G_00022;
   g_tmp_y_00002= g_y(tmp_MinpackGL2_G_00023, 1);
   tmp_y_00002= y(tmp_MinpackGL2_G_00023, 1);
   g_y(1: nx+ 1, ny+ 1)= g_tmp_y_00002;
   y(1: nx+ 1, ny+ 1)= tmp_y_00002; 
   tmp_MinpackGL2_G_00024= nx+ 1;
   tmp_MinpackGL2_G_00025= 1: tmp_MinpackGL2_G_00024;
   g_tmp_vpotx_00001= g_vpotx(tmp_MinpackGL2_G_00025, 1);
   tmp_vpotx_00001= vpotx(tmp_MinpackGL2_G_00025, 1);
   g_vpotx(1: nx+ 1, ny+ 1)= g_tmp_vpotx_00001;
   vpotx(1: nx+ 1, ny+ 1)= tmp_vpotx_00001; 
   tmp_MinpackGL2_G_00026= nx+ 1;
   tmp_MinpackGL2_G_00027= 1: tmp_MinpackGL2_G_00026;
   g_tmp_vpoty_00001= g_vpoty(tmp_MinpackGL2_G_00027, 1);
   tmp_vpoty_00001= vpoty(tmp_MinpackGL2_G_00027, 1);
   g_vpoty(1: nx+ 1, ny+ 1)= g_tmp_vpoty_00001;
   vpoty(1: nx+ 1, ny+ 1)= tmp_vpoty_00001; 
   
   % gradient follows
   tmp_MinpackGL2_G_00028= 1: nx;
   tmp_MinpackGL2_G_00029= 1: ny;
   g_tmp_x_00004= g_x(tmp_MinpackGL2_G_00028, tmp_MinpackGL2_G_00029);
   tmp_x_00004= x(tmp_MinpackGL2_G_00028, tmp_MinpackGL2_G_00029);
   tmp_MinpackGL2_G_00030= 1: nx;
   tmp_MinpackGL2_G_00031= 1: ny;
   g_tmp_x_00005= g_x(tmp_MinpackGL2_G_00030, tmp_MinpackGL2_G_00031);
   tmp_x_00005= x(tmp_MinpackGL2_G_00030, tmp_MinpackGL2_G_00031);
   g_tmp_MinpackGL2_G_00032= 2.* tmp_x_00005.^ (2- 1).* g_tmp_x_00005;
   tmp_MinpackGL2_G_00032= tmp_x_00005.^ 2;
   tmp_MinpackGL2_G_00033= 1: nx;
   tmp_MinpackGL2_G_00034= 1: ny;
   g_tmp_y_00003= g_y(tmp_MinpackGL2_G_00033, tmp_MinpackGL2_G_00034);
   tmp_y_00003= y(tmp_MinpackGL2_G_00033, tmp_MinpackGL2_G_00034);
   g_tmp_MinpackGL2_G_00035= 2.* tmp_y_00003.^ (2- 1).* g_tmp_y_00003;
   tmp_MinpackGL2_G_00035= tmp_y_00003.^ 2;
   g_tmp_MinpackGL2_G_00036= g_tmp_MinpackGL2_G_00032+ g_tmp_MinpackGL2_G_00035+ g_zeros(1);
   tmp_MinpackGL2_G_00036= tmp_MinpackGL2_G_00032- 1+ tmp_MinpackGL2_G_00035;
   g_tmp_MinpackGL2_G_00037= g_tmp_x_00004.* tmp_MinpackGL2_G_00036+ tmp_x_00004.* g_tmp_MinpackGL2_G_00036;
   tmp_MinpackGL2_G_00037= tmp_x_00004.* tmp_MinpackGL2_G_00036;
   g_tmp_MinpackGL2_G_00038= g_tmp_MinpackGL2_G_00037* 2;
   tmp_MinpackGL2_G_00038= tmp_MinpackGL2_G_00037* 2;
   g_gradx= adimat_g_mrdivide1(g_tmp_MinpackGL2_G_00038, tmp_MinpackGL2_G_00038, sqn);
   gradx= tmp_MinpackGL2_G_00038/ sqn; 
   tmp_MinpackGL2_G_00039= 1: nx;
   tmp_MinpackGL2_G_00040= 1: ny;
   g_tmp_y_00004= g_y(tmp_MinpackGL2_G_00039, tmp_MinpackGL2_G_00040);
   tmp_y_00004= y(tmp_MinpackGL2_G_00039, tmp_MinpackGL2_G_00040);
   tmp_MinpackGL2_G_00041= 1: nx;
   tmp_MinpackGL2_G_00042= 1: ny;
   g_tmp_x_00006= g_x(tmp_MinpackGL2_G_00041, tmp_MinpackGL2_G_00042);
   tmp_x_00006= x(tmp_MinpackGL2_G_00041, tmp_MinpackGL2_G_00042);
   g_tmp_MinpackGL2_G_00043= 2.* tmp_x_00006.^ (2- 1).* g_tmp_x_00006;
   tmp_MinpackGL2_G_00043= tmp_x_00006.^ 2;
   tmp_MinpackGL2_G_00044= 1: nx;
   tmp_MinpackGL2_G_00045= 1: ny;
   g_tmp_y_00005= g_y(tmp_MinpackGL2_G_00044, tmp_MinpackGL2_G_00045);
   tmp_y_00005= y(tmp_MinpackGL2_G_00044, tmp_MinpackGL2_G_00045);
   g_tmp_MinpackGL2_G_00046= 2.* tmp_y_00005.^ (2- 1).* g_tmp_y_00005;
   tmp_MinpackGL2_G_00046= tmp_y_00005.^ 2;
   g_tmp_MinpackGL2_G_00047= g_tmp_MinpackGL2_G_00043+ g_tmp_MinpackGL2_G_00046+ g_zeros(1);
   tmp_MinpackGL2_G_00047= tmp_MinpackGL2_G_00043- 1+ tmp_MinpackGL2_G_00046;
   g_tmp_MinpackGL2_G_00048= g_tmp_y_00004.* tmp_MinpackGL2_G_00047+ tmp_y_00004.* g_tmp_MinpackGL2_G_00047;
   tmp_MinpackGL2_G_00048= tmp_y_00004.* tmp_MinpackGL2_G_00047;
   g_tmp_MinpackGL2_G_00049= g_tmp_MinpackGL2_G_00048* 2;
   tmp_MinpackGL2_G_00049= tmp_MinpackGL2_G_00048* 2;
   g_grady= adimat_g_mrdivide1(g_tmp_MinpackGL2_G_00049, tmp_MinpackGL2_G_00049, sqn);
   grady= tmp_MinpackGL2_G_00049/ sqn; 
   g_gradax= zeros(nx, ny).* g_dummy;
   gradax= zeros(nx, ny).* dummy; 
   g_graday= zeros(nx, ny).* g_dummy;
   graday= zeros(nx, ny).* dummy; 
   
   %    Kinetic Energy Part, Interior Points
   
   tmp_MinpackGL2_G_00050= hx* hx* sqn;
   tmp_MinpackGL2_G_00051= 2/ tmp_MinpackGL2_G_00050;
   tmp_MinpackGL2_G_00052= nx+ 1;
   tmp_MinpackGL2_G_00053= 3: tmp_MinpackGL2_G_00052;
   tmp_MinpackGL2_G_00054= 2: ny;
   g_tmp_x_00007= g_x(tmp_MinpackGL2_G_00053, tmp_MinpackGL2_G_00054);
   tmp_x_00007= x(tmp_MinpackGL2_G_00053, tmp_MinpackGL2_G_00054);
   tmp_MinpackGL2_G_00055= 2: nx;
   tmp_MinpackGL2_G_00056= 2: ny;
   g_tmp_x_00008= g_x(tmp_MinpackGL2_G_00055, tmp_MinpackGL2_G_00056);
   tmp_x_00008= x(tmp_MinpackGL2_G_00055, tmp_MinpackGL2_G_00056);
   tmp_MinpackGL2_G_00057= 2: nx;
   tmp_MinpackGL2_G_00058= 2: ny;
   g_tmp_vpotx_00002= g_vpotx(tmp_MinpackGL2_G_00057, tmp_MinpackGL2_G_00058);
   tmp_vpotx_00002= vpotx(tmp_MinpackGL2_G_00057, tmp_MinpackGL2_G_00058);
   g_tmp_MinpackGL2_G_00059= hx* g_tmp_vpotx_00002;
   tmp_MinpackGL2_G_00059= hx* tmp_vpotx_00002;
   g_tmp_cos_00000= g_tmp_MinpackGL2_G_00059.* (-sin(tmp_MinpackGL2_G_00059));
   tmp_cos_00000= cos(tmp_MinpackGL2_G_00059);
   g_tmp_MinpackGL2_G_00060= g_tmp_x_00008.* tmp_cos_00000+ tmp_x_00008.* g_tmp_cos_00000;
   tmp_MinpackGL2_G_00060= tmp_x_00008.* tmp_cos_00000;
   tmp_MinpackGL2_G_00061= 2: nx;
   tmp_MinpackGL2_G_00062= 2: ny;
   g_tmp_y_00006= g_y(tmp_MinpackGL2_G_00061, tmp_MinpackGL2_G_00062);
   tmp_y_00006= y(tmp_MinpackGL2_G_00061, tmp_MinpackGL2_G_00062);
   tmp_MinpackGL2_G_00063= 2: nx;
   tmp_MinpackGL2_G_00064= 2: ny;
   g_tmp_vpotx_00003= g_vpotx(tmp_MinpackGL2_G_00063, tmp_MinpackGL2_G_00064);
   tmp_vpotx_00003= vpotx(tmp_MinpackGL2_G_00063, tmp_MinpackGL2_G_00064);
   g_tmp_MinpackGL2_G_00065= hx* g_tmp_vpotx_00003;
   tmp_MinpackGL2_G_00065= hx* tmp_vpotx_00003;
   g_tmp_sin_00000= g_tmp_MinpackGL2_G_00065.* cos(tmp_MinpackGL2_G_00065);
   tmp_sin_00000= sin(tmp_MinpackGL2_G_00065);
   g_tmp_MinpackGL2_G_00066= g_tmp_y_00006.* tmp_sin_00000+ tmp_y_00006.* g_tmp_sin_00000;
   tmp_MinpackGL2_G_00066= tmp_y_00006.* tmp_sin_00000;
   g_tmp_MinpackGL2_G_00067= g_tmp_x_00007- g_tmp_MinpackGL2_G_00060+ g_tmp_MinpackGL2_G_00066;
   tmp_MinpackGL2_G_00067= tmp_x_00007- tmp_MinpackGL2_G_00060+ tmp_MinpackGL2_G_00066;
   g_fkinx1= tmp_MinpackGL2_G_00051* g_tmp_MinpackGL2_G_00067;
   fkinx1= tmp_MinpackGL2_G_00051* tmp_MinpackGL2_G_00067; 
   tmp_MinpackGL2_G_00068= hx* hx* sqn;
   tmp_MinpackGL2_G_00069= 2/ tmp_MinpackGL2_G_00068;
   tmp_MinpackGL2_G_00070= nx+ 1;
   tmp_MinpackGL2_G_00071= 3: tmp_MinpackGL2_G_00070;
   tmp_MinpackGL2_G_00072= 2: ny;
   g_tmp_y_00007= g_y(tmp_MinpackGL2_G_00071, tmp_MinpackGL2_G_00072);
   tmp_y_00007= y(tmp_MinpackGL2_G_00071, tmp_MinpackGL2_G_00072);
   tmp_MinpackGL2_G_00073= 2: nx;
   tmp_MinpackGL2_G_00074= 2: ny;
   g_tmp_y_00008= g_y(tmp_MinpackGL2_G_00073, tmp_MinpackGL2_G_00074);
   tmp_y_00008= y(tmp_MinpackGL2_G_00073, tmp_MinpackGL2_G_00074);
   tmp_MinpackGL2_G_00075= 2: nx;
   tmp_MinpackGL2_G_00076= 2: ny;
   g_tmp_vpotx_00004= g_vpotx(tmp_MinpackGL2_G_00075, tmp_MinpackGL2_G_00076);
   tmp_vpotx_00004= vpotx(tmp_MinpackGL2_G_00075, tmp_MinpackGL2_G_00076);
   g_tmp_MinpackGL2_G_00077= hx* g_tmp_vpotx_00004;
   tmp_MinpackGL2_G_00077= hx* tmp_vpotx_00004;
   g_tmp_cos_00001= g_tmp_MinpackGL2_G_00077.* (-sin(tmp_MinpackGL2_G_00077));
   tmp_cos_00001= cos(tmp_MinpackGL2_G_00077);
   g_tmp_MinpackGL2_G_00078= g_tmp_y_00008.* tmp_cos_00001+ tmp_y_00008.* g_tmp_cos_00001;
   tmp_MinpackGL2_G_00078= tmp_y_00008.* tmp_cos_00001;
   tmp_MinpackGL2_G_00079= 2: nx;
   tmp_MinpackGL2_G_00080= 2: ny;
   g_tmp_x_00009= g_x(tmp_MinpackGL2_G_00079, tmp_MinpackGL2_G_00080);
   tmp_x_00009= x(tmp_MinpackGL2_G_00079, tmp_MinpackGL2_G_00080);
   tmp_MinpackGL2_G_00081= 2: nx;
   tmp_MinpackGL2_G_00082= 2: ny;
   g_tmp_vpotx_00005= g_vpotx(tmp_MinpackGL2_G_00081, tmp_MinpackGL2_G_00082);
   tmp_vpotx_00005= vpotx(tmp_MinpackGL2_G_00081, tmp_MinpackGL2_G_00082);
   g_tmp_MinpackGL2_G_00083= hx* g_tmp_vpotx_00005;
   tmp_MinpackGL2_G_00083= hx* tmp_vpotx_00005;
   g_tmp_sin_00001= g_tmp_MinpackGL2_G_00083.* cos(tmp_MinpackGL2_G_00083);
   tmp_sin_00001= sin(tmp_MinpackGL2_G_00083);
   g_tmp_MinpackGL2_G_00084= g_tmp_x_00009.* tmp_sin_00001+ tmp_x_00009.* g_tmp_sin_00001;
   tmp_MinpackGL2_G_00084= tmp_x_00009.* tmp_sin_00001;
   g_tmp_MinpackGL2_G_00085= g_tmp_y_00007- g_tmp_MinpackGL2_G_00078- g_tmp_MinpackGL2_G_00084;
   tmp_MinpackGL2_G_00085= tmp_y_00007- tmp_MinpackGL2_G_00078- tmp_MinpackGL2_G_00084;
   g_fkinx2= tmp_MinpackGL2_G_00069* g_tmp_MinpackGL2_G_00085;
   fkinx2= tmp_MinpackGL2_G_00069* tmp_MinpackGL2_G_00085; 
   tmp_MinpackGL2_G_00086= hy* hy* sqn;
   tmp_MinpackGL2_G_00087= 2/ tmp_MinpackGL2_G_00086;
   tmp_MinpackGL2_G_00088= 2: nx;
   tmp_MinpackGL2_G_00089= ny+ 1;
   tmp_MinpackGL2_G_00090= 3: tmp_MinpackGL2_G_00089;
   g_tmp_x_00010= g_x(tmp_MinpackGL2_G_00088, tmp_MinpackGL2_G_00090);
   tmp_x_00010= x(tmp_MinpackGL2_G_00088, tmp_MinpackGL2_G_00090);
   tmp_MinpackGL2_G_00091= 2: nx;
   tmp_MinpackGL2_G_00092= 2: ny;
   g_tmp_x_00011= g_x(tmp_MinpackGL2_G_00091, tmp_MinpackGL2_G_00092);
   tmp_x_00011= x(tmp_MinpackGL2_G_00091, tmp_MinpackGL2_G_00092);
   tmp_MinpackGL2_G_00093= 2: nx;
   tmp_MinpackGL2_G_00094= 2: ny;
   g_tmp_vpoty_00002= g_vpoty(tmp_MinpackGL2_G_00093, tmp_MinpackGL2_G_00094);
   tmp_vpoty_00002= vpoty(tmp_MinpackGL2_G_00093, tmp_MinpackGL2_G_00094);
   g_tmp_MinpackGL2_G_00095= hy* g_tmp_vpoty_00002;
   tmp_MinpackGL2_G_00095= hy* tmp_vpoty_00002;
   g_tmp_cos_00002= g_tmp_MinpackGL2_G_00095.* (-sin(tmp_MinpackGL2_G_00095));
   tmp_cos_00002= cos(tmp_MinpackGL2_G_00095);
   g_tmp_MinpackGL2_G_00096= g_tmp_x_00011.* tmp_cos_00002+ tmp_x_00011.* g_tmp_cos_00002;
   tmp_MinpackGL2_G_00096= tmp_x_00011.* tmp_cos_00002;
   tmp_MinpackGL2_G_00097= 2: nx;
   tmp_MinpackGL2_G_00098= 2: ny;
   g_tmp_y_00009= g_y(tmp_MinpackGL2_G_00097, tmp_MinpackGL2_G_00098);
   tmp_y_00009= y(tmp_MinpackGL2_G_00097, tmp_MinpackGL2_G_00098);
   tmp_MinpackGL2_G_00099= 2: nx;
   tmp_MinpackGL2_G_00100= 2: ny;
   g_tmp_vpoty_00003= g_vpoty(tmp_MinpackGL2_G_00099, tmp_MinpackGL2_G_00100);
   tmp_vpoty_00003= vpoty(tmp_MinpackGL2_G_00099, tmp_MinpackGL2_G_00100);
   g_tmp_MinpackGL2_G_00101= hy* g_tmp_vpoty_00003;
   tmp_MinpackGL2_G_00101= hy* tmp_vpoty_00003;
   g_tmp_sin_00002= g_tmp_MinpackGL2_G_00101.* cos(tmp_MinpackGL2_G_00101);
   tmp_sin_00002= sin(tmp_MinpackGL2_G_00101);
   g_tmp_MinpackGL2_G_00102= g_tmp_y_00009.* tmp_sin_00002+ tmp_y_00009.* g_tmp_sin_00002;
   tmp_MinpackGL2_G_00102= tmp_y_00009.* tmp_sin_00002;
   g_tmp_MinpackGL2_G_00103= g_tmp_x_00010- g_tmp_MinpackGL2_G_00096+ g_tmp_MinpackGL2_G_00102;
   tmp_MinpackGL2_G_00103= tmp_x_00010- tmp_MinpackGL2_G_00096+ tmp_MinpackGL2_G_00102;
   g_fkiny1= tmp_MinpackGL2_G_00087* g_tmp_MinpackGL2_G_00103;
   fkiny1= tmp_MinpackGL2_G_00087* tmp_MinpackGL2_G_00103; 
   tmp_MinpackGL2_G_00104= hy* hy* sqn;
   tmp_MinpackGL2_G_00105= 2/ tmp_MinpackGL2_G_00104;
   tmp_MinpackGL2_G_00106= 2: nx;
   tmp_MinpackGL2_G_00107= ny+ 1;
   tmp_MinpackGL2_G_00108= 3: tmp_MinpackGL2_G_00107;
   g_tmp_y_00010= g_y(tmp_MinpackGL2_G_00106, tmp_MinpackGL2_G_00108);
   tmp_y_00010= y(tmp_MinpackGL2_G_00106, tmp_MinpackGL2_G_00108);
   tmp_MinpackGL2_G_00109= 2: nx;
   tmp_MinpackGL2_G_00110= 2: ny;
   g_tmp_y_00011= g_y(tmp_MinpackGL2_G_00109, tmp_MinpackGL2_G_00110);
   tmp_y_00011= y(tmp_MinpackGL2_G_00109, tmp_MinpackGL2_G_00110);
   tmp_MinpackGL2_G_00111= 2: nx;
   tmp_MinpackGL2_G_00112= 2: ny;
   g_tmp_vpoty_00004= g_vpoty(tmp_MinpackGL2_G_00111, tmp_MinpackGL2_G_00112);
   tmp_vpoty_00004= vpoty(tmp_MinpackGL2_G_00111, tmp_MinpackGL2_G_00112);
   g_tmp_MinpackGL2_G_00113= hy* g_tmp_vpoty_00004;
   tmp_MinpackGL2_G_00113= hy* tmp_vpoty_00004;
   g_tmp_cos_00003= g_tmp_MinpackGL2_G_00113.* (-sin(tmp_MinpackGL2_G_00113));
   tmp_cos_00003= cos(tmp_MinpackGL2_G_00113);
   g_tmp_MinpackGL2_G_00114= g_tmp_y_00011.* tmp_cos_00003+ tmp_y_00011.* g_tmp_cos_00003;
   tmp_MinpackGL2_G_00114= tmp_y_00011.* tmp_cos_00003;
   tmp_MinpackGL2_G_00115= 2: nx;
   tmp_MinpackGL2_G_00116= 2: ny;
   g_tmp_x_00012= g_x(tmp_MinpackGL2_G_00115, tmp_MinpackGL2_G_00116);
   tmp_x_00012= x(tmp_MinpackGL2_G_00115, tmp_MinpackGL2_G_00116);
   tmp_MinpackGL2_G_00117= 2: nx;
   tmp_MinpackGL2_G_00118= 2: ny;
   g_tmp_vpoty_00005= g_vpoty(tmp_MinpackGL2_G_00117, tmp_MinpackGL2_G_00118);
   tmp_vpoty_00005= vpoty(tmp_MinpackGL2_G_00117, tmp_MinpackGL2_G_00118);
   g_tmp_MinpackGL2_G_00119= hy* g_tmp_vpoty_00005;
   tmp_MinpackGL2_G_00119= hy* tmp_vpoty_00005;
   g_tmp_sin_00003= g_tmp_MinpackGL2_G_00119.* cos(tmp_MinpackGL2_G_00119);
   tmp_sin_00003= sin(tmp_MinpackGL2_G_00119);
   g_tmp_MinpackGL2_G_00120= g_tmp_x_00012.* tmp_sin_00003+ tmp_x_00012.* g_tmp_sin_00003;
   tmp_MinpackGL2_G_00120= tmp_x_00012.* tmp_sin_00003;
   g_tmp_MinpackGL2_G_00121= g_tmp_y_00010- g_tmp_MinpackGL2_G_00114- g_tmp_MinpackGL2_G_00120;
   tmp_MinpackGL2_G_00121= tmp_y_00010- tmp_MinpackGL2_G_00114- tmp_MinpackGL2_G_00120;
   g_fkiny2= tmp_MinpackGL2_G_00105* g_tmp_MinpackGL2_G_00121;
   fkiny2= tmp_MinpackGL2_G_00105* tmp_MinpackGL2_G_00121; 
   tmp_MinpackGL2_G_00122= 2: nx;
   tmp_MinpackGL2_G_00123= 2: ny;
   g_tmp_vpotx_00006= g_vpotx(tmp_MinpackGL2_G_00122, tmp_MinpackGL2_G_00123);
   tmp_vpotx_00006= vpotx(tmp_MinpackGL2_G_00122, tmp_MinpackGL2_G_00123);
   tmp_MinpackGL2_G_00124= 2: nx;
   tmp_MinpackGL2_G_00125= ny+ 1;
   tmp_MinpackGL2_G_00126= 3: tmp_MinpackGL2_G_00125;
   g_tmp_vpotx_00007= g_vpotx(tmp_MinpackGL2_G_00124, tmp_MinpackGL2_G_00126);
   tmp_vpotx_00007= vpotx(tmp_MinpackGL2_G_00124, tmp_MinpackGL2_G_00126);
   g_tmp_MinpackGL2_G_00127= g_tmp_vpotx_00006- g_tmp_vpotx_00007;
   tmp_MinpackGL2_G_00127= tmp_vpotx_00006- tmp_vpotx_00007;
   g_tmp_MinpackGL2_G_00128= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00127), (tmp_MinpackGL2_G_00127), hy);
   tmp_MinpackGL2_G_00128= tmp_MinpackGL2_G_00127/ hy;
   tmp_MinpackGL2_G_00129= nx+ 1;
   tmp_MinpackGL2_G_00130= 3: tmp_MinpackGL2_G_00129;
   tmp_MinpackGL2_G_00131= 2: ny;
   g_tmp_vpoty_00006= g_vpoty(tmp_MinpackGL2_G_00130, tmp_MinpackGL2_G_00131);
   tmp_vpoty_00006= vpoty(tmp_MinpackGL2_G_00130, tmp_MinpackGL2_G_00131);
   tmp_MinpackGL2_G_00132= 2: nx;
   tmp_MinpackGL2_G_00133= 2: ny;
   g_tmp_vpoty_00007= g_vpoty(tmp_MinpackGL2_G_00132, tmp_MinpackGL2_G_00133);
   tmp_vpoty_00007= vpoty(tmp_MinpackGL2_G_00132, tmp_MinpackGL2_G_00133);
   g_tmp_MinpackGL2_G_00134= g_tmp_vpoty_00006- g_tmp_vpoty_00007;
   tmp_MinpackGL2_G_00134= tmp_vpoty_00006- tmp_vpoty_00007;
   g_tmp_MinpackGL2_G_00135= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00134), (tmp_MinpackGL2_G_00134), hx);
   tmp_MinpackGL2_G_00135= tmp_MinpackGL2_G_00134/ hx;
   g_tmp_MinpackGL2_G_00136= g_tmp_MinpackGL2_G_00128+ g_tmp_MinpackGL2_G_00135;
   tmp_MinpackGL2_G_00136= tmp_MinpackGL2_G_00128+ tmp_MinpackGL2_G_00135;
   tmp_MinpackGL2_G_00137= tkappa^ 2;
   tmp_MinpackGL2_G_00138= 2* tmp_MinpackGL2_G_00137;
   tmp_MinpackGL2_G_00139= tmp_MinpackGL2_G_00138/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00136* tmp_MinpackGL2_G_00139;
   ffield= tmp_MinpackGL2_G_00136* tmp_MinpackGL2_G_00139; 
   tmp_MinpackGL2_G_00140= 2: nx;
   tmp_MinpackGL2_G_00141= 2: ny;
   g_tmp_gradx_00000= g_gradx(tmp_MinpackGL2_G_00140, tmp_MinpackGL2_G_00141);
   tmp_gradx_00000= gradx(tmp_MinpackGL2_G_00140, tmp_MinpackGL2_G_00141);
   tmp_MinpackGL2_G_00142= 2: nx;
   tmp_MinpackGL2_G_00143= 2: ny;
   g_tmp_vpotx_00008= g_vpotx(tmp_MinpackGL2_G_00142, tmp_MinpackGL2_G_00143);
   tmp_vpotx_00008= vpotx(tmp_MinpackGL2_G_00142, tmp_MinpackGL2_G_00143);
   g_tmp_MinpackGL2_G_00144= hx* g_tmp_vpotx_00008;
   tmp_MinpackGL2_G_00144= hx* tmp_vpotx_00008;
   g_tmp_cos_00004= g_tmp_MinpackGL2_G_00144.* (-sin(tmp_MinpackGL2_G_00144));
   tmp_cos_00004= cos(tmp_MinpackGL2_G_00144);
   g_tmp_MinpackGL2_G_00145= g_tmp_cos_00004.* fkinx1+ tmp_cos_00004.* g_fkinx1;
   tmp_MinpackGL2_G_00145= tmp_cos_00004.* fkinx1;
   tmp_MinpackGL2_G_00146= 2: nx;
   tmp_MinpackGL2_G_00147= 2: ny;
   g_tmp_vpotx_00009= g_vpotx(tmp_MinpackGL2_G_00146, tmp_MinpackGL2_G_00147);
   tmp_vpotx_00009= vpotx(tmp_MinpackGL2_G_00146, tmp_MinpackGL2_G_00147);
   g_tmp_MinpackGL2_G_00148= hx* g_tmp_vpotx_00009;
   tmp_MinpackGL2_G_00148= hx* tmp_vpotx_00009;
   g_tmp_sin_00004= g_tmp_MinpackGL2_G_00148.* cos(tmp_MinpackGL2_G_00148);
   tmp_sin_00004= sin(tmp_MinpackGL2_G_00148);
   g_tmp_MinpackGL2_G_00149= g_tmp_sin_00004.* fkinx2+ tmp_sin_00004.* g_fkinx2;
   tmp_MinpackGL2_G_00149= tmp_sin_00004.* fkinx2;
   tmp_MinpackGL2_G_00150= 2: nx;
   tmp_MinpackGL2_G_00151= 2: ny;
   g_tmp_vpoty_00008= g_vpoty(tmp_MinpackGL2_G_00150, tmp_MinpackGL2_G_00151);
   tmp_vpoty_00008= vpoty(tmp_MinpackGL2_G_00150, tmp_MinpackGL2_G_00151);
   g_tmp_MinpackGL2_G_00152= hy* g_tmp_vpoty_00008;
   tmp_MinpackGL2_G_00152= hy* tmp_vpoty_00008;
   g_tmp_cos_00005= g_tmp_MinpackGL2_G_00152.* (-sin(tmp_MinpackGL2_G_00152));
   tmp_cos_00005= cos(tmp_MinpackGL2_G_00152);
   g_tmp_MinpackGL2_G_00153= g_tmp_cos_00005.* fkiny1+ tmp_cos_00005.* g_fkiny1;
   tmp_MinpackGL2_G_00153= tmp_cos_00005.* fkiny1;
   tmp_MinpackGL2_G_00154= 2: nx;
   tmp_MinpackGL2_G_00155= 2: ny;
   g_tmp_vpoty_00009= g_vpoty(tmp_MinpackGL2_G_00154, tmp_MinpackGL2_G_00155);
   tmp_vpoty_00009= vpoty(tmp_MinpackGL2_G_00154, tmp_MinpackGL2_G_00155);
   g_tmp_MinpackGL2_G_00156= hy* g_tmp_vpoty_00009;
   tmp_MinpackGL2_G_00156= hy* tmp_vpoty_00009;
   g_tmp_sin_00005= g_tmp_MinpackGL2_G_00156.* cos(tmp_MinpackGL2_G_00156);
   tmp_sin_00005= sin(tmp_MinpackGL2_G_00156);
   g_tmp_MinpackGL2_G_00157= g_tmp_sin_00005.* fkiny2+ tmp_sin_00005.* g_fkiny2;
   tmp_MinpackGL2_G_00157= tmp_sin_00005.* fkiny2;
   g_gradx(2: nx, 2: ny)= g_tmp_gradx_00000- g_tmp_MinpackGL2_G_00145- g_tmp_MinpackGL2_G_00149- g_tmp_MinpackGL2_G_00153- g_tmp_MinpackGL2_G_00157;
   gradx(2: nx, 2: ny)= tmp_gradx_00000- tmp_MinpackGL2_G_00145- tmp_MinpackGL2_G_00149- tmp_MinpackGL2_G_00153- tmp_MinpackGL2_G_00157; 
   tmp_MinpackGL2_G_00158= 2: nx;
   tmp_MinpackGL2_G_00159= 2: ny;
   g_tmp_grady_00000= g_grady(tmp_MinpackGL2_G_00158, tmp_MinpackGL2_G_00159);
   tmp_grady_00000= grady(tmp_MinpackGL2_G_00158, tmp_MinpackGL2_G_00159);
   tmp_MinpackGL2_G_00160= 2: nx;
   tmp_MinpackGL2_G_00161= 2: ny;
   g_tmp_vpotx_00010= g_vpotx(tmp_MinpackGL2_G_00160, tmp_MinpackGL2_G_00161);
   tmp_vpotx_00010= vpotx(tmp_MinpackGL2_G_00160, tmp_MinpackGL2_G_00161);
   g_tmp_MinpackGL2_G_00162= hx* g_tmp_vpotx_00010;
   tmp_MinpackGL2_G_00162= hx* tmp_vpotx_00010;
   g_tmp_sin_00006= g_tmp_MinpackGL2_G_00162.* cos(tmp_MinpackGL2_G_00162);
   tmp_sin_00006= sin(tmp_MinpackGL2_G_00162);
   g_tmp_MinpackGL2_G_00163= g_tmp_sin_00006.* fkinx1+ tmp_sin_00006.* g_fkinx1;
   tmp_MinpackGL2_G_00163= tmp_sin_00006.* fkinx1;
   tmp_MinpackGL2_G_00164= 2: nx;
   tmp_MinpackGL2_G_00165= 2: ny;
   g_tmp_vpotx_00011= g_vpotx(tmp_MinpackGL2_G_00164, tmp_MinpackGL2_G_00165);
   tmp_vpotx_00011= vpotx(tmp_MinpackGL2_G_00164, tmp_MinpackGL2_G_00165);
   g_tmp_MinpackGL2_G_00166= hx* g_tmp_vpotx_00011;
   tmp_MinpackGL2_G_00166= hx* tmp_vpotx_00011;
   g_tmp_cos_00006= g_tmp_MinpackGL2_G_00166.* (-sin(tmp_MinpackGL2_G_00166));
   tmp_cos_00006= cos(tmp_MinpackGL2_G_00166);
   g_tmp_MinpackGL2_G_00167= g_tmp_cos_00006.* fkinx2+ tmp_cos_00006.* g_fkinx2;
   tmp_MinpackGL2_G_00167= tmp_cos_00006.* fkinx2;
   tmp_MinpackGL2_G_00168= 2: nx;
   tmp_MinpackGL2_G_00169= 2: ny;
   g_tmp_vpoty_00010= g_vpoty(tmp_MinpackGL2_G_00168, tmp_MinpackGL2_G_00169);
   tmp_vpoty_00010= vpoty(tmp_MinpackGL2_G_00168, tmp_MinpackGL2_G_00169);
   g_tmp_MinpackGL2_G_00170= hy* g_tmp_vpoty_00010;
   tmp_MinpackGL2_G_00170= hy* tmp_vpoty_00010;
   g_tmp_sin_00007= g_tmp_MinpackGL2_G_00170.* cos(tmp_MinpackGL2_G_00170);
   tmp_sin_00007= sin(tmp_MinpackGL2_G_00170);
   g_tmp_MinpackGL2_G_00171= g_tmp_sin_00007.* fkiny1+ tmp_sin_00007.* g_fkiny1;
   tmp_MinpackGL2_G_00171= tmp_sin_00007.* fkiny1;
   tmp_MinpackGL2_G_00172= 2: nx;
   tmp_MinpackGL2_G_00173= 2: ny;
   g_tmp_vpoty_00011= g_vpoty(tmp_MinpackGL2_G_00172, tmp_MinpackGL2_G_00173);
   tmp_vpoty_00011= vpoty(tmp_MinpackGL2_G_00172, tmp_MinpackGL2_G_00173);
   g_tmp_MinpackGL2_G_00174= hy* g_tmp_vpoty_00011;
   tmp_MinpackGL2_G_00174= hy* tmp_vpoty_00011;
   g_tmp_cos_00007= g_tmp_MinpackGL2_G_00174.* (-sin(tmp_MinpackGL2_G_00174));
   tmp_cos_00007= cos(tmp_MinpackGL2_G_00174);
   g_tmp_MinpackGL2_G_00175= g_tmp_cos_00007.* fkiny2+ tmp_cos_00007.* g_fkiny2;
   tmp_MinpackGL2_G_00175= tmp_cos_00007.* fkiny2;
   g_grady(2: nx, 2: ny)= g_tmp_grady_00000+ g_tmp_MinpackGL2_G_00163- g_tmp_MinpackGL2_G_00167+ g_tmp_MinpackGL2_G_00171- g_tmp_MinpackGL2_G_00175;
   grady(2: nx, 2: ny)= tmp_grady_00000+ tmp_MinpackGL2_G_00163- tmp_MinpackGL2_G_00167+ tmp_MinpackGL2_G_00171- tmp_MinpackGL2_G_00175; 
   g_tmp_MinpackGL2_G_00176= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00176= ffield/ hy;
   tmp_MinpackGL2_G_00177= 2: nx;
   tmp_MinpackGL2_G_00178= 2: ny;
   g_tmp_x_00013= g_x(tmp_MinpackGL2_G_00177, tmp_MinpackGL2_G_00178);
   tmp_x_00013= x(tmp_MinpackGL2_G_00177, tmp_MinpackGL2_G_00178);
   g_tmp_MinpackGL2_G_00179= hx* g_tmp_x_00013;
   tmp_MinpackGL2_G_00179= hx* tmp_x_00013;
   tmp_MinpackGL2_G_00180= 2: nx;
   tmp_MinpackGL2_G_00181= 2: ny;
   g_tmp_vpotx_00012= g_vpotx(tmp_MinpackGL2_G_00180, tmp_MinpackGL2_G_00181);
   tmp_vpotx_00012= vpotx(tmp_MinpackGL2_G_00180, tmp_MinpackGL2_G_00181);
   g_tmp_MinpackGL2_G_00182= hx* g_tmp_vpotx_00012;
   tmp_MinpackGL2_G_00182= hx* tmp_vpotx_00012;
   g_tmp_sin_00008= g_tmp_MinpackGL2_G_00182.* cos(tmp_MinpackGL2_G_00182);
   tmp_sin_00008= sin(tmp_MinpackGL2_G_00182);
   g_tmp_MinpackGL2_G_00183= g_tmp_MinpackGL2_G_00179.* tmp_sin_00008+ tmp_MinpackGL2_G_00179.* g_tmp_sin_00008;
   tmp_MinpackGL2_G_00183= tmp_MinpackGL2_G_00179.* tmp_sin_00008;
   tmp_MinpackGL2_G_00184= 2: nx;
   tmp_MinpackGL2_G_00185= 2: ny;
   g_tmp_y_00012= g_y(tmp_MinpackGL2_G_00184, tmp_MinpackGL2_G_00185);
   tmp_y_00012= y(tmp_MinpackGL2_G_00184, tmp_MinpackGL2_G_00185);
   g_tmp_MinpackGL2_G_00186= hx* g_tmp_y_00012;
   tmp_MinpackGL2_G_00186= hx* tmp_y_00012;
   tmp_MinpackGL2_G_00187= 2: nx;
   tmp_MinpackGL2_G_00188= 2: ny;
   g_tmp_vpotx_00013= g_vpotx(tmp_MinpackGL2_G_00187, tmp_MinpackGL2_G_00188);
   tmp_vpotx_00013= vpotx(tmp_MinpackGL2_G_00187, tmp_MinpackGL2_G_00188);
   g_tmp_MinpackGL2_G_00189= hx* g_tmp_vpotx_00013;
   tmp_MinpackGL2_G_00189= hx* tmp_vpotx_00013;
   g_tmp_cos_00008= g_tmp_MinpackGL2_G_00189.* (-sin(tmp_MinpackGL2_G_00189));
   tmp_cos_00008= cos(tmp_MinpackGL2_G_00189);
   g_tmp_MinpackGL2_G_00190= g_tmp_MinpackGL2_G_00186.* tmp_cos_00008+ tmp_MinpackGL2_G_00186.* g_tmp_cos_00008;
   tmp_MinpackGL2_G_00190= tmp_MinpackGL2_G_00186.* tmp_cos_00008;
   g_tmp_MinpackGL2_G_00191= g_tmp_MinpackGL2_G_00183+ g_tmp_MinpackGL2_G_00190;
   tmp_MinpackGL2_G_00191= tmp_MinpackGL2_G_00183+ tmp_MinpackGL2_G_00190;
   g_tmp_MinpackGL2_G_00192= g_fkinx1.* tmp_MinpackGL2_G_00191+ fkinx1.* g_tmp_MinpackGL2_G_00191;
   tmp_MinpackGL2_G_00192= fkinx1.* tmp_MinpackGL2_G_00191;
   tmp_MinpackGL2_G_00193= 2: nx;
   tmp_MinpackGL2_G_00194= 2: ny;
   g_tmp_y_00013= g_y(tmp_MinpackGL2_G_00193, tmp_MinpackGL2_G_00194);
   tmp_y_00013= y(tmp_MinpackGL2_G_00193, tmp_MinpackGL2_G_00194);
   g_tmp_MinpackGL2_G_00195= hx* g_tmp_y_00013;
   tmp_MinpackGL2_G_00195= hx* tmp_y_00013;
   tmp_MinpackGL2_G_00196= 2: nx;
   tmp_MinpackGL2_G_00197= 2: ny;
   g_tmp_vpotx_00014= g_vpotx(tmp_MinpackGL2_G_00196, tmp_MinpackGL2_G_00197);
   tmp_vpotx_00014= vpotx(tmp_MinpackGL2_G_00196, tmp_MinpackGL2_G_00197);
   g_tmp_MinpackGL2_G_00198= hx* g_tmp_vpotx_00014;
   tmp_MinpackGL2_G_00198= hx* tmp_vpotx_00014;
   g_tmp_sin_00009= g_tmp_MinpackGL2_G_00198.* cos(tmp_MinpackGL2_G_00198);
   tmp_sin_00009= sin(tmp_MinpackGL2_G_00198);
   g_tmp_MinpackGL2_G_00199= g_tmp_MinpackGL2_G_00195.* tmp_sin_00009+ tmp_MinpackGL2_G_00195.* g_tmp_sin_00009;
   tmp_MinpackGL2_G_00199= tmp_MinpackGL2_G_00195.* tmp_sin_00009;
   tmp_MinpackGL2_G_00200= 2: nx;
   tmp_MinpackGL2_G_00201= 2: ny;
   g_tmp_x_00014= g_x(tmp_MinpackGL2_G_00200, tmp_MinpackGL2_G_00201);
   tmp_x_00014= x(tmp_MinpackGL2_G_00200, tmp_MinpackGL2_G_00201);
   g_tmp_MinpackGL2_G_00202= hx* g_tmp_x_00014;
   tmp_MinpackGL2_G_00202= hx* tmp_x_00014;
   tmp_MinpackGL2_G_00203= 2: nx;
   tmp_MinpackGL2_G_00204= 2: ny;
   g_tmp_vpotx_00015= g_vpotx(tmp_MinpackGL2_G_00203, tmp_MinpackGL2_G_00204);
   tmp_vpotx_00015= vpotx(tmp_MinpackGL2_G_00203, tmp_MinpackGL2_G_00204);
   g_tmp_MinpackGL2_G_00205= hx* g_tmp_vpotx_00015;
   tmp_MinpackGL2_G_00205= hx* tmp_vpotx_00015;
   g_tmp_cos_00009= g_tmp_MinpackGL2_G_00205.* (-sin(tmp_MinpackGL2_G_00205));
   tmp_cos_00009= cos(tmp_MinpackGL2_G_00205);
   g_tmp_MinpackGL2_G_00206= g_tmp_MinpackGL2_G_00202.* tmp_cos_00009+ tmp_MinpackGL2_G_00202.* g_tmp_cos_00009;
   tmp_MinpackGL2_G_00206= tmp_MinpackGL2_G_00202.* tmp_cos_00009;
   g_tmp_MinpackGL2_G_00207= g_tmp_MinpackGL2_G_00199- g_tmp_MinpackGL2_G_00206;
   tmp_MinpackGL2_G_00207= tmp_MinpackGL2_G_00199- tmp_MinpackGL2_G_00206;
   g_tmp_MinpackGL2_G_00208= g_fkinx2.* tmp_MinpackGL2_G_00207+ fkinx2.* g_tmp_MinpackGL2_G_00207;
   tmp_MinpackGL2_G_00208= fkinx2.* tmp_MinpackGL2_G_00207;
   g_gradax(2: nx, 2: ny)= g_tmp_MinpackGL2_G_00176+ g_tmp_MinpackGL2_G_00192+ g_tmp_MinpackGL2_G_00208;
   gradax(2: nx, 2: ny)= tmp_MinpackGL2_G_00176+ tmp_MinpackGL2_G_00192+ tmp_MinpackGL2_G_00208; 
   g_tmp_MinpackGL2_G_00209= -g_ffield;
   tmp_MinpackGL2_G_00209= -ffield;
   g_tmp_MinpackGL2_G_00210= adimat_g_mrdivide1(g_tmp_MinpackGL2_G_00209, tmp_MinpackGL2_G_00209, hx);
   tmp_MinpackGL2_G_00210= tmp_MinpackGL2_G_00209/ hx;
   tmp_MinpackGL2_G_00211= 2: nx;
   tmp_MinpackGL2_G_00212= 2: ny;
   g_tmp_x_00015= g_x(tmp_MinpackGL2_G_00211, tmp_MinpackGL2_G_00212);
   tmp_x_00015= x(tmp_MinpackGL2_G_00211, tmp_MinpackGL2_G_00212);
   g_tmp_MinpackGL2_G_00213= hy* g_tmp_x_00015;
   tmp_MinpackGL2_G_00213= hy* tmp_x_00015;
   tmp_MinpackGL2_G_00214= 2: nx;
   tmp_MinpackGL2_G_00215= 2: ny;
   g_tmp_vpoty_00012= g_vpoty(tmp_MinpackGL2_G_00214, tmp_MinpackGL2_G_00215);
   tmp_vpoty_00012= vpoty(tmp_MinpackGL2_G_00214, tmp_MinpackGL2_G_00215);
   g_tmp_MinpackGL2_G_00216= hy* g_tmp_vpoty_00012;
   tmp_MinpackGL2_G_00216= hy* tmp_vpoty_00012;
   g_tmp_sin_00010= g_tmp_MinpackGL2_G_00216.* cos(tmp_MinpackGL2_G_00216);
   tmp_sin_00010= sin(tmp_MinpackGL2_G_00216);
   g_tmp_MinpackGL2_G_00217= g_tmp_MinpackGL2_G_00213.* tmp_sin_00010+ tmp_MinpackGL2_G_00213.* g_tmp_sin_00010;
   tmp_MinpackGL2_G_00217= tmp_MinpackGL2_G_00213.* tmp_sin_00010;
   tmp_MinpackGL2_G_00218= 2: nx;
   tmp_MinpackGL2_G_00219= 2: ny;
   g_tmp_y_00014= g_y(tmp_MinpackGL2_G_00218, tmp_MinpackGL2_G_00219);
   tmp_y_00014= y(tmp_MinpackGL2_G_00218, tmp_MinpackGL2_G_00219);
   g_tmp_MinpackGL2_G_00220= hy* g_tmp_y_00014;
   tmp_MinpackGL2_G_00220= hy* tmp_y_00014;
   tmp_MinpackGL2_G_00221= 2: nx;
   tmp_MinpackGL2_G_00222= 2: ny;
   g_tmp_vpoty_00013= g_vpoty(tmp_MinpackGL2_G_00221, tmp_MinpackGL2_G_00222);
   tmp_vpoty_00013= vpoty(tmp_MinpackGL2_G_00221, tmp_MinpackGL2_G_00222);
   g_tmp_MinpackGL2_G_00223= hy* g_tmp_vpoty_00013;
   tmp_MinpackGL2_G_00223= hy* tmp_vpoty_00013;
   g_tmp_cos_00010= g_tmp_MinpackGL2_G_00223.* (-sin(tmp_MinpackGL2_G_00223));
   tmp_cos_00010= cos(tmp_MinpackGL2_G_00223);
   g_tmp_MinpackGL2_G_00224= g_tmp_MinpackGL2_G_00220.* tmp_cos_00010+ tmp_MinpackGL2_G_00220.* g_tmp_cos_00010;
   tmp_MinpackGL2_G_00224= tmp_MinpackGL2_G_00220.* tmp_cos_00010;
   g_tmp_MinpackGL2_G_00225= g_tmp_MinpackGL2_G_00217+ g_tmp_MinpackGL2_G_00224;
   tmp_MinpackGL2_G_00225= tmp_MinpackGL2_G_00217+ tmp_MinpackGL2_G_00224;
   g_tmp_MinpackGL2_G_00226= g_fkiny1.* tmp_MinpackGL2_G_00225+ fkiny1.* g_tmp_MinpackGL2_G_00225;
   tmp_MinpackGL2_G_00226= fkiny1.* tmp_MinpackGL2_G_00225;
   tmp_MinpackGL2_G_00227= 2: nx;
   tmp_MinpackGL2_G_00228= 2: ny;
   g_tmp_y_00015= g_y(tmp_MinpackGL2_G_00227, tmp_MinpackGL2_G_00228);
   tmp_y_00015= y(tmp_MinpackGL2_G_00227, tmp_MinpackGL2_G_00228);
   g_tmp_MinpackGL2_G_00229= hy* g_tmp_y_00015;
   tmp_MinpackGL2_G_00229= hy* tmp_y_00015;
   tmp_MinpackGL2_G_00230= 2: nx;
   tmp_MinpackGL2_G_00231= 2: ny;
   g_tmp_vpoty_00014= g_vpoty(tmp_MinpackGL2_G_00230, tmp_MinpackGL2_G_00231);
   tmp_vpoty_00014= vpoty(tmp_MinpackGL2_G_00230, tmp_MinpackGL2_G_00231);
   g_tmp_MinpackGL2_G_00232= hy* g_tmp_vpoty_00014;
   tmp_MinpackGL2_G_00232= hy* tmp_vpoty_00014;
   g_tmp_sin_00011= g_tmp_MinpackGL2_G_00232.* cos(tmp_MinpackGL2_G_00232);
   tmp_sin_00011= sin(tmp_MinpackGL2_G_00232);
   g_tmp_MinpackGL2_G_00233= g_tmp_MinpackGL2_G_00229.* tmp_sin_00011+ tmp_MinpackGL2_G_00229.* g_tmp_sin_00011;
   tmp_MinpackGL2_G_00233= tmp_MinpackGL2_G_00229.* tmp_sin_00011;
   tmp_MinpackGL2_G_00234= 2: nx;
   tmp_MinpackGL2_G_00235= 2: ny;
   g_tmp_x_00016= g_x(tmp_MinpackGL2_G_00234, tmp_MinpackGL2_G_00235);
   tmp_x_00016= x(tmp_MinpackGL2_G_00234, tmp_MinpackGL2_G_00235);
   g_tmp_MinpackGL2_G_00236= hy* g_tmp_x_00016;
   tmp_MinpackGL2_G_00236= hy* tmp_x_00016;
   tmp_MinpackGL2_G_00237= 2: nx;
   tmp_MinpackGL2_G_00238= 2: ny;
   g_tmp_vpoty_00015= g_vpoty(tmp_MinpackGL2_G_00237, tmp_MinpackGL2_G_00238);
   tmp_vpoty_00015= vpoty(tmp_MinpackGL2_G_00237, tmp_MinpackGL2_G_00238);
   g_tmp_MinpackGL2_G_00239= hy* g_tmp_vpoty_00015;
   tmp_MinpackGL2_G_00239= hy* tmp_vpoty_00015;
   g_tmp_cos_00011= g_tmp_MinpackGL2_G_00239.* (-sin(tmp_MinpackGL2_G_00239));
   tmp_cos_00011= cos(tmp_MinpackGL2_G_00239);
   g_tmp_MinpackGL2_G_00240= g_tmp_MinpackGL2_G_00236.* tmp_cos_00011+ tmp_MinpackGL2_G_00236.* g_tmp_cos_00011;
   tmp_MinpackGL2_G_00240= tmp_MinpackGL2_G_00236.* tmp_cos_00011;
   g_tmp_MinpackGL2_G_00241= g_tmp_MinpackGL2_G_00233- g_tmp_MinpackGL2_G_00240;
   tmp_MinpackGL2_G_00241= tmp_MinpackGL2_G_00233- tmp_MinpackGL2_G_00240;
   g_tmp_MinpackGL2_G_00242= g_fkiny2.* tmp_MinpackGL2_G_00241+ fkiny2.* g_tmp_MinpackGL2_G_00241;
   tmp_MinpackGL2_G_00242= fkiny2.* tmp_MinpackGL2_G_00241;
   g_graday(2: nx, 2: ny)= g_tmp_MinpackGL2_G_00210+ g_tmp_MinpackGL2_G_00226+ g_tmp_MinpackGL2_G_00242;
   graday(2: nx, 2: ny)= tmp_MinpackGL2_G_00210+ tmp_MinpackGL2_G_00226+ tmp_MinpackGL2_G_00242; 
   tmp_MinpackGL2_G_00243= hx* hx* sqn;
   tmp_MinpackGL2_G_00244= 2/ tmp_MinpackGL2_G_00243;
   tmp_MinpackGL2_G_00245= 2: nx;
   tmp_MinpackGL2_G_00246= 2: ny;
   g_tmp_x_00017= g_x(tmp_MinpackGL2_G_00245, tmp_MinpackGL2_G_00246);
   tmp_x_00017= x(tmp_MinpackGL2_G_00245, tmp_MinpackGL2_G_00246);
   tmp_MinpackGL2_G_00247= nx- 1;
   tmp_MinpackGL2_G_00248= 1: tmp_MinpackGL2_G_00247;
   tmp_MinpackGL2_G_00249= 2: ny;
   g_tmp_x_00018= g_x(tmp_MinpackGL2_G_00248, tmp_MinpackGL2_G_00249);
   tmp_x_00018= x(tmp_MinpackGL2_G_00248, tmp_MinpackGL2_G_00249);
   tmp_MinpackGL2_G_00250= nx- 1;
   tmp_MinpackGL2_G_00251= 1: tmp_MinpackGL2_G_00250;
   tmp_MinpackGL2_G_00252= 2: ny;
   g_tmp_vpotx_00016= g_vpotx(tmp_MinpackGL2_G_00251, tmp_MinpackGL2_G_00252);
   tmp_vpotx_00016= vpotx(tmp_MinpackGL2_G_00251, tmp_MinpackGL2_G_00252);
   g_tmp_MinpackGL2_G_00253= hx* g_tmp_vpotx_00016;
   tmp_MinpackGL2_G_00253= hx* tmp_vpotx_00016;
   g_tmp_cos_00012= g_tmp_MinpackGL2_G_00253.* (-sin(tmp_MinpackGL2_G_00253));
   tmp_cos_00012= cos(tmp_MinpackGL2_G_00253);
   g_tmp_MinpackGL2_G_00254= g_tmp_x_00018.* tmp_cos_00012+ tmp_x_00018.* g_tmp_cos_00012;
   tmp_MinpackGL2_G_00254= tmp_x_00018.* tmp_cos_00012;
   tmp_MinpackGL2_G_00255= nx- 1;
   tmp_MinpackGL2_G_00256= 1: tmp_MinpackGL2_G_00255;
   tmp_MinpackGL2_G_00257= 2: ny;
   g_tmp_y_00016= g_y(tmp_MinpackGL2_G_00256, tmp_MinpackGL2_G_00257);
   tmp_y_00016= y(tmp_MinpackGL2_G_00256, tmp_MinpackGL2_G_00257);
   tmp_MinpackGL2_G_00258= nx- 1;
   tmp_MinpackGL2_G_00259= 1: tmp_MinpackGL2_G_00258;
   tmp_MinpackGL2_G_00260= 2: ny;
   g_tmp_vpotx_00017= g_vpotx(tmp_MinpackGL2_G_00259, tmp_MinpackGL2_G_00260);
   tmp_vpotx_00017= vpotx(tmp_MinpackGL2_G_00259, tmp_MinpackGL2_G_00260);
   g_tmp_MinpackGL2_G_00261= hx* g_tmp_vpotx_00017;
   tmp_MinpackGL2_G_00261= hx* tmp_vpotx_00017;
   g_tmp_sin_00012= g_tmp_MinpackGL2_G_00261.* cos(tmp_MinpackGL2_G_00261);
   tmp_sin_00012= sin(tmp_MinpackGL2_G_00261);
   g_tmp_MinpackGL2_G_00262= g_tmp_y_00016.* tmp_sin_00012+ tmp_y_00016.* g_tmp_sin_00012;
   tmp_MinpackGL2_G_00262= tmp_y_00016.* tmp_sin_00012;
   g_tmp_MinpackGL2_G_00263= g_tmp_x_00017- g_tmp_MinpackGL2_G_00254+ g_tmp_MinpackGL2_G_00262;
   tmp_MinpackGL2_G_00263= tmp_x_00017- tmp_MinpackGL2_G_00254+ tmp_MinpackGL2_G_00262;
   g_fkinx1= tmp_MinpackGL2_G_00244* g_tmp_MinpackGL2_G_00263;
   fkinx1= tmp_MinpackGL2_G_00244* tmp_MinpackGL2_G_00263; 
   tmp_MinpackGL2_G_00264= hx* hx* sqn;
   tmp_MinpackGL2_G_00265= 2/ tmp_MinpackGL2_G_00264;
   tmp_MinpackGL2_G_00266= 2: nx;
   tmp_MinpackGL2_G_00267= 2: ny;
   g_tmp_y_00017= g_y(tmp_MinpackGL2_G_00266, tmp_MinpackGL2_G_00267);
   tmp_y_00017= y(tmp_MinpackGL2_G_00266, tmp_MinpackGL2_G_00267);
   tmp_MinpackGL2_G_00268= nx- 1;
   tmp_MinpackGL2_G_00269= 1: tmp_MinpackGL2_G_00268;
   tmp_MinpackGL2_G_00270= 2: ny;
   g_tmp_y_00018= g_y(tmp_MinpackGL2_G_00269, tmp_MinpackGL2_G_00270);
   tmp_y_00018= y(tmp_MinpackGL2_G_00269, tmp_MinpackGL2_G_00270);
   tmp_MinpackGL2_G_00271= nx- 1;
   tmp_MinpackGL2_G_00272= 1: tmp_MinpackGL2_G_00271;
   tmp_MinpackGL2_G_00273= 2: ny;
   g_tmp_vpotx_00018= g_vpotx(tmp_MinpackGL2_G_00272, tmp_MinpackGL2_G_00273);
   tmp_vpotx_00018= vpotx(tmp_MinpackGL2_G_00272, tmp_MinpackGL2_G_00273);
   g_tmp_MinpackGL2_G_00274= hx* g_tmp_vpotx_00018;
   tmp_MinpackGL2_G_00274= hx* tmp_vpotx_00018;
   g_tmp_cos_00013= g_tmp_MinpackGL2_G_00274.* (-sin(tmp_MinpackGL2_G_00274));
   tmp_cos_00013= cos(tmp_MinpackGL2_G_00274);
   g_tmp_MinpackGL2_G_00275= g_tmp_y_00018.* tmp_cos_00013+ tmp_y_00018.* g_tmp_cos_00013;
   tmp_MinpackGL2_G_00275= tmp_y_00018.* tmp_cos_00013;
   tmp_MinpackGL2_G_00276= nx- 1;
   tmp_MinpackGL2_G_00277= 1: tmp_MinpackGL2_G_00276;
   tmp_MinpackGL2_G_00278= 2: ny;
   g_tmp_x_00019= g_x(tmp_MinpackGL2_G_00277, tmp_MinpackGL2_G_00278);
   tmp_x_00019= x(tmp_MinpackGL2_G_00277, tmp_MinpackGL2_G_00278);
   tmp_MinpackGL2_G_00279= nx- 1;
   tmp_MinpackGL2_G_00280= 1: tmp_MinpackGL2_G_00279;
   tmp_MinpackGL2_G_00281= 2: ny;
   g_tmp_vpotx_00019= g_vpotx(tmp_MinpackGL2_G_00280, tmp_MinpackGL2_G_00281);
   tmp_vpotx_00019= vpotx(tmp_MinpackGL2_G_00280, tmp_MinpackGL2_G_00281);
   g_tmp_MinpackGL2_G_00282= hx* g_tmp_vpotx_00019;
   tmp_MinpackGL2_G_00282= hx* tmp_vpotx_00019;
   g_tmp_sin_00013= g_tmp_MinpackGL2_G_00282.* cos(tmp_MinpackGL2_G_00282);
   tmp_sin_00013= sin(tmp_MinpackGL2_G_00282);
   g_tmp_MinpackGL2_G_00283= g_tmp_x_00019.* tmp_sin_00013+ tmp_x_00019.* g_tmp_sin_00013;
   tmp_MinpackGL2_G_00283= tmp_x_00019.* tmp_sin_00013;
   g_tmp_MinpackGL2_G_00284= g_tmp_y_00017- g_tmp_MinpackGL2_G_00275- g_tmp_MinpackGL2_G_00283;
   tmp_MinpackGL2_G_00284= tmp_y_00017- tmp_MinpackGL2_G_00275- tmp_MinpackGL2_G_00283;
   g_fkinx2= tmp_MinpackGL2_G_00265* g_tmp_MinpackGL2_G_00284;
   fkinx2= tmp_MinpackGL2_G_00265* tmp_MinpackGL2_G_00284; 
   tmp_MinpackGL2_G_00285= hy* hy* sqn;
   tmp_MinpackGL2_G_00286= 2/ tmp_MinpackGL2_G_00285;
   tmp_MinpackGL2_G_00287= 2: nx;
   tmp_MinpackGL2_G_00288= 2: ny;
   g_tmp_x_00020= g_x(tmp_MinpackGL2_G_00287, tmp_MinpackGL2_G_00288);
   tmp_x_00020= x(tmp_MinpackGL2_G_00287, tmp_MinpackGL2_G_00288);
   tmp_MinpackGL2_G_00289= 2: nx;
   tmp_MinpackGL2_G_00290= ny- 1;
   tmp_MinpackGL2_G_00291= 1: tmp_MinpackGL2_G_00290;
   g_tmp_x_00021= g_x(tmp_MinpackGL2_G_00289, tmp_MinpackGL2_G_00291);
   tmp_x_00021= x(tmp_MinpackGL2_G_00289, tmp_MinpackGL2_G_00291);
   tmp_MinpackGL2_G_00292= 2: nx;
   tmp_MinpackGL2_G_00293= ny- 1;
   tmp_MinpackGL2_G_00294= 1: tmp_MinpackGL2_G_00293;
   g_tmp_vpoty_00016= g_vpoty(tmp_MinpackGL2_G_00292, tmp_MinpackGL2_G_00294);
   tmp_vpoty_00016= vpoty(tmp_MinpackGL2_G_00292, tmp_MinpackGL2_G_00294);
   g_tmp_MinpackGL2_G_00295= hy* g_tmp_vpoty_00016;
   tmp_MinpackGL2_G_00295= hy* tmp_vpoty_00016;
   g_tmp_cos_00014= g_tmp_MinpackGL2_G_00295.* (-sin(tmp_MinpackGL2_G_00295));
   tmp_cos_00014= cos(tmp_MinpackGL2_G_00295);
   g_tmp_MinpackGL2_G_00296= g_tmp_x_00021.* tmp_cos_00014+ tmp_x_00021.* g_tmp_cos_00014;
   tmp_MinpackGL2_G_00296= tmp_x_00021.* tmp_cos_00014;
   tmp_MinpackGL2_G_00297= 2: nx;
   tmp_MinpackGL2_G_00298= ny- 1;
   tmp_MinpackGL2_G_00299= 1: tmp_MinpackGL2_G_00298;
   g_tmp_y_00019= g_y(tmp_MinpackGL2_G_00297, tmp_MinpackGL2_G_00299);
   tmp_y_00019= y(tmp_MinpackGL2_G_00297, tmp_MinpackGL2_G_00299);
   tmp_MinpackGL2_G_00300= 2: nx;
   tmp_MinpackGL2_G_00301= ny- 1;
   tmp_MinpackGL2_G_00302= 1: tmp_MinpackGL2_G_00301;
   g_tmp_vpoty_00017= g_vpoty(tmp_MinpackGL2_G_00300, tmp_MinpackGL2_G_00302);
   tmp_vpoty_00017= vpoty(tmp_MinpackGL2_G_00300, tmp_MinpackGL2_G_00302);
   g_tmp_MinpackGL2_G_00303= hy* g_tmp_vpoty_00017;
   tmp_MinpackGL2_G_00303= hy* tmp_vpoty_00017;
   g_tmp_sin_00014= g_tmp_MinpackGL2_G_00303.* cos(tmp_MinpackGL2_G_00303);
   tmp_sin_00014= sin(tmp_MinpackGL2_G_00303);
   g_tmp_MinpackGL2_G_00304= g_tmp_y_00019.* tmp_sin_00014+ tmp_y_00019.* g_tmp_sin_00014;
   tmp_MinpackGL2_G_00304= tmp_y_00019.* tmp_sin_00014;
   g_tmp_MinpackGL2_G_00305= g_tmp_x_00020- g_tmp_MinpackGL2_G_00296+ g_tmp_MinpackGL2_G_00304;
   tmp_MinpackGL2_G_00305= tmp_x_00020- tmp_MinpackGL2_G_00296+ tmp_MinpackGL2_G_00304;
   g_fkiny1= tmp_MinpackGL2_G_00286* g_tmp_MinpackGL2_G_00305;
   fkiny1= tmp_MinpackGL2_G_00286* tmp_MinpackGL2_G_00305; 
   tmp_MinpackGL2_G_00306= hy* hy* sqn;
   tmp_MinpackGL2_G_00307= 2/ tmp_MinpackGL2_G_00306;
   tmp_MinpackGL2_G_00308= 2: nx;
   tmp_MinpackGL2_G_00309= 2: ny;
   g_tmp_y_00020= g_y(tmp_MinpackGL2_G_00308, tmp_MinpackGL2_G_00309);
   tmp_y_00020= y(tmp_MinpackGL2_G_00308, tmp_MinpackGL2_G_00309);
   tmp_MinpackGL2_G_00310= 2: nx;
   tmp_MinpackGL2_G_00311= ny- 1;
   tmp_MinpackGL2_G_00312= 1: tmp_MinpackGL2_G_00311;
   g_tmp_y_00021= g_y(tmp_MinpackGL2_G_00310, tmp_MinpackGL2_G_00312);
   tmp_y_00021= y(tmp_MinpackGL2_G_00310, tmp_MinpackGL2_G_00312);
   tmp_MinpackGL2_G_00313= 2: nx;
   tmp_MinpackGL2_G_00314= ny- 1;
   tmp_MinpackGL2_G_00315= 1: tmp_MinpackGL2_G_00314;
   g_tmp_vpoty_00018= g_vpoty(tmp_MinpackGL2_G_00313, tmp_MinpackGL2_G_00315);
   tmp_vpoty_00018= vpoty(tmp_MinpackGL2_G_00313, tmp_MinpackGL2_G_00315);
   g_tmp_MinpackGL2_G_00316= hy* g_tmp_vpoty_00018;
   tmp_MinpackGL2_G_00316= hy* tmp_vpoty_00018;
   g_tmp_cos_00015= g_tmp_MinpackGL2_G_00316.* (-sin(tmp_MinpackGL2_G_00316));
   tmp_cos_00015= cos(tmp_MinpackGL2_G_00316);
   g_tmp_MinpackGL2_G_00317= g_tmp_y_00021.* tmp_cos_00015+ tmp_y_00021.* g_tmp_cos_00015;
   tmp_MinpackGL2_G_00317= tmp_y_00021.* tmp_cos_00015;
   tmp_MinpackGL2_G_00318= 2: nx;
   tmp_MinpackGL2_G_00319= ny- 1;
   tmp_MinpackGL2_G_00320= 1: tmp_MinpackGL2_G_00319;
   g_tmp_x_00022= g_x(tmp_MinpackGL2_G_00318, tmp_MinpackGL2_G_00320);
   tmp_x_00022= x(tmp_MinpackGL2_G_00318, tmp_MinpackGL2_G_00320);
   tmp_MinpackGL2_G_00321= 2: nx;
   tmp_MinpackGL2_G_00322= ny- 1;
   tmp_MinpackGL2_G_00323= 1: tmp_MinpackGL2_G_00322;
   g_tmp_vpoty_00019= g_vpoty(tmp_MinpackGL2_G_00321, tmp_MinpackGL2_G_00323);
   tmp_vpoty_00019= vpoty(tmp_MinpackGL2_G_00321, tmp_MinpackGL2_G_00323);
   g_tmp_MinpackGL2_G_00324= hy* g_tmp_vpoty_00019;
   tmp_MinpackGL2_G_00324= hy* tmp_vpoty_00019;
   g_tmp_sin_00015= g_tmp_MinpackGL2_G_00324.* cos(tmp_MinpackGL2_G_00324);
   tmp_sin_00015= sin(tmp_MinpackGL2_G_00324);
   g_tmp_MinpackGL2_G_00325= g_tmp_x_00022.* tmp_sin_00015+ tmp_x_00022.* g_tmp_sin_00015;
   tmp_MinpackGL2_G_00325= tmp_x_00022.* tmp_sin_00015;
   g_tmp_MinpackGL2_G_00326= g_tmp_y_00020- g_tmp_MinpackGL2_G_00317- g_tmp_MinpackGL2_G_00325;
   tmp_MinpackGL2_G_00326= tmp_y_00020- tmp_MinpackGL2_G_00317- tmp_MinpackGL2_G_00325;
   g_fkiny2= tmp_MinpackGL2_G_00307* g_tmp_MinpackGL2_G_00326;
   fkiny2= tmp_MinpackGL2_G_00307* tmp_MinpackGL2_G_00326; 
   tmp_MinpackGL2_G_00327= 2: nx;
   tmp_MinpackGL2_G_00328= 2: ny;
   g_tmp_gradx_00001= g_gradx(tmp_MinpackGL2_G_00327, tmp_MinpackGL2_G_00328);
   tmp_gradx_00001= gradx(tmp_MinpackGL2_G_00327, tmp_MinpackGL2_G_00328);
   g_gradx(2: nx, 2: ny)= g_tmp_gradx_00001+ g_fkinx1+ g_fkiny1;
   gradx(2: nx, 2: ny)= tmp_gradx_00001+ fkinx1+ fkiny1; 
   tmp_MinpackGL2_G_00329= 2: nx;
   tmp_MinpackGL2_G_00330= 2: ny;
   g_tmp_grady_00001= g_grady(tmp_MinpackGL2_G_00329, tmp_MinpackGL2_G_00330);
   tmp_grady_00001= grady(tmp_MinpackGL2_G_00329, tmp_MinpackGL2_G_00330);
   g_grady(2: nx, 2: ny)= g_tmp_grady_00001+ g_fkinx2+ g_fkiny2;
   grady(2: nx, 2: ny)= tmp_grady_00001+ fkinx2+ fkiny2; 
   tmp_MinpackGL2_G_00331= 2: nx;
   tmp_MinpackGL2_G_00332= ny- 1;
   tmp_MinpackGL2_G_00333= 1: tmp_MinpackGL2_G_00332;
   g_tmp_vpotx_00020= g_vpotx(tmp_MinpackGL2_G_00331, tmp_MinpackGL2_G_00333);
   tmp_vpotx_00020= vpotx(tmp_MinpackGL2_G_00331, tmp_MinpackGL2_G_00333);
   tmp_MinpackGL2_G_00334= 2: nx;
   tmp_MinpackGL2_G_00335= 2: ny;
   g_tmp_vpotx_00021= g_vpotx(tmp_MinpackGL2_G_00334, tmp_MinpackGL2_G_00335);
   tmp_vpotx_00021= vpotx(tmp_MinpackGL2_G_00334, tmp_MinpackGL2_G_00335);
   g_tmp_MinpackGL2_G_00336= g_tmp_vpotx_00020- g_tmp_vpotx_00021;
   tmp_MinpackGL2_G_00336= tmp_vpotx_00020- tmp_vpotx_00021;
   g_tmp_MinpackGL2_G_00337= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00336), (tmp_MinpackGL2_G_00336), hy);
   tmp_MinpackGL2_G_00337= tmp_MinpackGL2_G_00336/ hy;
   tmp_MinpackGL2_G_00338= nx+ 1;
   tmp_MinpackGL2_G_00339= 3: tmp_MinpackGL2_G_00338;
   tmp_MinpackGL2_G_00340= ny- 1;
   tmp_MinpackGL2_G_00341= 1: tmp_MinpackGL2_G_00340;
   g_tmp_vpoty_00020= g_vpoty(tmp_MinpackGL2_G_00339, tmp_MinpackGL2_G_00341);
   tmp_vpoty_00020= vpoty(tmp_MinpackGL2_G_00339, tmp_MinpackGL2_G_00341);
   tmp_MinpackGL2_G_00342= 2: nx;
   tmp_MinpackGL2_G_00343= ny- 1;
   tmp_MinpackGL2_G_00344= 1: tmp_MinpackGL2_G_00343;
   g_tmp_vpoty_00021= g_vpoty(tmp_MinpackGL2_G_00342, tmp_MinpackGL2_G_00344);
   tmp_vpoty_00021= vpoty(tmp_MinpackGL2_G_00342, tmp_MinpackGL2_G_00344);
   g_tmp_MinpackGL2_G_00345= g_tmp_vpoty_00020- g_tmp_vpoty_00021;
   tmp_MinpackGL2_G_00345= tmp_vpoty_00020- tmp_vpoty_00021;
   g_tmp_MinpackGL2_G_00346= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00345), (tmp_MinpackGL2_G_00345), hx);
   tmp_MinpackGL2_G_00346= tmp_MinpackGL2_G_00345/ hx;
   g_tmp_MinpackGL2_G_00347= g_tmp_MinpackGL2_G_00337+ g_tmp_MinpackGL2_G_00346;
   tmp_MinpackGL2_G_00347= tmp_MinpackGL2_G_00337+ tmp_MinpackGL2_G_00346;
   tmp_MinpackGL2_G_00348= tkappa^ 2;
   tmp_MinpackGL2_G_00349= 2* tmp_MinpackGL2_G_00348;
   tmp_MinpackGL2_G_00350= tmp_MinpackGL2_G_00349/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00347* tmp_MinpackGL2_G_00350;
   ffield= tmp_MinpackGL2_G_00347* tmp_MinpackGL2_G_00350; 
   tmp_MinpackGL2_G_00351= 2: nx;
   tmp_MinpackGL2_G_00352= 2: ny;
   g_tmp_gradax_00000= g_gradax(tmp_MinpackGL2_G_00351, tmp_MinpackGL2_G_00352);
   tmp_gradax_00000= gradax(tmp_MinpackGL2_G_00351, tmp_MinpackGL2_G_00352);
   g_tmp_MinpackGL2_G_00353= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00353= ffield/ hy;
   g_gradax(2: nx, 2: ny)= g_tmp_gradax_00000- g_tmp_MinpackGL2_G_00353;
   gradax(2: nx, 2: ny)= tmp_gradax_00000- tmp_MinpackGL2_G_00353; 
   tmp_MinpackGL2_G_00354= nx- 1;
   tmp_MinpackGL2_G_00355= 1: tmp_MinpackGL2_G_00354;
   tmp_MinpackGL2_G_00356= 2: ny;
   g_tmp_vpotx_00022= g_vpotx(tmp_MinpackGL2_G_00355, tmp_MinpackGL2_G_00356);
   tmp_vpotx_00022= vpotx(tmp_MinpackGL2_G_00355, tmp_MinpackGL2_G_00356);
   tmp_MinpackGL2_G_00357= nx- 1;
   tmp_MinpackGL2_G_00358= 1: tmp_MinpackGL2_G_00357;
   tmp_MinpackGL2_G_00359= ny+ 1;
   tmp_MinpackGL2_G_00360= 3: tmp_MinpackGL2_G_00359;
   g_tmp_vpotx_00023= g_vpotx(tmp_MinpackGL2_G_00358, tmp_MinpackGL2_G_00360);
   tmp_vpotx_00023= vpotx(tmp_MinpackGL2_G_00358, tmp_MinpackGL2_G_00360);
   g_tmp_MinpackGL2_G_00361= g_tmp_vpotx_00022- g_tmp_vpotx_00023;
   tmp_MinpackGL2_G_00361= tmp_vpotx_00022- tmp_vpotx_00023;
   g_tmp_MinpackGL2_G_00362= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00361), (tmp_MinpackGL2_G_00361), hy);
   tmp_MinpackGL2_G_00362= tmp_MinpackGL2_G_00361/ hy;
   tmp_MinpackGL2_G_00363= 2: nx;
   tmp_MinpackGL2_G_00364= 2: ny;
   g_tmp_vpoty_00022= g_vpoty(tmp_MinpackGL2_G_00363, tmp_MinpackGL2_G_00364);
   tmp_vpoty_00022= vpoty(tmp_MinpackGL2_G_00363, tmp_MinpackGL2_G_00364);
   tmp_MinpackGL2_G_00365= nx- 1;
   tmp_MinpackGL2_G_00366= 1: tmp_MinpackGL2_G_00365;
   tmp_MinpackGL2_G_00367= 2: ny;
   g_tmp_vpoty_00023= g_vpoty(tmp_MinpackGL2_G_00366, tmp_MinpackGL2_G_00367);
   tmp_vpoty_00023= vpoty(tmp_MinpackGL2_G_00366, tmp_MinpackGL2_G_00367);
   g_tmp_MinpackGL2_G_00368= g_tmp_vpoty_00022- g_tmp_vpoty_00023;
   tmp_MinpackGL2_G_00368= tmp_vpoty_00022- tmp_vpoty_00023;
   g_tmp_MinpackGL2_G_00369= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00368), (tmp_MinpackGL2_G_00368), hx);
   tmp_MinpackGL2_G_00369= tmp_MinpackGL2_G_00368/ hx;
   g_tmp_MinpackGL2_G_00370= g_tmp_MinpackGL2_G_00362+ g_tmp_MinpackGL2_G_00369;
   tmp_MinpackGL2_G_00370= tmp_MinpackGL2_G_00362+ tmp_MinpackGL2_G_00369;
   tmp_MinpackGL2_G_00371= tkappa^ 2;
   tmp_MinpackGL2_G_00372= 2* tmp_MinpackGL2_G_00371;
   tmp_MinpackGL2_G_00373= tmp_MinpackGL2_G_00372/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00370* tmp_MinpackGL2_G_00373;
   ffield= tmp_MinpackGL2_G_00370* tmp_MinpackGL2_G_00373; 
   tmp_MinpackGL2_G_00374= 2: nx;
   tmp_MinpackGL2_G_00375= 2: ny;
   g_tmp_graday_00000= g_graday(tmp_MinpackGL2_G_00374, tmp_MinpackGL2_G_00375);
   tmp_graday_00000= graday(tmp_MinpackGL2_G_00374, tmp_MinpackGL2_G_00375);
   g_tmp_MinpackGL2_G_00376= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00376= ffield/ hx;
   g_graday(2: nx, 2: ny)= g_tmp_graday_00000+ g_tmp_MinpackGL2_G_00376;
   graday(2: nx, 2: ny)= tmp_graday_00000+ tmp_MinpackGL2_G_00376; 
   
   %    Kinetic Energy Part, Boundary Points.
   
   %    Bottom J = 1
   tmp_MinpackGL2_G_00377= hx* hx* sqn;
   tmp_MinpackGL2_G_00378= 2/ tmp_MinpackGL2_G_00377;
   tmp_MinpackGL2_G_00379= nx+ 1;
   tmp_MinpackGL2_G_00380= 3: tmp_MinpackGL2_G_00379;
   g_tmp_x_00023= g_x(tmp_MinpackGL2_G_00380, 1);
   tmp_x_00023= x(tmp_MinpackGL2_G_00380, 1);
   tmp_MinpackGL2_G_00381= 2: nx;
   g_tmp_x_00024= g_x(tmp_MinpackGL2_G_00381, 1);
   tmp_x_00024= x(tmp_MinpackGL2_G_00381, 1);
   tmp_MinpackGL2_G_00382= 2: nx;
   g_tmp_vpotx_00024= g_vpotx(tmp_MinpackGL2_G_00382, 1);
   tmp_vpotx_00024= vpotx(tmp_MinpackGL2_G_00382, 1);
   g_tmp_MinpackGL2_G_00383= hx* g_tmp_vpotx_00024;
   tmp_MinpackGL2_G_00383= hx* tmp_vpotx_00024;
   g_tmp_cos_00016= g_tmp_MinpackGL2_G_00383.* (-sin(tmp_MinpackGL2_G_00383));
   tmp_cos_00016= cos(tmp_MinpackGL2_G_00383);
   g_tmp_MinpackGL2_G_00384= g_tmp_x_00024.* tmp_cos_00016+ tmp_x_00024.* g_tmp_cos_00016;
   tmp_MinpackGL2_G_00384= tmp_x_00024.* tmp_cos_00016;
   tmp_MinpackGL2_G_00385= 2: nx;
   g_tmp_y_00022= g_y(tmp_MinpackGL2_G_00385, 1);
   tmp_y_00022= y(tmp_MinpackGL2_G_00385, 1);
   tmp_MinpackGL2_G_00386= 2: nx;
   g_tmp_vpotx_00025= g_vpotx(tmp_MinpackGL2_G_00386, 1);
   tmp_vpotx_00025= vpotx(tmp_MinpackGL2_G_00386, 1);
   g_tmp_MinpackGL2_G_00387= hx* g_tmp_vpotx_00025;
   tmp_MinpackGL2_G_00387= hx* tmp_vpotx_00025;
   g_tmp_sin_00016= g_tmp_MinpackGL2_G_00387.* cos(tmp_MinpackGL2_G_00387);
   tmp_sin_00016= sin(tmp_MinpackGL2_G_00387);
   g_tmp_MinpackGL2_G_00388= g_tmp_y_00022.* tmp_sin_00016+ tmp_y_00022.* g_tmp_sin_00016;
   tmp_MinpackGL2_G_00388= tmp_y_00022.* tmp_sin_00016;
   g_tmp_MinpackGL2_G_00389= g_tmp_x_00023- g_tmp_MinpackGL2_G_00384+ g_tmp_MinpackGL2_G_00388;
   tmp_MinpackGL2_G_00389= tmp_x_00023- tmp_MinpackGL2_G_00384+ tmp_MinpackGL2_G_00388;
   g_fkinx1= tmp_MinpackGL2_G_00378* g_tmp_MinpackGL2_G_00389;
   fkinx1= tmp_MinpackGL2_G_00378* tmp_MinpackGL2_G_00389; 
   tmp_MinpackGL2_G_00390= hx* hx* sqn;
   tmp_MinpackGL2_G_00391= 2/ tmp_MinpackGL2_G_00390;
   tmp_MinpackGL2_G_00392= nx+ 1;
   tmp_MinpackGL2_G_00393= 3: tmp_MinpackGL2_G_00392;
   g_tmp_y_00023= g_y(tmp_MinpackGL2_G_00393, 1);
   tmp_y_00023= y(tmp_MinpackGL2_G_00393, 1);
   tmp_MinpackGL2_G_00394= 2: nx;
   g_tmp_y_00024= g_y(tmp_MinpackGL2_G_00394, 1);
   tmp_y_00024= y(tmp_MinpackGL2_G_00394, 1);
   tmp_MinpackGL2_G_00395= 2: nx;
   g_tmp_vpotx_00026= g_vpotx(tmp_MinpackGL2_G_00395, 1);
   tmp_vpotx_00026= vpotx(tmp_MinpackGL2_G_00395, 1);
   g_tmp_MinpackGL2_G_00396= hx* g_tmp_vpotx_00026;
   tmp_MinpackGL2_G_00396= hx* tmp_vpotx_00026;
   g_tmp_cos_00017= g_tmp_MinpackGL2_G_00396.* (-sin(tmp_MinpackGL2_G_00396));
   tmp_cos_00017= cos(tmp_MinpackGL2_G_00396);
   g_tmp_MinpackGL2_G_00397= g_tmp_y_00024.* tmp_cos_00017+ tmp_y_00024.* g_tmp_cos_00017;
   tmp_MinpackGL2_G_00397= tmp_y_00024.* tmp_cos_00017;
   tmp_MinpackGL2_G_00398= 2: nx;
   g_tmp_x_00025= g_x(tmp_MinpackGL2_G_00398, 1);
   tmp_x_00025= x(tmp_MinpackGL2_G_00398, 1);
   tmp_MinpackGL2_G_00399= 2: nx;
   g_tmp_vpotx_00027= g_vpotx(tmp_MinpackGL2_G_00399, 1);
   tmp_vpotx_00027= vpotx(tmp_MinpackGL2_G_00399, 1);
   g_tmp_MinpackGL2_G_00400= hx* g_tmp_vpotx_00027;
   tmp_MinpackGL2_G_00400= hx* tmp_vpotx_00027;
   g_tmp_sin_00017= g_tmp_MinpackGL2_G_00400.* cos(tmp_MinpackGL2_G_00400);
   tmp_sin_00017= sin(tmp_MinpackGL2_G_00400);
   g_tmp_MinpackGL2_G_00401= g_tmp_x_00025.* tmp_sin_00017+ tmp_x_00025.* g_tmp_sin_00017;
   tmp_MinpackGL2_G_00401= tmp_x_00025.* tmp_sin_00017;
   g_tmp_MinpackGL2_G_00402= g_tmp_y_00023- g_tmp_MinpackGL2_G_00397- g_tmp_MinpackGL2_G_00401;
   tmp_MinpackGL2_G_00402= tmp_y_00023- tmp_MinpackGL2_G_00397- tmp_MinpackGL2_G_00401;
   g_fkinx2= tmp_MinpackGL2_G_00391* g_tmp_MinpackGL2_G_00402;
   fkinx2= tmp_MinpackGL2_G_00391* tmp_MinpackGL2_G_00402; 
   tmp_MinpackGL2_G_00403= hy* hy* sqn;
   tmp_MinpackGL2_G_00404= 2/ tmp_MinpackGL2_G_00403;
   tmp_MinpackGL2_G_00405= 2: nx;
   g_tmp_x_00026= g_x(tmp_MinpackGL2_G_00405, 2);
   tmp_x_00026= x(tmp_MinpackGL2_G_00405, 2);
   tmp_MinpackGL2_G_00406= 2: nx;
   g_tmp_x_00027= g_x(tmp_MinpackGL2_G_00406, 1);
   tmp_x_00027= x(tmp_MinpackGL2_G_00406, 1);
   tmp_MinpackGL2_G_00407= 2: nx;
   g_tmp_vpoty_00024= g_vpoty(tmp_MinpackGL2_G_00407, 1);
   tmp_vpoty_00024= vpoty(tmp_MinpackGL2_G_00407, 1);
   g_tmp_MinpackGL2_G_00408= hy* g_tmp_vpoty_00024;
   tmp_MinpackGL2_G_00408= hy* tmp_vpoty_00024;
   g_tmp_cos_00018= g_tmp_MinpackGL2_G_00408.* (-sin(tmp_MinpackGL2_G_00408));
   tmp_cos_00018= cos(tmp_MinpackGL2_G_00408);
   g_tmp_MinpackGL2_G_00409= g_tmp_x_00027.* tmp_cos_00018+ tmp_x_00027.* g_tmp_cos_00018;
   tmp_MinpackGL2_G_00409= tmp_x_00027.* tmp_cos_00018;
   tmp_MinpackGL2_G_00410= 2: nx;
   g_tmp_y_00025= g_y(tmp_MinpackGL2_G_00410, 1);
   tmp_y_00025= y(tmp_MinpackGL2_G_00410, 1);
   tmp_MinpackGL2_G_00411= 2: nx;
   g_tmp_vpoty_00025= g_vpoty(tmp_MinpackGL2_G_00411, 1);
   tmp_vpoty_00025= vpoty(tmp_MinpackGL2_G_00411, 1);
   g_tmp_MinpackGL2_G_00412= hy* g_tmp_vpoty_00025;
   tmp_MinpackGL2_G_00412= hy* tmp_vpoty_00025;
   g_tmp_sin_00018= g_tmp_MinpackGL2_G_00412.* cos(tmp_MinpackGL2_G_00412);
   tmp_sin_00018= sin(tmp_MinpackGL2_G_00412);
   g_tmp_MinpackGL2_G_00413= g_tmp_y_00025.* tmp_sin_00018+ tmp_y_00025.* g_tmp_sin_00018;
   tmp_MinpackGL2_G_00413= tmp_y_00025.* tmp_sin_00018;
   g_tmp_MinpackGL2_G_00414= g_tmp_x_00026- g_tmp_MinpackGL2_G_00409+ g_tmp_MinpackGL2_G_00413;
   tmp_MinpackGL2_G_00414= tmp_x_00026- tmp_MinpackGL2_G_00409+ tmp_MinpackGL2_G_00413;
   g_fkiny1= tmp_MinpackGL2_G_00404* g_tmp_MinpackGL2_G_00414;
   fkiny1= tmp_MinpackGL2_G_00404* tmp_MinpackGL2_G_00414; 
   tmp_MinpackGL2_G_00415= hy* hy* sqn;
   tmp_MinpackGL2_G_00416= 2/ tmp_MinpackGL2_G_00415;
   tmp_MinpackGL2_G_00417= 2: nx;
   g_tmp_y_00026= g_y(tmp_MinpackGL2_G_00417, 2);
   tmp_y_00026= y(tmp_MinpackGL2_G_00417, 2);
   tmp_MinpackGL2_G_00418= 2: nx;
   g_tmp_y_00027= g_y(tmp_MinpackGL2_G_00418, 1);
   tmp_y_00027= y(tmp_MinpackGL2_G_00418, 1);
   tmp_MinpackGL2_G_00419= 2: nx;
   g_tmp_vpoty_00026= g_vpoty(tmp_MinpackGL2_G_00419, 1);
   tmp_vpoty_00026= vpoty(tmp_MinpackGL2_G_00419, 1);
   g_tmp_MinpackGL2_G_00420= hy* g_tmp_vpoty_00026;
   tmp_MinpackGL2_G_00420= hy* tmp_vpoty_00026;
   g_tmp_cos_00019= g_tmp_MinpackGL2_G_00420.* (-sin(tmp_MinpackGL2_G_00420));
   tmp_cos_00019= cos(tmp_MinpackGL2_G_00420);
   g_tmp_MinpackGL2_G_00421= g_tmp_y_00027.* tmp_cos_00019+ tmp_y_00027.* g_tmp_cos_00019;
   tmp_MinpackGL2_G_00421= tmp_y_00027.* tmp_cos_00019;
   tmp_MinpackGL2_G_00422= 2: nx;
   g_tmp_x_00028= g_x(tmp_MinpackGL2_G_00422, 1);
   tmp_x_00028= x(tmp_MinpackGL2_G_00422, 1);
   tmp_MinpackGL2_G_00423= 2: nx;
   g_tmp_vpoty_00027= g_vpoty(tmp_MinpackGL2_G_00423, 1);
   tmp_vpoty_00027= vpoty(tmp_MinpackGL2_G_00423, 1);
   g_tmp_MinpackGL2_G_00424= hy* g_tmp_vpoty_00027;
   tmp_MinpackGL2_G_00424= hy* tmp_vpoty_00027;
   g_tmp_sin_00019= g_tmp_MinpackGL2_G_00424.* cos(tmp_MinpackGL2_G_00424);
   tmp_sin_00019= sin(tmp_MinpackGL2_G_00424);
   g_tmp_MinpackGL2_G_00425= g_tmp_x_00028.* tmp_sin_00019+ tmp_x_00028.* g_tmp_sin_00019;
   tmp_MinpackGL2_G_00425= tmp_x_00028.* tmp_sin_00019;
   g_tmp_MinpackGL2_G_00426= g_tmp_y_00026- g_tmp_MinpackGL2_G_00421- g_tmp_MinpackGL2_G_00425;
   tmp_MinpackGL2_G_00426= tmp_y_00026- tmp_MinpackGL2_G_00421- tmp_MinpackGL2_G_00425;
   g_fkiny2= tmp_MinpackGL2_G_00416* g_tmp_MinpackGL2_G_00426;
   fkiny2= tmp_MinpackGL2_G_00416* tmp_MinpackGL2_G_00426; 
   tmp_MinpackGL2_G_00427= 2: nx;
   g_tmp_vpotx_00028= g_vpotx(tmp_MinpackGL2_G_00427, 1);
   tmp_vpotx_00028= vpotx(tmp_MinpackGL2_G_00427, 1);
   tmp_MinpackGL2_G_00428= 2: nx;
   g_tmp_vpotx_00029= g_vpotx(tmp_MinpackGL2_G_00428, 2);
   tmp_vpotx_00029= vpotx(tmp_MinpackGL2_G_00428, 2);
   g_tmp_MinpackGL2_G_00429= g_tmp_vpotx_00028- g_tmp_vpotx_00029;
   tmp_MinpackGL2_G_00429= tmp_vpotx_00028- tmp_vpotx_00029;
   g_tmp_MinpackGL2_G_00430= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00429), (tmp_MinpackGL2_G_00429), hy);
   tmp_MinpackGL2_G_00430= tmp_MinpackGL2_G_00429/ hy;
   tmp_MinpackGL2_G_00431= nx+ 1;
   tmp_MinpackGL2_G_00432= 3: tmp_MinpackGL2_G_00431;
   g_tmp_vpoty_00028= g_vpoty(tmp_MinpackGL2_G_00432, 1);
   tmp_vpoty_00028= vpoty(tmp_MinpackGL2_G_00432, 1);
   tmp_MinpackGL2_G_00433= 2: nx;
   g_tmp_vpoty_00029= g_vpoty(tmp_MinpackGL2_G_00433, 1);
   tmp_vpoty_00029= vpoty(tmp_MinpackGL2_G_00433, 1);
   g_tmp_MinpackGL2_G_00434= g_tmp_vpoty_00028- g_tmp_vpoty_00029;
   tmp_MinpackGL2_G_00434= tmp_vpoty_00028- tmp_vpoty_00029;
   g_tmp_MinpackGL2_G_00435= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00434), (tmp_MinpackGL2_G_00434), hx);
   tmp_MinpackGL2_G_00435= tmp_MinpackGL2_G_00434/ hx;
   g_tmp_MinpackGL2_G_00436= g_tmp_MinpackGL2_G_00430+ g_tmp_MinpackGL2_G_00435;
   tmp_MinpackGL2_G_00436= tmp_MinpackGL2_G_00430+ tmp_MinpackGL2_G_00435;
   tmp_MinpackGL2_G_00437= tkappa^ 2;
   tmp_MinpackGL2_G_00438= 2* tmp_MinpackGL2_G_00437;
   tmp_MinpackGL2_G_00439= tmp_MinpackGL2_G_00438/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00436* tmp_MinpackGL2_G_00439;
   ffield= tmp_MinpackGL2_G_00436* tmp_MinpackGL2_G_00439; 
   tmp_MinpackGL2_G_00440= 2: nx;
   g_tmp_gradx_00002= g_gradx(tmp_MinpackGL2_G_00440, 1);
   tmp_gradx_00002= gradx(tmp_MinpackGL2_G_00440, 1);
   tmp_MinpackGL2_G_00441= 2: nx;
   g_tmp_vpotx_00030= g_vpotx(tmp_MinpackGL2_G_00441, 1);
   tmp_vpotx_00030= vpotx(tmp_MinpackGL2_G_00441, 1);
   g_tmp_MinpackGL2_G_00442= hx* g_tmp_vpotx_00030;
   tmp_MinpackGL2_G_00442= hx* tmp_vpotx_00030;
   g_tmp_cos_00020= g_tmp_MinpackGL2_G_00442.* (-sin(tmp_MinpackGL2_G_00442));
   tmp_cos_00020= cos(tmp_MinpackGL2_G_00442);
   g_tmp_MinpackGL2_G_00443= g_tmp_cos_00020.* fkinx1+ tmp_cos_00020.* g_fkinx1;
   tmp_MinpackGL2_G_00443= tmp_cos_00020.* fkinx1;
   tmp_MinpackGL2_G_00444= 2: nx;
   g_tmp_vpotx_00031= g_vpotx(tmp_MinpackGL2_G_00444, 1);
   tmp_vpotx_00031= vpotx(tmp_MinpackGL2_G_00444, 1);
   g_tmp_MinpackGL2_G_00445= hx* g_tmp_vpotx_00031;
   tmp_MinpackGL2_G_00445= hx* tmp_vpotx_00031;
   g_tmp_sin_00020= g_tmp_MinpackGL2_G_00445.* cos(tmp_MinpackGL2_G_00445);
   tmp_sin_00020= sin(tmp_MinpackGL2_G_00445);
   g_tmp_MinpackGL2_G_00446= g_tmp_sin_00020.* fkinx2+ tmp_sin_00020.* g_fkinx2;
   tmp_MinpackGL2_G_00446= tmp_sin_00020.* fkinx2;
   tmp_MinpackGL2_G_00447= 2: nx;
   g_tmp_vpoty_00030= g_vpoty(tmp_MinpackGL2_G_00447, 1);
   tmp_vpoty_00030= vpoty(tmp_MinpackGL2_G_00447, 1);
   g_tmp_MinpackGL2_G_00448= hy* g_tmp_vpoty_00030;
   tmp_MinpackGL2_G_00448= hy* tmp_vpoty_00030;
   g_tmp_cos_00021= g_tmp_MinpackGL2_G_00448.* (-sin(tmp_MinpackGL2_G_00448));
   tmp_cos_00021= cos(tmp_MinpackGL2_G_00448);
   g_tmp_MinpackGL2_G_00449= g_tmp_cos_00021.* fkiny1+ tmp_cos_00021.* g_fkiny1;
   tmp_MinpackGL2_G_00449= tmp_cos_00021.* fkiny1;
   tmp_MinpackGL2_G_00450= 2: nx;
   g_tmp_vpoty_00031= g_vpoty(tmp_MinpackGL2_G_00450, 1);
   tmp_vpoty_00031= vpoty(tmp_MinpackGL2_G_00450, 1);
   g_tmp_MinpackGL2_G_00451= hy* g_tmp_vpoty_00031;
   tmp_MinpackGL2_G_00451= hy* tmp_vpoty_00031;
   g_tmp_sin_00021= g_tmp_MinpackGL2_G_00451.* cos(tmp_MinpackGL2_G_00451);
   tmp_sin_00021= sin(tmp_MinpackGL2_G_00451);
   g_tmp_MinpackGL2_G_00452= g_tmp_sin_00021.* fkiny2+ tmp_sin_00021.* g_fkiny2;
   tmp_MinpackGL2_G_00452= tmp_sin_00021.* fkiny2;
   g_gradx(2: nx, 1)= g_tmp_gradx_00002- g_tmp_MinpackGL2_G_00443- g_tmp_MinpackGL2_G_00446- g_tmp_MinpackGL2_G_00449- g_tmp_MinpackGL2_G_00452;
   gradx(2: nx, 1)= tmp_gradx_00002- tmp_MinpackGL2_G_00443- tmp_MinpackGL2_G_00446- tmp_MinpackGL2_G_00449- tmp_MinpackGL2_G_00452; 
   tmp_MinpackGL2_G_00453= 2: nx;
   g_tmp_grady_00002= g_grady(tmp_MinpackGL2_G_00453, 1);
   tmp_grady_00002= grady(tmp_MinpackGL2_G_00453, 1);
   tmp_MinpackGL2_G_00454= 2: nx;
   g_tmp_vpotx_00032= g_vpotx(tmp_MinpackGL2_G_00454, 1);
   tmp_vpotx_00032= vpotx(tmp_MinpackGL2_G_00454, 1);
   g_tmp_MinpackGL2_G_00455= hx* g_tmp_vpotx_00032;
   tmp_MinpackGL2_G_00455= hx* tmp_vpotx_00032;
   g_tmp_sin_00022= g_tmp_MinpackGL2_G_00455.* cos(tmp_MinpackGL2_G_00455);
   tmp_sin_00022= sin(tmp_MinpackGL2_G_00455);
   g_tmp_MinpackGL2_G_00456= g_tmp_sin_00022.* fkinx1+ tmp_sin_00022.* g_fkinx1;
   tmp_MinpackGL2_G_00456= tmp_sin_00022.* fkinx1;
   tmp_MinpackGL2_G_00457= 2: nx;
   g_tmp_vpotx_00033= g_vpotx(tmp_MinpackGL2_G_00457, 1);
   tmp_vpotx_00033= vpotx(tmp_MinpackGL2_G_00457, 1);
   g_tmp_MinpackGL2_G_00458= hx* g_tmp_vpotx_00033;
   tmp_MinpackGL2_G_00458= hx* tmp_vpotx_00033;
   g_tmp_cos_00022= g_tmp_MinpackGL2_G_00458.* (-sin(tmp_MinpackGL2_G_00458));
   tmp_cos_00022= cos(tmp_MinpackGL2_G_00458);
   g_tmp_MinpackGL2_G_00459= g_tmp_cos_00022.* fkinx2+ tmp_cos_00022.* g_fkinx2;
   tmp_MinpackGL2_G_00459= tmp_cos_00022.* fkinx2;
   tmp_MinpackGL2_G_00460= 2: nx;
   g_tmp_vpoty_00032= g_vpoty(tmp_MinpackGL2_G_00460, 1);
   tmp_vpoty_00032= vpoty(tmp_MinpackGL2_G_00460, 1);
   g_tmp_MinpackGL2_G_00461= hy* g_tmp_vpoty_00032;
   tmp_MinpackGL2_G_00461= hy* tmp_vpoty_00032;
   g_tmp_sin_00023= g_tmp_MinpackGL2_G_00461.* cos(tmp_MinpackGL2_G_00461);
   tmp_sin_00023= sin(tmp_MinpackGL2_G_00461);
   g_tmp_MinpackGL2_G_00462= g_tmp_sin_00023.* fkiny1+ tmp_sin_00023.* g_fkiny1;
   tmp_MinpackGL2_G_00462= tmp_sin_00023.* fkiny1;
   tmp_MinpackGL2_G_00463= 2: nx;
   g_tmp_vpoty_00033= g_vpoty(tmp_MinpackGL2_G_00463, 1);
   tmp_vpoty_00033= vpoty(tmp_MinpackGL2_G_00463, 1);
   g_tmp_MinpackGL2_G_00464= hy* g_tmp_vpoty_00033;
   tmp_MinpackGL2_G_00464= hy* tmp_vpoty_00033;
   g_tmp_cos_00023= g_tmp_MinpackGL2_G_00464.* (-sin(tmp_MinpackGL2_G_00464));
   tmp_cos_00023= cos(tmp_MinpackGL2_G_00464);
   g_tmp_MinpackGL2_G_00465= g_tmp_cos_00023.* fkiny2+ tmp_cos_00023.* g_fkiny2;
   tmp_MinpackGL2_G_00465= tmp_cos_00023.* fkiny2;
   g_grady(2: nx, 1)= g_tmp_grady_00002+ g_tmp_MinpackGL2_G_00456- g_tmp_MinpackGL2_G_00459+ g_tmp_MinpackGL2_G_00462- g_tmp_MinpackGL2_G_00465;
   grady(2: nx, 1)= tmp_grady_00002+ tmp_MinpackGL2_G_00456- tmp_MinpackGL2_G_00459+ tmp_MinpackGL2_G_00462- tmp_MinpackGL2_G_00465; 
   tmp_MinpackGL2_G_00466= 2: nx;
   g_tmp_gradax_00001= g_gradax(tmp_MinpackGL2_G_00466, 1);
   tmp_gradax_00001= gradax(tmp_MinpackGL2_G_00466, 1);
   g_tmp_MinpackGL2_G_00467= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00467= ffield/ hy;
   tmp_MinpackGL2_G_00468= 2: nx;
   g_tmp_x_00029= g_x(tmp_MinpackGL2_G_00468, 1);
   tmp_x_00029= x(tmp_MinpackGL2_G_00468, 1);
   g_tmp_MinpackGL2_G_00469= hx* g_tmp_x_00029;
   tmp_MinpackGL2_G_00469= hx* tmp_x_00029;
   tmp_MinpackGL2_G_00470= 2: nx;
   g_tmp_vpotx_00034= g_vpotx(tmp_MinpackGL2_G_00470, 1);
   tmp_vpotx_00034= vpotx(tmp_MinpackGL2_G_00470, 1);
   g_tmp_MinpackGL2_G_00471= hx* g_tmp_vpotx_00034;
   tmp_MinpackGL2_G_00471= hx* tmp_vpotx_00034;
   g_tmp_sin_00024= g_tmp_MinpackGL2_G_00471.* cos(tmp_MinpackGL2_G_00471);
   tmp_sin_00024= sin(tmp_MinpackGL2_G_00471);
   g_tmp_MinpackGL2_G_00472= g_tmp_MinpackGL2_G_00469.* tmp_sin_00024+ tmp_MinpackGL2_G_00469.* g_tmp_sin_00024;
   tmp_MinpackGL2_G_00472= tmp_MinpackGL2_G_00469.* tmp_sin_00024;
   tmp_MinpackGL2_G_00473= 2: nx;
   g_tmp_y_00028= g_y(tmp_MinpackGL2_G_00473, 1);
   tmp_y_00028= y(tmp_MinpackGL2_G_00473, 1);
   g_tmp_MinpackGL2_G_00474= hx* g_tmp_y_00028;
   tmp_MinpackGL2_G_00474= hx* tmp_y_00028;
   tmp_MinpackGL2_G_00475= 2: nx;
   g_tmp_vpotx_00035= g_vpotx(tmp_MinpackGL2_G_00475, 1);
   tmp_vpotx_00035= vpotx(tmp_MinpackGL2_G_00475, 1);
   g_tmp_MinpackGL2_G_00476= hx* g_tmp_vpotx_00035;
   tmp_MinpackGL2_G_00476= hx* tmp_vpotx_00035;
   g_tmp_cos_00024= g_tmp_MinpackGL2_G_00476.* (-sin(tmp_MinpackGL2_G_00476));
   tmp_cos_00024= cos(tmp_MinpackGL2_G_00476);
   g_tmp_MinpackGL2_G_00477= g_tmp_MinpackGL2_G_00474.* tmp_cos_00024+ tmp_MinpackGL2_G_00474.* g_tmp_cos_00024;
   tmp_MinpackGL2_G_00477= tmp_MinpackGL2_G_00474.* tmp_cos_00024;
   g_tmp_MinpackGL2_G_00478= g_tmp_MinpackGL2_G_00472+ g_tmp_MinpackGL2_G_00477;
   tmp_MinpackGL2_G_00478= tmp_MinpackGL2_G_00472+ tmp_MinpackGL2_G_00477;
   g_tmp_MinpackGL2_G_00479= g_fkinx1.* tmp_MinpackGL2_G_00478+ fkinx1.* g_tmp_MinpackGL2_G_00478;
   tmp_MinpackGL2_G_00479= fkinx1.* tmp_MinpackGL2_G_00478;
   tmp_MinpackGL2_G_00480= 2: nx;
   g_tmp_y_00029= g_y(tmp_MinpackGL2_G_00480, 1);
   tmp_y_00029= y(tmp_MinpackGL2_G_00480, 1);
   g_tmp_MinpackGL2_G_00481= hx* g_tmp_y_00029;
   tmp_MinpackGL2_G_00481= hx* tmp_y_00029;
   tmp_MinpackGL2_G_00482= 2: nx;
   g_tmp_vpotx_00036= g_vpotx(tmp_MinpackGL2_G_00482, 1);
   tmp_vpotx_00036= vpotx(tmp_MinpackGL2_G_00482, 1);
   g_tmp_MinpackGL2_G_00483= hx* g_tmp_vpotx_00036;
   tmp_MinpackGL2_G_00483= hx* tmp_vpotx_00036;
   g_tmp_sin_00025= g_tmp_MinpackGL2_G_00483.* cos(tmp_MinpackGL2_G_00483);
   tmp_sin_00025= sin(tmp_MinpackGL2_G_00483);
   g_tmp_MinpackGL2_G_00484= g_tmp_MinpackGL2_G_00481.* tmp_sin_00025+ tmp_MinpackGL2_G_00481.* g_tmp_sin_00025;
   tmp_MinpackGL2_G_00484= tmp_MinpackGL2_G_00481.* tmp_sin_00025;
   tmp_MinpackGL2_G_00485= 2: nx;
   g_tmp_x_00030= g_x(tmp_MinpackGL2_G_00485, 1);
   tmp_x_00030= x(tmp_MinpackGL2_G_00485, 1);
   g_tmp_MinpackGL2_G_00486= hx* g_tmp_x_00030;
   tmp_MinpackGL2_G_00486= hx* tmp_x_00030;
   tmp_MinpackGL2_G_00487= 2: nx;
   g_tmp_vpotx_00037= g_vpotx(tmp_MinpackGL2_G_00487, 1);
   tmp_vpotx_00037= vpotx(tmp_MinpackGL2_G_00487, 1);
   g_tmp_MinpackGL2_G_00488= hx* g_tmp_vpotx_00037;
   tmp_MinpackGL2_G_00488= hx* tmp_vpotx_00037;
   g_tmp_cos_00025= g_tmp_MinpackGL2_G_00488.* (-sin(tmp_MinpackGL2_G_00488));
   tmp_cos_00025= cos(tmp_MinpackGL2_G_00488);
   g_tmp_MinpackGL2_G_00489= g_tmp_MinpackGL2_G_00486.* tmp_cos_00025+ tmp_MinpackGL2_G_00486.* g_tmp_cos_00025;
   tmp_MinpackGL2_G_00489= tmp_MinpackGL2_G_00486.* tmp_cos_00025;
   g_tmp_MinpackGL2_G_00490= g_tmp_MinpackGL2_G_00484- g_tmp_MinpackGL2_G_00489;
   tmp_MinpackGL2_G_00490= tmp_MinpackGL2_G_00484- tmp_MinpackGL2_G_00489;
   g_tmp_MinpackGL2_G_00491= g_fkinx2.* tmp_MinpackGL2_G_00490+ fkinx2.* g_tmp_MinpackGL2_G_00490;
   tmp_MinpackGL2_G_00491= fkinx2.* tmp_MinpackGL2_G_00490;
   g_gradax(2: nx, 1)= g_tmp_gradax_00001+ g_tmp_MinpackGL2_G_00467+ g_tmp_MinpackGL2_G_00479+ g_tmp_MinpackGL2_G_00491;
   gradax(2: nx, 1)= tmp_gradax_00001+ tmp_MinpackGL2_G_00467+ tmp_MinpackGL2_G_00479+ tmp_MinpackGL2_G_00491; 
   tmp_MinpackGL2_G_00492= 2: nx;
   g_tmp_graday_00001= g_graday(tmp_MinpackGL2_G_00492, 1);
   tmp_graday_00001= graday(tmp_MinpackGL2_G_00492, 1);
   g_tmp_MinpackGL2_G_00493= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00493= ffield/ hx;
   tmp_MinpackGL2_G_00494= 2: nx;
   g_tmp_x_00031= g_x(tmp_MinpackGL2_G_00494, 1);
   tmp_x_00031= x(tmp_MinpackGL2_G_00494, 1);
   g_tmp_MinpackGL2_G_00495= hy* g_tmp_x_00031;
   tmp_MinpackGL2_G_00495= hy* tmp_x_00031;
   tmp_MinpackGL2_G_00496= 2: nx;
   g_tmp_vpoty_00034= g_vpoty(tmp_MinpackGL2_G_00496, 1);
   tmp_vpoty_00034= vpoty(tmp_MinpackGL2_G_00496, 1);
   g_tmp_MinpackGL2_G_00497= hy* g_tmp_vpoty_00034;
   tmp_MinpackGL2_G_00497= hy* tmp_vpoty_00034;
   g_tmp_sin_00026= g_tmp_MinpackGL2_G_00497.* cos(tmp_MinpackGL2_G_00497);
   tmp_sin_00026= sin(tmp_MinpackGL2_G_00497);
   g_tmp_MinpackGL2_G_00498= g_tmp_MinpackGL2_G_00495.* tmp_sin_00026+ tmp_MinpackGL2_G_00495.* g_tmp_sin_00026;
   tmp_MinpackGL2_G_00498= tmp_MinpackGL2_G_00495.* tmp_sin_00026;
   tmp_MinpackGL2_G_00499= 2: nx;
   g_tmp_y_00030= g_y(tmp_MinpackGL2_G_00499, 1);
   tmp_y_00030= y(tmp_MinpackGL2_G_00499, 1);
   g_tmp_MinpackGL2_G_00500= hy* g_tmp_y_00030;
   tmp_MinpackGL2_G_00500= hy* tmp_y_00030;
   tmp_MinpackGL2_G_00501= 2: nx;
   g_tmp_vpoty_00035= g_vpoty(tmp_MinpackGL2_G_00501, 1);
   tmp_vpoty_00035= vpoty(tmp_MinpackGL2_G_00501, 1);
   g_tmp_MinpackGL2_G_00502= hy* g_tmp_vpoty_00035;
   tmp_MinpackGL2_G_00502= hy* tmp_vpoty_00035;
   g_tmp_cos_00026= g_tmp_MinpackGL2_G_00502.* (-sin(tmp_MinpackGL2_G_00502));
   tmp_cos_00026= cos(tmp_MinpackGL2_G_00502);
   g_tmp_MinpackGL2_G_00503= g_tmp_MinpackGL2_G_00500.* tmp_cos_00026+ tmp_MinpackGL2_G_00500.* g_tmp_cos_00026;
   tmp_MinpackGL2_G_00503= tmp_MinpackGL2_G_00500.* tmp_cos_00026;
   g_tmp_MinpackGL2_G_00504= g_tmp_MinpackGL2_G_00498+ g_tmp_MinpackGL2_G_00503;
   tmp_MinpackGL2_G_00504= tmp_MinpackGL2_G_00498+ tmp_MinpackGL2_G_00503;
   g_tmp_MinpackGL2_G_00505= g_fkiny1.* tmp_MinpackGL2_G_00504+ fkiny1.* g_tmp_MinpackGL2_G_00504;
   tmp_MinpackGL2_G_00505= fkiny1.* tmp_MinpackGL2_G_00504;
   tmp_MinpackGL2_G_00506= 2: nx;
   g_tmp_y_00031= g_y(tmp_MinpackGL2_G_00506, 1);
   tmp_y_00031= y(tmp_MinpackGL2_G_00506, 1);
   g_tmp_MinpackGL2_G_00507= hy* g_tmp_y_00031;
   tmp_MinpackGL2_G_00507= hy* tmp_y_00031;
   tmp_MinpackGL2_G_00508= 2: nx;
   g_tmp_vpoty_00036= g_vpoty(tmp_MinpackGL2_G_00508, 1);
   tmp_vpoty_00036= vpoty(tmp_MinpackGL2_G_00508, 1);
   g_tmp_MinpackGL2_G_00509= hy* g_tmp_vpoty_00036;
   tmp_MinpackGL2_G_00509= hy* tmp_vpoty_00036;
   g_tmp_sin_00027= g_tmp_MinpackGL2_G_00509.* cos(tmp_MinpackGL2_G_00509);
   tmp_sin_00027= sin(tmp_MinpackGL2_G_00509);
   g_tmp_MinpackGL2_G_00510= g_tmp_MinpackGL2_G_00507.* tmp_sin_00027+ tmp_MinpackGL2_G_00507.* g_tmp_sin_00027;
   tmp_MinpackGL2_G_00510= tmp_MinpackGL2_G_00507.* tmp_sin_00027;
   tmp_MinpackGL2_G_00511= 2: nx;
   g_tmp_x_00032= g_x(tmp_MinpackGL2_G_00511, 1);
   tmp_x_00032= x(tmp_MinpackGL2_G_00511, 1);
   g_tmp_MinpackGL2_G_00512= hy* g_tmp_x_00032;
   tmp_MinpackGL2_G_00512= hy* tmp_x_00032;
   tmp_MinpackGL2_G_00513= 2: nx;
   g_tmp_vpoty_00037= g_vpoty(tmp_MinpackGL2_G_00513, 1);
   tmp_vpoty_00037= vpoty(tmp_MinpackGL2_G_00513, 1);
   g_tmp_MinpackGL2_G_00514= hy* g_tmp_vpoty_00037;
   tmp_MinpackGL2_G_00514= hy* tmp_vpoty_00037;
   g_tmp_cos_00027= g_tmp_MinpackGL2_G_00514.* (-sin(tmp_MinpackGL2_G_00514));
   tmp_cos_00027= cos(tmp_MinpackGL2_G_00514);
   g_tmp_MinpackGL2_G_00515= g_tmp_MinpackGL2_G_00512.* tmp_cos_00027+ tmp_MinpackGL2_G_00512.* g_tmp_cos_00027;
   tmp_MinpackGL2_G_00515= tmp_MinpackGL2_G_00512.* tmp_cos_00027;
   g_tmp_MinpackGL2_G_00516= g_tmp_MinpackGL2_G_00510- g_tmp_MinpackGL2_G_00515;
   tmp_MinpackGL2_G_00516= tmp_MinpackGL2_G_00510- tmp_MinpackGL2_G_00515;
   g_tmp_MinpackGL2_G_00517= g_fkiny2.* tmp_MinpackGL2_G_00516+ fkiny2.* g_tmp_MinpackGL2_G_00516;
   tmp_MinpackGL2_G_00517= fkiny2.* tmp_MinpackGL2_G_00516;
   g_graday(2: nx, 1)= g_tmp_graday_00001- g_tmp_MinpackGL2_G_00493+ g_tmp_MinpackGL2_G_00505+ g_tmp_MinpackGL2_G_00517;
   graday(2: nx, 1)= tmp_graday_00001- tmp_MinpackGL2_G_00493+ tmp_MinpackGL2_G_00505+ tmp_MinpackGL2_G_00517; 
   tmp_MinpackGL2_G_00518= hx* hx* sqn;
   tmp_MinpackGL2_G_00519= 2/ tmp_MinpackGL2_G_00518;
   tmp_MinpackGL2_G_00520= 2: nx;
   g_tmp_x_00033= g_x(tmp_MinpackGL2_G_00520, 1);
   tmp_x_00033= x(tmp_MinpackGL2_G_00520, 1);
   tmp_MinpackGL2_G_00521= nx- 1;
   tmp_MinpackGL2_G_00522= 1: tmp_MinpackGL2_G_00521;
   g_tmp_x_00034= g_x(tmp_MinpackGL2_G_00522, 1);
   tmp_x_00034= x(tmp_MinpackGL2_G_00522, 1);
   tmp_MinpackGL2_G_00523= nx- 1;
   tmp_MinpackGL2_G_00524= 1: tmp_MinpackGL2_G_00523;
   g_tmp_vpotx_00038= g_vpotx(tmp_MinpackGL2_G_00524, 1);
   tmp_vpotx_00038= vpotx(tmp_MinpackGL2_G_00524, 1);
   g_tmp_MinpackGL2_G_00525= hx* g_tmp_vpotx_00038;
   tmp_MinpackGL2_G_00525= hx* tmp_vpotx_00038;
   g_tmp_cos_00028= g_tmp_MinpackGL2_G_00525.* (-sin(tmp_MinpackGL2_G_00525));
   tmp_cos_00028= cos(tmp_MinpackGL2_G_00525);
   g_tmp_MinpackGL2_G_00526= g_tmp_x_00034.* tmp_cos_00028+ tmp_x_00034.* g_tmp_cos_00028;
   tmp_MinpackGL2_G_00526= tmp_x_00034.* tmp_cos_00028;
   tmp_MinpackGL2_G_00527= nx- 1;
   tmp_MinpackGL2_G_00528= 1: tmp_MinpackGL2_G_00527;
   g_tmp_y_00032= g_y(tmp_MinpackGL2_G_00528, 1);
   tmp_y_00032= y(tmp_MinpackGL2_G_00528, 1);
   tmp_MinpackGL2_G_00529= nx- 1;
   tmp_MinpackGL2_G_00530= 1: tmp_MinpackGL2_G_00529;
   g_tmp_vpotx_00039= g_vpotx(tmp_MinpackGL2_G_00530, 1);
   tmp_vpotx_00039= vpotx(tmp_MinpackGL2_G_00530, 1);
   g_tmp_MinpackGL2_G_00531= hx* g_tmp_vpotx_00039;
   tmp_MinpackGL2_G_00531= hx* tmp_vpotx_00039;
   g_tmp_sin_00028= g_tmp_MinpackGL2_G_00531.* cos(tmp_MinpackGL2_G_00531);
   tmp_sin_00028= sin(tmp_MinpackGL2_G_00531);
   g_tmp_MinpackGL2_G_00532= g_tmp_y_00032.* tmp_sin_00028+ tmp_y_00032.* g_tmp_sin_00028;
   tmp_MinpackGL2_G_00532= tmp_y_00032.* tmp_sin_00028;
   g_tmp_MinpackGL2_G_00533= g_tmp_x_00033- g_tmp_MinpackGL2_G_00526+ g_tmp_MinpackGL2_G_00532;
   tmp_MinpackGL2_G_00533= tmp_x_00033- tmp_MinpackGL2_G_00526+ tmp_MinpackGL2_G_00532;
   g_fkinx1= tmp_MinpackGL2_G_00519* g_tmp_MinpackGL2_G_00533;
   fkinx1= tmp_MinpackGL2_G_00519* tmp_MinpackGL2_G_00533; 
   tmp_MinpackGL2_G_00534= hx* hx* sqn;
   tmp_MinpackGL2_G_00535= 2/ tmp_MinpackGL2_G_00534;
   tmp_MinpackGL2_G_00536= 2: nx;
   g_tmp_y_00033= g_y(tmp_MinpackGL2_G_00536, 1);
   tmp_y_00033= y(tmp_MinpackGL2_G_00536, 1);
   tmp_MinpackGL2_G_00537= nx- 1;
   tmp_MinpackGL2_G_00538= 1: tmp_MinpackGL2_G_00537;
   g_tmp_y_00034= g_y(tmp_MinpackGL2_G_00538, 1);
   tmp_y_00034= y(tmp_MinpackGL2_G_00538, 1);
   tmp_MinpackGL2_G_00539= nx- 1;
   tmp_MinpackGL2_G_00540= 1: tmp_MinpackGL2_G_00539;
   g_tmp_vpotx_00040= g_vpotx(tmp_MinpackGL2_G_00540, 1);
   tmp_vpotx_00040= vpotx(tmp_MinpackGL2_G_00540, 1);
   g_tmp_MinpackGL2_G_00541= hx* g_tmp_vpotx_00040;
   tmp_MinpackGL2_G_00541= hx* tmp_vpotx_00040;
   g_tmp_cos_00029= g_tmp_MinpackGL2_G_00541.* (-sin(tmp_MinpackGL2_G_00541));
   tmp_cos_00029= cos(tmp_MinpackGL2_G_00541);
   g_tmp_MinpackGL2_G_00542= g_tmp_y_00034.* tmp_cos_00029+ tmp_y_00034.* g_tmp_cos_00029;
   tmp_MinpackGL2_G_00542= tmp_y_00034.* tmp_cos_00029;
   tmp_MinpackGL2_G_00543= nx- 1;
   tmp_MinpackGL2_G_00544= 1: tmp_MinpackGL2_G_00543;
   g_tmp_x_00035= g_x(tmp_MinpackGL2_G_00544, 1);
   tmp_x_00035= x(tmp_MinpackGL2_G_00544, 1);
   tmp_MinpackGL2_G_00545= nx- 1;
   tmp_MinpackGL2_G_00546= 1: tmp_MinpackGL2_G_00545;
   g_tmp_vpotx_00041= g_vpotx(tmp_MinpackGL2_G_00546, 1);
   tmp_vpotx_00041= vpotx(tmp_MinpackGL2_G_00546, 1);
   g_tmp_MinpackGL2_G_00547= hx* g_tmp_vpotx_00041;
   tmp_MinpackGL2_G_00547= hx* tmp_vpotx_00041;
   g_tmp_sin_00029= g_tmp_MinpackGL2_G_00547.* cos(tmp_MinpackGL2_G_00547);
   tmp_sin_00029= sin(tmp_MinpackGL2_G_00547);
   g_tmp_MinpackGL2_G_00548= g_tmp_x_00035.* tmp_sin_00029+ tmp_x_00035.* g_tmp_sin_00029;
   tmp_MinpackGL2_G_00548= tmp_x_00035.* tmp_sin_00029;
   g_tmp_MinpackGL2_G_00549= g_tmp_y_00033- g_tmp_MinpackGL2_G_00542- g_tmp_MinpackGL2_G_00548;
   tmp_MinpackGL2_G_00549= tmp_y_00033- tmp_MinpackGL2_G_00542- tmp_MinpackGL2_G_00548;
   g_fkinx2= tmp_MinpackGL2_G_00535* g_tmp_MinpackGL2_G_00549;
   fkinx2= tmp_MinpackGL2_G_00535* tmp_MinpackGL2_G_00549; 
   tmp_MinpackGL2_G_00550= hy* hy* sqn;
   tmp_MinpackGL2_G_00551= 2/ tmp_MinpackGL2_G_00550;
   tmp_MinpackGL2_G_00552= 2: nx;
   tmp_MinpackGL2_G_00553= ny+ 1;
   g_tmp_x_00036= g_x(tmp_MinpackGL2_G_00552, tmp_MinpackGL2_G_00553);
   tmp_x_00036= x(tmp_MinpackGL2_G_00552, tmp_MinpackGL2_G_00553);
   tmp_MinpackGL2_G_00554= 2: nx;
   g_tmp_x_00037= g_x(tmp_MinpackGL2_G_00554, ny);
   tmp_x_00037= x(tmp_MinpackGL2_G_00554, ny);
   tmp_MinpackGL2_G_00555= 2: nx;
   g_tmp_vpoty_00038= g_vpoty(tmp_MinpackGL2_G_00555, ny);
   tmp_vpoty_00038= vpoty(tmp_MinpackGL2_G_00555, ny);
   g_tmp_MinpackGL2_G_00556= hy* g_tmp_vpoty_00038;
   tmp_MinpackGL2_G_00556= hy* tmp_vpoty_00038;
   g_tmp_cos_00030= g_tmp_MinpackGL2_G_00556.* (-sin(tmp_MinpackGL2_G_00556));
   tmp_cos_00030= cos(tmp_MinpackGL2_G_00556);
   g_tmp_MinpackGL2_G_00557= g_tmp_x_00037.* tmp_cos_00030+ tmp_x_00037.* g_tmp_cos_00030;
   tmp_MinpackGL2_G_00557= tmp_x_00037.* tmp_cos_00030;
   tmp_MinpackGL2_G_00558= 2: nx;
   g_tmp_y_00035= g_y(tmp_MinpackGL2_G_00558, ny);
   tmp_y_00035= y(tmp_MinpackGL2_G_00558, ny);
   tmp_MinpackGL2_G_00559= 2: nx;
   g_tmp_vpoty_00039= g_vpoty(tmp_MinpackGL2_G_00559, ny);
   tmp_vpoty_00039= vpoty(tmp_MinpackGL2_G_00559, ny);
   g_tmp_MinpackGL2_G_00560= hy* g_tmp_vpoty_00039;
   tmp_MinpackGL2_G_00560= hy* tmp_vpoty_00039;
   g_tmp_sin_00030= g_tmp_MinpackGL2_G_00560.* cos(tmp_MinpackGL2_G_00560);
   tmp_sin_00030= sin(tmp_MinpackGL2_G_00560);
   g_tmp_MinpackGL2_G_00561= g_tmp_y_00035.* tmp_sin_00030+ tmp_y_00035.* g_tmp_sin_00030;
   tmp_MinpackGL2_G_00561= tmp_y_00035.* tmp_sin_00030;
   g_tmp_MinpackGL2_G_00562= g_tmp_x_00036- g_tmp_MinpackGL2_G_00557+ g_tmp_MinpackGL2_G_00561;
   tmp_MinpackGL2_G_00562= tmp_x_00036- tmp_MinpackGL2_G_00557+ tmp_MinpackGL2_G_00561;
   g_fkiny1= tmp_MinpackGL2_G_00551* g_tmp_MinpackGL2_G_00562;
   fkiny1= tmp_MinpackGL2_G_00551* tmp_MinpackGL2_G_00562; 
   tmp_MinpackGL2_G_00563= hy* hy* sqn;
   tmp_MinpackGL2_G_00564= 2/ tmp_MinpackGL2_G_00563;
   tmp_MinpackGL2_G_00565= 2: nx;
   tmp_MinpackGL2_G_00566= ny+ 1;
   g_tmp_y_00036= g_y(tmp_MinpackGL2_G_00565, tmp_MinpackGL2_G_00566);
   tmp_y_00036= y(tmp_MinpackGL2_G_00565, tmp_MinpackGL2_G_00566);
   tmp_MinpackGL2_G_00567= 2: nx;
   g_tmp_y_00037= g_y(tmp_MinpackGL2_G_00567, ny);
   tmp_y_00037= y(tmp_MinpackGL2_G_00567, ny);
   tmp_MinpackGL2_G_00568= 2: nx;
   g_tmp_vpoty_00040= g_vpoty(tmp_MinpackGL2_G_00568, ny);
   tmp_vpoty_00040= vpoty(tmp_MinpackGL2_G_00568, ny);
   g_tmp_MinpackGL2_G_00569= hy* g_tmp_vpoty_00040;
   tmp_MinpackGL2_G_00569= hy* tmp_vpoty_00040;
   g_tmp_cos_00031= g_tmp_MinpackGL2_G_00569.* (-sin(tmp_MinpackGL2_G_00569));
   tmp_cos_00031= cos(tmp_MinpackGL2_G_00569);
   g_tmp_MinpackGL2_G_00570= g_tmp_y_00037.* tmp_cos_00031+ tmp_y_00037.* g_tmp_cos_00031;
   tmp_MinpackGL2_G_00570= tmp_y_00037.* tmp_cos_00031;
   tmp_MinpackGL2_G_00571= 2: nx;
   g_tmp_x_00038= g_x(tmp_MinpackGL2_G_00571, ny);
   tmp_x_00038= x(tmp_MinpackGL2_G_00571, ny);
   tmp_MinpackGL2_G_00572= 2: nx;
   g_tmp_vpoty_00041= g_vpoty(tmp_MinpackGL2_G_00572, ny);
   tmp_vpoty_00041= vpoty(tmp_MinpackGL2_G_00572, ny);
   g_tmp_MinpackGL2_G_00573= hy* g_tmp_vpoty_00041;
   tmp_MinpackGL2_G_00573= hy* tmp_vpoty_00041;
   g_tmp_sin_00031= g_tmp_MinpackGL2_G_00573.* cos(tmp_MinpackGL2_G_00573);
   tmp_sin_00031= sin(tmp_MinpackGL2_G_00573);
   g_tmp_MinpackGL2_G_00574= g_tmp_x_00038.* tmp_sin_00031+ tmp_x_00038.* g_tmp_sin_00031;
   tmp_MinpackGL2_G_00574= tmp_x_00038.* tmp_sin_00031;
   g_tmp_MinpackGL2_G_00575= g_tmp_y_00036- g_tmp_MinpackGL2_G_00570- g_tmp_MinpackGL2_G_00574;
   tmp_MinpackGL2_G_00575= tmp_y_00036- tmp_MinpackGL2_G_00570- tmp_MinpackGL2_G_00574;
   g_fkiny2= tmp_MinpackGL2_G_00564* g_tmp_MinpackGL2_G_00575;
   fkiny2= tmp_MinpackGL2_G_00564* tmp_MinpackGL2_G_00575; 
   tmp_MinpackGL2_G_00576= 2: nx;
   g_tmp_gradx_00003= g_gradx(tmp_MinpackGL2_G_00576, 1);
   tmp_gradx_00003= gradx(tmp_MinpackGL2_G_00576, 1);
   g_gradx(2: nx, 1)= g_tmp_gradx_00003+ g_fkinx1+ g_fkiny1;
   gradx(2: nx, 1)= tmp_gradx_00003+ fkinx1+ fkiny1; 
   tmp_MinpackGL2_G_00577= 2: nx;
   g_tmp_grady_00003= g_grady(tmp_MinpackGL2_G_00577, 1);
   tmp_grady_00003= grady(tmp_MinpackGL2_G_00577, 1);
   g_grady(2: nx, 1)= g_tmp_grady_00003+ g_fkinx2+ g_fkiny2;
   grady(2: nx, 1)= tmp_grady_00003+ fkinx2+ fkiny2; 
   tmp_MinpackGL2_G_00578= 2: nx;
   g_tmp_vpotx_00042= g_vpotx(tmp_MinpackGL2_G_00578, ny);
   tmp_vpotx_00042= vpotx(tmp_MinpackGL2_G_00578, ny);
   tmp_MinpackGL2_G_00579= 2: nx;
   tmp_MinpackGL2_G_00580= ny+ 1;
   g_tmp_vpotx_00043= g_vpotx(tmp_MinpackGL2_G_00579, tmp_MinpackGL2_G_00580);
   tmp_vpotx_00043= vpotx(tmp_MinpackGL2_G_00579, tmp_MinpackGL2_G_00580);
   g_tmp_MinpackGL2_G_00581= g_tmp_vpotx_00042- g_tmp_vpotx_00043;
   tmp_MinpackGL2_G_00581= tmp_vpotx_00042- tmp_vpotx_00043;
   g_tmp_MinpackGL2_G_00582= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00581), (tmp_MinpackGL2_G_00581), hy);
   tmp_MinpackGL2_G_00582= tmp_MinpackGL2_G_00581/ hy;
   tmp_MinpackGL2_G_00583= nx+ 1;
   tmp_MinpackGL2_G_00584= 3: tmp_MinpackGL2_G_00583;
   g_tmp_vpoty_00042= g_vpoty(tmp_MinpackGL2_G_00584, ny);
   tmp_vpoty_00042= vpoty(tmp_MinpackGL2_G_00584, ny);
   tmp_MinpackGL2_G_00585= 2: nx;
   g_tmp_vpoty_00043= g_vpoty(tmp_MinpackGL2_G_00585, ny);
   tmp_vpoty_00043= vpoty(tmp_MinpackGL2_G_00585, ny);
   g_tmp_MinpackGL2_G_00586= g_tmp_vpoty_00042- g_tmp_vpoty_00043;
   tmp_MinpackGL2_G_00586= tmp_vpoty_00042- tmp_vpoty_00043;
   g_tmp_MinpackGL2_G_00587= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00586), (tmp_MinpackGL2_G_00586), hx);
   tmp_MinpackGL2_G_00587= tmp_MinpackGL2_G_00586/ hx;
   g_tmp_MinpackGL2_G_00588= g_tmp_MinpackGL2_G_00582+ g_tmp_MinpackGL2_G_00587;
   tmp_MinpackGL2_G_00588= tmp_MinpackGL2_G_00582+ tmp_MinpackGL2_G_00587;
   tmp_MinpackGL2_G_00589= tkappa^ 2;
   tmp_MinpackGL2_G_00590= 2* tmp_MinpackGL2_G_00589;
   tmp_MinpackGL2_G_00591= tmp_MinpackGL2_G_00590/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00588* tmp_MinpackGL2_G_00591;
   ffield= tmp_MinpackGL2_G_00588* tmp_MinpackGL2_G_00591; 
   tmp_MinpackGL2_G_00592= 2: nx;
   g_tmp_gradax_00002= g_gradax(tmp_MinpackGL2_G_00592, 1);
   tmp_gradax_00002= gradax(tmp_MinpackGL2_G_00592, 1);
   g_tmp_MinpackGL2_G_00593= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00593= ffield/ hy;
   g_gradax(2: nx, 1)= g_tmp_gradax_00002- g_tmp_MinpackGL2_G_00593;
   gradax(2: nx, 1)= tmp_gradax_00002- tmp_MinpackGL2_G_00593; 
   tmp_MinpackGL2_G_00594= nx- 1;
   tmp_MinpackGL2_G_00595= 1: tmp_MinpackGL2_G_00594;
   g_tmp_vpotx_00044= g_vpotx(tmp_MinpackGL2_G_00595, 1);
   tmp_vpotx_00044= vpotx(tmp_MinpackGL2_G_00595, 1);
   tmp_MinpackGL2_G_00596= nx- 1;
   tmp_MinpackGL2_G_00597= 1: tmp_MinpackGL2_G_00596;
   g_tmp_vpotx_00045= g_vpotx(tmp_MinpackGL2_G_00597, 2);
   tmp_vpotx_00045= vpotx(tmp_MinpackGL2_G_00597, 2);
   g_tmp_MinpackGL2_G_00598= g_tmp_vpotx_00044- g_tmp_vpotx_00045;
   tmp_MinpackGL2_G_00598= tmp_vpotx_00044- tmp_vpotx_00045;
   g_tmp_MinpackGL2_G_00599= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00598), (tmp_MinpackGL2_G_00598), hy);
   tmp_MinpackGL2_G_00599= tmp_MinpackGL2_G_00598/ hy;
   tmp_MinpackGL2_G_00600= 2: nx;
   g_tmp_vpoty_00044= g_vpoty(tmp_MinpackGL2_G_00600, 1);
   tmp_vpoty_00044= vpoty(tmp_MinpackGL2_G_00600, 1);
   tmp_MinpackGL2_G_00601= nx- 1;
   tmp_MinpackGL2_G_00602= 1: tmp_MinpackGL2_G_00601;
   g_tmp_vpoty_00045= g_vpoty(tmp_MinpackGL2_G_00602, 1);
   tmp_vpoty_00045= vpoty(tmp_MinpackGL2_G_00602, 1);
   g_tmp_MinpackGL2_G_00603= g_tmp_vpoty_00044- g_tmp_vpoty_00045;
   tmp_MinpackGL2_G_00603= tmp_vpoty_00044- tmp_vpoty_00045;
   g_tmp_MinpackGL2_G_00604= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00603), (tmp_MinpackGL2_G_00603), hx);
   tmp_MinpackGL2_G_00604= tmp_MinpackGL2_G_00603/ hx;
   g_tmp_MinpackGL2_G_00605= g_tmp_MinpackGL2_G_00599+ g_tmp_MinpackGL2_G_00604;
   tmp_MinpackGL2_G_00605= tmp_MinpackGL2_G_00599+ tmp_MinpackGL2_G_00604;
   tmp_MinpackGL2_G_00606= tkappa^ 2;
   tmp_MinpackGL2_G_00607= 2* tmp_MinpackGL2_G_00606;
   tmp_MinpackGL2_G_00608= tmp_MinpackGL2_G_00607/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00605* tmp_MinpackGL2_G_00608;
   ffield= tmp_MinpackGL2_G_00605* tmp_MinpackGL2_G_00608; 
   tmp_MinpackGL2_G_00609= 2: nx;
   g_tmp_graday_00002= g_graday(tmp_MinpackGL2_G_00609, 1);
   tmp_graday_00002= graday(tmp_MinpackGL2_G_00609, 1);
   g_tmp_MinpackGL2_G_00610= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00610= ffield/ hx;
   g_graday(2: nx, 1)= g_tmp_graday_00002+ g_tmp_MinpackGL2_G_00610;
   graday(2: nx, 1)= tmp_graday_00002+ tmp_MinpackGL2_G_00610; 
   
   %    Left I = 1.
   
   tmp_MinpackGL2_G_00611= hx* hx* sqn;
   tmp_MinpackGL2_G_00612= 2/ tmp_MinpackGL2_G_00611;
   tmp_MinpackGL2_G_00613= 2: ny;
   g_tmp_x_00039= g_x(2, tmp_MinpackGL2_G_00613);
   tmp_x_00039= x(2, tmp_MinpackGL2_G_00613);
   tmp_MinpackGL2_G_00614= 2: ny;
   g_tmp_x_00040= g_x(1, tmp_MinpackGL2_G_00614);
   tmp_x_00040= x(1, tmp_MinpackGL2_G_00614);
   tmp_MinpackGL2_G_00615= 2: ny;
   g_tmp_vpotx_00046= g_vpotx(1, tmp_MinpackGL2_G_00615);
   tmp_vpotx_00046= vpotx(1, tmp_MinpackGL2_G_00615);
   g_tmp_MinpackGL2_G_00616= hx* g_tmp_vpotx_00046;
   tmp_MinpackGL2_G_00616= hx* tmp_vpotx_00046;
   g_tmp_cos_00032= g_tmp_MinpackGL2_G_00616.* (-sin(tmp_MinpackGL2_G_00616));
   tmp_cos_00032= cos(tmp_MinpackGL2_G_00616);
   g_tmp_MinpackGL2_G_00617= g_tmp_x_00040.* tmp_cos_00032+ tmp_x_00040.* g_tmp_cos_00032;
   tmp_MinpackGL2_G_00617= tmp_x_00040.* tmp_cos_00032;
   tmp_MinpackGL2_G_00618= 2: ny;
   g_tmp_y_00038= g_y(1, tmp_MinpackGL2_G_00618);
   tmp_y_00038= y(1, tmp_MinpackGL2_G_00618);
   tmp_MinpackGL2_G_00619= 2: ny;
   g_tmp_vpotx_00047= g_vpotx(1, tmp_MinpackGL2_G_00619);
   tmp_vpotx_00047= vpotx(1, tmp_MinpackGL2_G_00619);
   g_tmp_MinpackGL2_G_00620= hx* g_tmp_vpotx_00047;
   tmp_MinpackGL2_G_00620= hx* tmp_vpotx_00047;
   g_tmp_sin_00032= g_tmp_MinpackGL2_G_00620.* cos(tmp_MinpackGL2_G_00620);
   tmp_sin_00032= sin(tmp_MinpackGL2_G_00620);
   g_tmp_MinpackGL2_G_00621= g_tmp_y_00038.* tmp_sin_00032+ tmp_y_00038.* g_tmp_sin_00032;
   tmp_MinpackGL2_G_00621= tmp_y_00038.* tmp_sin_00032;
   g_tmp_MinpackGL2_G_00622= g_tmp_x_00039- g_tmp_MinpackGL2_G_00617+ g_tmp_MinpackGL2_G_00621;
   tmp_MinpackGL2_G_00622= tmp_x_00039- tmp_MinpackGL2_G_00617+ tmp_MinpackGL2_G_00621;
   g_fkinx1= tmp_MinpackGL2_G_00612* g_tmp_MinpackGL2_G_00622;
   fkinx1= tmp_MinpackGL2_G_00612* tmp_MinpackGL2_G_00622; 
   tmp_MinpackGL2_G_00623= hx* hx* sqn;
   tmp_MinpackGL2_G_00624= 2/ tmp_MinpackGL2_G_00623;
   tmp_MinpackGL2_G_00625= 2: ny;
   g_tmp_y_00039= g_y(2, tmp_MinpackGL2_G_00625);
   tmp_y_00039= y(2, tmp_MinpackGL2_G_00625);
   tmp_MinpackGL2_G_00626= 2: ny;
   g_tmp_y_00040= g_y(1, tmp_MinpackGL2_G_00626);
   tmp_y_00040= y(1, tmp_MinpackGL2_G_00626);
   tmp_MinpackGL2_G_00627= 2: ny;
   g_tmp_vpotx_00048= g_vpotx(1, tmp_MinpackGL2_G_00627);
   tmp_vpotx_00048= vpotx(1, tmp_MinpackGL2_G_00627);
   g_tmp_MinpackGL2_G_00628= hx* g_tmp_vpotx_00048;
   tmp_MinpackGL2_G_00628= hx* tmp_vpotx_00048;
   g_tmp_cos_00033= g_tmp_MinpackGL2_G_00628.* (-sin(tmp_MinpackGL2_G_00628));
   tmp_cos_00033= cos(tmp_MinpackGL2_G_00628);
   g_tmp_MinpackGL2_G_00629= g_tmp_y_00040.* tmp_cos_00033+ tmp_y_00040.* g_tmp_cos_00033;
   tmp_MinpackGL2_G_00629= tmp_y_00040.* tmp_cos_00033;
   tmp_MinpackGL2_G_00630= 2: ny;
   g_tmp_x_00041= g_x(1, tmp_MinpackGL2_G_00630);
   tmp_x_00041= x(1, tmp_MinpackGL2_G_00630);
   tmp_MinpackGL2_G_00631= 2: ny;
   g_tmp_vpotx_00049= g_vpotx(1, tmp_MinpackGL2_G_00631);
   tmp_vpotx_00049= vpotx(1, tmp_MinpackGL2_G_00631);
   g_tmp_MinpackGL2_G_00632= hx* g_tmp_vpotx_00049;
   tmp_MinpackGL2_G_00632= hx* tmp_vpotx_00049;
   g_tmp_sin_00033= g_tmp_MinpackGL2_G_00632.* cos(tmp_MinpackGL2_G_00632);
   tmp_sin_00033= sin(tmp_MinpackGL2_G_00632);
   g_tmp_MinpackGL2_G_00633= g_tmp_x_00041.* tmp_sin_00033+ tmp_x_00041.* g_tmp_sin_00033;
   tmp_MinpackGL2_G_00633= tmp_x_00041.* tmp_sin_00033;
   g_tmp_MinpackGL2_G_00634= g_tmp_y_00039- g_tmp_MinpackGL2_G_00629- g_tmp_MinpackGL2_G_00633;
   tmp_MinpackGL2_G_00634= tmp_y_00039- tmp_MinpackGL2_G_00629- tmp_MinpackGL2_G_00633;
   g_fkinx2= tmp_MinpackGL2_G_00624* g_tmp_MinpackGL2_G_00634;
   fkinx2= tmp_MinpackGL2_G_00624* tmp_MinpackGL2_G_00634; 
   tmp_MinpackGL2_G_00635= hy* hy* sqn;
   tmp_MinpackGL2_G_00636= 2/ tmp_MinpackGL2_G_00635;
   tmp_MinpackGL2_G_00637= ny+ 1;
   tmp_MinpackGL2_G_00638= 3: tmp_MinpackGL2_G_00637;
   g_tmp_x_00042= g_x(1, tmp_MinpackGL2_G_00638);
   tmp_x_00042= x(1, tmp_MinpackGL2_G_00638);
   tmp_MinpackGL2_G_00639= 2: ny;
   g_tmp_x_00043= g_x(1, tmp_MinpackGL2_G_00639);
   tmp_x_00043= x(1, tmp_MinpackGL2_G_00639);
   tmp_MinpackGL2_G_00640= 2: ny;
   g_tmp_vpoty_00046= g_vpoty(1, tmp_MinpackGL2_G_00640);
   tmp_vpoty_00046= vpoty(1, tmp_MinpackGL2_G_00640);
   g_tmp_MinpackGL2_G_00641= hy* g_tmp_vpoty_00046;
   tmp_MinpackGL2_G_00641= hy* tmp_vpoty_00046;
   g_tmp_cos_00034= g_tmp_MinpackGL2_G_00641.* (-sin(tmp_MinpackGL2_G_00641));
   tmp_cos_00034= cos(tmp_MinpackGL2_G_00641);
   g_tmp_MinpackGL2_G_00642= g_tmp_x_00043.* tmp_cos_00034+ tmp_x_00043.* g_tmp_cos_00034;
   tmp_MinpackGL2_G_00642= tmp_x_00043.* tmp_cos_00034;
   tmp_MinpackGL2_G_00643= 2: ny;
   g_tmp_y_00041= g_y(1, tmp_MinpackGL2_G_00643);
   tmp_y_00041= y(1, tmp_MinpackGL2_G_00643);
   tmp_MinpackGL2_G_00644= 2: ny;
   g_tmp_vpoty_00047= g_vpoty(1, tmp_MinpackGL2_G_00644);
   tmp_vpoty_00047= vpoty(1, tmp_MinpackGL2_G_00644);
   g_tmp_MinpackGL2_G_00645= hy* g_tmp_vpoty_00047;
   tmp_MinpackGL2_G_00645= hy* tmp_vpoty_00047;
   g_tmp_sin_00034= g_tmp_MinpackGL2_G_00645.* cos(tmp_MinpackGL2_G_00645);
   tmp_sin_00034= sin(tmp_MinpackGL2_G_00645);
   g_tmp_MinpackGL2_G_00646= g_tmp_y_00041.* tmp_sin_00034+ tmp_y_00041.* g_tmp_sin_00034;
   tmp_MinpackGL2_G_00646= tmp_y_00041.* tmp_sin_00034;
   g_tmp_MinpackGL2_G_00647= g_tmp_x_00042- g_tmp_MinpackGL2_G_00642+ g_tmp_MinpackGL2_G_00646;
   tmp_MinpackGL2_G_00647= tmp_x_00042- tmp_MinpackGL2_G_00642+ tmp_MinpackGL2_G_00646;
   g_fkiny1= tmp_MinpackGL2_G_00636* g_tmp_MinpackGL2_G_00647;
   fkiny1= tmp_MinpackGL2_G_00636* tmp_MinpackGL2_G_00647; 
   tmp_MinpackGL2_G_00648= hy* hy* sqn;
   tmp_MinpackGL2_G_00649= 2/ tmp_MinpackGL2_G_00648;
   tmp_MinpackGL2_G_00650= ny+ 1;
   tmp_MinpackGL2_G_00651= 3: tmp_MinpackGL2_G_00650;
   g_tmp_y_00042= g_y(1, tmp_MinpackGL2_G_00651);
   tmp_y_00042= y(1, tmp_MinpackGL2_G_00651);
   tmp_MinpackGL2_G_00652= 2: ny;
   g_tmp_y_00043= g_y(1, tmp_MinpackGL2_G_00652);
   tmp_y_00043= y(1, tmp_MinpackGL2_G_00652);
   tmp_MinpackGL2_G_00653= 2: ny;
   g_tmp_vpoty_00048= g_vpoty(1, tmp_MinpackGL2_G_00653);
   tmp_vpoty_00048= vpoty(1, tmp_MinpackGL2_G_00653);
   g_tmp_MinpackGL2_G_00654= hy* g_tmp_vpoty_00048;
   tmp_MinpackGL2_G_00654= hy* tmp_vpoty_00048;
   g_tmp_cos_00035= g_tmp_MinpackGL2_G_00654.* (-sin(tmp_MinpackGL2_G_00654));
   tmp_cos_00035= cos(tmp_MinpackGL2_G_00654);
   g_tmp_MinpackGL2_G_00655= g_tmp_y_00043.* tmp_cos_00035+ tmp_y_00043.* g_tmp_cos_00035;
   tmp_MinpackGL2_G_00655= tmp_y_00043.* tmp_cos_00035;
   tmp_MinpackGL2_G_00656= 2: ny;
   g_tmp_x_00044= g_x(1, tmp_MinpackGL2_G_00656);
   tmp_x_00044= x(1, tmp_MinpackGL2_G_00656);
   tmp_MinpackGL2_G_00657= 2: ny;
   g_tmp_vpoty_00049= g_vpoty(1, tmp_MinpackGL2_G_00657);
   tmp_vpoty_00049= vpoty(1, tmp_MinpackGL2_G_00657);
   g_tmp_MinpackGL2_G_00658= hy* g_tmp_vpoty_00049;
   tmp_MinpackGL2_G_00658= hy* tmp_vpoty_00049;
   g_tmp_sin_00035= g_tmp_MinpackGL2_G_00658.* cos(tmp_MinpackGL2_G_00658);
   tmp_sin_00035= sin(tmp_MinpackGL2_G_00658);
   g_tmp_MinpackGL2_G_00659= g_tmp_x_00044.* tmp_sin_00035+ tmp_x_00044.* g_tmp_sin_00035;
   tmp_MinpackGL2_G_00659= tmp_x_00044.* tmp_sin_00035;
   g_tmp_MinpackGL2_G_00660= g_tmp_y_00042- g_tmp_MinpackGL2_G_00655- g_tmp_MinpackGL2_G_00659;
   tmp_MinpackGL2_G_00660= tmp_y_00042- tmp_MinpackGL2_G_00655- tmp_MinpackGL2_G_00659;
   g_fkiny2= tmp_MinpackGL2_G_00649* g_tmp_MinpackGL2_G_00660;
   fkiny2= tmp_MinpackGL2_G_00649* tmp_MinpackGL2_G_00660; 
   tmp_MinpackGL2_G_00661= 2: ny;
   g_tmp_vpotx_00050= g_vpotx(1, tmp_MinpackGL2_G_00661);
   tmp_vpotx_00050= vpotx(1, tmp_MinpackGL2_G_00661);
   tmp_MinpackGL2_G_00662= ny+ 1;
   tmp_MinpackGL2_G_00663= 3: tmp_MinpackGL2_G_00662;
   g_tmp_vpotx_00051= g_vpotx(1, tmp_MinpackGL2_G_00663);
   tmp_vpotx_00051= vpotx(1, tmp_MinpackGL2_G_00663);
   g_tmp_MinpackGL2_G_00664= g_tmp_vpotx_00050- g_tmp_vpotx_00051;
   tmp_MinpackGL2_G_00664= tmp_vpotx_00050- tmp_vpotx_00051;
   g_tmp_MinpackGL2_G_00665= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00664), (tmp_MinpackGL2_G_00664), hy);
   tmp_MinpackGL2_G_00665= tmp_MinpackGL2_G_00664/ hy;
   tmp_MinpackGL2_G_00666= 2: ny;
   g_tmp_vpoty_00050= g_vpoty(2, tmp_MinpackGL2_G_00666);
   tmp_vpoty_00050= vpoty(2, tmp_MinpackGL2_G_00666);
   tmp_MinpackGL2_G_00667= 2: ny;
   g_tmp_vpoty_00051= g_vpoty(1, tmp_MinpackGL2_G_00667);
   tmp_vpoty_00051= vpoty(1, tmp_MinpackGL2_G_00667);
   g_tmp_MinpackGL2_G_00668= g_tmp_vpoty_00050- g_tmp_vpoty_00051;
   tmp_MinpackGL2_G_00668= tmp_vpoty_00050- tmp_vpoty_00051;
   g_tmp_MinpackGL2_G_00669= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00668), (tmp_MinpackGL2_G_00668), hx);
   tmp_MinpackGL2_G_00669= tmp_MinpackGL2_G_00668/ hx;
   g_tmp_MinpackGL2_G_00670= g_tmp_MinpackGL2_G_00665+ g_tmp_MinpackGL2_G_00669;
   tmp_MinpackGL2_G_00670= tmp_MinpackGL2_G_00665+ tmp_MinpackGL2_G_00669;
   tmp_MinpackGL2_G_00671= tkappa^ 2;
   tmp_MinpackGL2_G_00672= 2* tmp_MinpackGL2_G_00671;
   tmp_MinpackGL2_G_00673= tmp_MinpackGL2_G_00672/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00670* tmp_MinpackGL2_G_00673;
   ffield= tmp_MinpackGL2_G_00670* tmp_MinpackGL2_G_00673; 
   tmp_MinpackGL2_G_00674= 2: ny;
   g_tmp_gradx_00004= g_gradx(1, tmp_MinpackGL2_G_00674);
   tmp_gradx_00004= gradx(1, tmp_MinpackGL2_G_00674);
   tmp_MinpackGL2_G_00675= 2: ny;
   g_tmp_vpotx_00052= g_vpotx(1, tmp_MinpackGL2_G_00675);
   tmp_vpotx_00052= vpotx(1, tmp_MinpackGL2_G_00675);
   g_tmp_MinpackGL2_G_00676= hx* g_tmp_vpotx_00052;
   tmp_MinpackGL2_G_00676= hx* tmp_vpotx_00052;
   g_tmp_cos_00036= g_tmp_MinpackGL2_G_00676.* (-sin(tmp_MinpackGL2_G_00676));
   tmp_cos_00036= cos(tmp_MinpackGL2_G_00676);
   g_tmp_MinpackGL2_G_00677= g_tmp_cos_00036.* fkinx1+ tmp_cos_00036.* g_fkinx1;
   tmp_MinpackGL2_G_00677= tmp_cos_00036.* fkinx1;
   tmp_MinpackGL2_G_00678= 2: ny;
   g_tmp_vpotx_00053= g_vpotx(1, tmp_MinpackGL2_G_00678);
   tmp_vpotx_00053= vpotx(1, tmp_MinpackGL2_G_00678);
   g_tmp_MinpackGL2_G_00679= hx* g_tmp_vpotx_00053;
   tmp_MinpackGL2_G_00679= hx* tmp_vpotx_00053;
   g_tmp_sin_00036= g_tmp_MinpackGL2_G_00679.* cos(tmp_MinpackGL2_G_00679);
   tmp_sin_00036= sin(tmp_MinpackGL2_G_00679);
   g_tmp_MinpackGL2_G_00680= g_tmp_sin_00036.* fkinx2+ tmp_sin_00036.* g_fkinx2;
   tmp_MinpackGL2_G_00680= tmp_sin_00036.* fkinx2;
   tmp_MinpackGL2_G_00681= 2: ny;
   g_tmp_vpoty_00052= g_vpoty(1, tmp_MinpackGL2_G_00681);
   tmp_vpoty_00052= vpoty(1, tmp_MinpackGL2_G_00681);
   g_tmp_MinpackGL2_G_00682= hy* g_tmp_vpoty_00052;
   tmp_MinpackGL2_G_00682= hy* tmp_vpoty_00052;
   g_tmp_cos_00037= g_tmp_MinpackGL2_G_00682.* (-sin(tmp_MinpackGL2_G_00682));
   tmp_cos_00037= cos(tmp_MinpackGL2_G_00682);
   g_tmp_MinpackGL2_G_00683= g_tmp_cos_00037.* fkiny1+ tmp_cos_00037.* g_fkiny1;
   tmp_MinpackGL2_G_00683= tmp_cos_00037.* fkiny1;
   tmp_MinpackGL2_G_00684= 2: ny;
   g_tmp_vpoty_00053= g_vpoty(1, tmp_MinpackGL2_G_00684);
   tmp_vpoty_00053= vpoty(1, tmp_MinpackGL2_G_00684);
   g_tmp_MinpackGL2_G_00685= hy* g_tmp_vpoty_00053;
   tmp_MinpackGL2_G_00685= hy* tmp_vpoty_00053;
   g_tmp_sin_00037= g_tmp_MinpackGL2_G_00685.* cos(tmp_MinpackGL2_G_00685);
   tmp_sin_00037= sin(tmp_MinpackGL2_G_00685);
   g_tmp_MinpackGL2_G_00686= g_tmp_sin_00037.* fkiny2+ tmp_sin_00037.* g_fkiny2;
   tmp_MinpackGL2_G_00686= tmp_sin_00037.* fkiny2;
   g_gradx(1, 2: ny)= g_tmp_gradx_00004- g_tmp_MinpackGL2_G_00677- g_tmp_MinpackGL2_G_00680- g_tmp_MinpackGL2_G_00683- g_tmp_MinpackGL2_G_00686;
   gradx(1, 2: ny)= tmp_gradx_00004- tmp_MinpackGL2_G_00677- tmp_MinpackGL2_G_00680- tmp_MinpackGL2_G_00683- tmp_MinpackGL2_G_00686; 
   tmp_MinpackGL2_G_00687= 2: ny;
   g_tmp_grady_00004= g_grady(1, tmp_MinpackGL2_G_00687);
   tmp_grady_00004= grady(1, tmp_MinpackGL2_G_00687);
   tmp_MinpackGL2_G_00688= 2: ny;
   g_tmp_vpotx_00054= g_vpotx(1, tmp_MinpackGL2_G_00688);
   tmp_vpotx_00054= vpotx(1, tmp_MinpackGL2_G_00688);
   g_tmp_MinpackGL2_G_00689= hx* g_tmp_vpotx_00054;
   tmp_MinpackGL2_G_00689= hx* tmp_vpotx_00054;
   g_tmp_sin_00038= g_tmp_MinpackGL2_G_00689.* cos(tmp_MinpackGL2_G_00689);
   tmp_sin_00038= sin(tmp_MinpackGL2_G_00689);
   g_tmp_MinpackGL2_G_00690= g_tmp_sin_00038.* fkinx1+ tmp_sin_00038.* g_fkinx1;
   tmp_MinpackGL2_G_00690= tmp_sin_00038.* fkinx1;
   tmp_MinpackGL2_G_00691= 2: ny;
   g_tmp_vpotx_00055= g_vpotx(1, tmp_MinpackGL2_G_00691);
   tmp_vpotx_00055= vpotx(1, tmp_MinpackGL2_G_00691);
   g_tmp_MinpackGL2_G_00692= hx* g_tmp_vpotx_00055;
   tmp_MinpackGL2_G_00692= hx* tmp_vpotx_00055;
   g_tmp_cos_00038= g_tmp_MinpackGL2_G_00692.* (-sin(tmp_MinpackGL2_G_00692));
   tmp_cos_00038= cos(tmp_MinpackGL2_G_00692);
   g_tmp_MinpackGL2_G_00693= g_tmp_cos_00038.* fkinx2+ tmp_cos_00038.* g_fkinx2;
   tmp_MinpackGL2_G_00693= tmp_cos_00038.* fkinx2;
   tmp_MinpackGL2_G_00694= 2: ny;
   g_tmp_vpoty_00054= g_vpoty(1, tmp_MinpackGL2_G_00694);
   tmp_vpoty_00054= vpoty(1, tmp_MinpackGL2_G_00694);
   g_tmp_MinpackGL2_G_00695= hy* g_tmp_vpoty_00054;
   tmp_MinpackGL2_G_00695= hy* tmp_vpoty_00054;
   g_tmp_sin_00039= g_tmp_MinpackGL2_G_00695.* cos(tmp_MinpackGL2_G_00695);
   tmp_sin_00039= sin(tmp_MinpackGL2_G_00695);
   g_tmp_MinpackGL2_G_00696= g_tmp_sin_00039.* fkiny1+ tmp_sin_00039.* g_fkiny1;
   tmp_MinpackGL2_G_00696= tmp_sin_00039.* fkiny1;
   tmp_MinpackGL2_G_00697= 2: ny;
   g_tmp_vpoty_00055= g_vpoty(1, tmp_MinpackGL2_G_00697);
   tmp_vpoty_00055= vpoty(1, tmp_MinpackGL2_G_00697);
   g_tmp_MinpackGL2_G_00698= hy* g_tmp_vpoty_00055;
   tmp_MinpackGL2_G_00698= hy* tmp_vpoty_00055;
   g_tmp_cos_00039= g_tmp_MinpackGL2_G_00698.* (-sin(tmp_MinpackGL2_G_00698));
   tmp_cos_00039= cos(tmp_MinpackGL2_G_00698);
   g_tmp_MinpackGL2_G_00699= g_tmp_cos_00039.* fkiny2+ tmp_cos_00039.* g_fkiny2;
   tmp_MinpackGL2_G_00699= tmp_cos_00039.* fkiny2;
   g_grady(1, 2: ny)= g_tmp_grady_00004+ g_tmp_MinpackGL2_G_00690- g_tmp_MinpackGL2_G_00693+ g_tmp_MinpackGL2_G_00696- g_tmp_MinpackGL2_G_00699;
   grady(1, 2: ny)= tmp_grady_00004+ tmp_MinpackGL2_G_00690- tmp_MinpackGL2_G_00693+ tmp_MinpackGL2_G_00696- tmp_MinpackGL2_G_00699; 
   tmp_MinpackGL2_G_00700= 2: ny;
   g_tmp_gradax_00003= g_gradax(1, tmp_MinpackGL2_G_00700);
   tmp_gradax_00003= gradax(1, tmp_MinpackGL2_G_00700);
   g_tmp_MinpackGL2_G_00701= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00701= ffield/ hy;
   tmp_MinpackGL2_G_00702= 2: ny;
   g_tmp_x_00045= g_x(1, tmp_MinpackGL2_G_00702);
   tmp_x_00045= x(1, tmp_MinpackGL2_G_00702);
   g_tmp_MinpackGL2_G_00703= hx* g_tmp_x_00045;
   tmp_MinpackGL2_G_00703= hx* tmp_x_00045;
   tmp_MinpackGL2_G_00704= 2: ny;
   g_tmp_vpotx_00056= g_vpotx(1, tmp_MinpackGL2_G_00704);
   tmp_vpotx_00056= vpotx(1, tmp_MinpackGL2_G_00704);
   g_tmp_MinpackGL2_G_00705= hx* g_tmp_vpotx_00056;
   tmp_MinpackGL2_G_00705= hx* tmp_vpotx_00056;
   g_tmp_sin_00040= g_tmp_MinpackGL2_G_00705.* cos(tmp_MinpackGL2_G_00705);
   tmp_sin_00040= sin(tmp_MinpackGL2_G_00705);
   g_tmp_MinpackGL2_G_00706= g_tmp_MinpackGL2_G_00703.* tmp_sin_00040+ tmp_MinpackGL2_G_00703.* g_tmp_sin_00040;
   tmp_MinpackGL2_G_00706= tmp_MinpackGL2_G_00703.* tmp_sin_00040;
   tmp_MinpackGL2_G_00707= 2: ny;
   g_tmp_y_00044= g_y(1, tmp_MinpackGL2_G_00707);
   tmp_y_00044= y(1, tmp_MinpackGL2_G_00707);
   g_tmp_MinpackGL2_G_00708= hx* g_tmp_y_00044;
   tmp_MinpackGL2_G_00708= hx* tmp_y_00044;
   tmp_MinpackGL2_G_00709= 2: ny;
   g_tmp_vpotx_00057= g_vpotx(1, tmp_MinpackGL2_G_00709);
   tmp_vpotx_00057= vpotx(1, tmp_MinpackGL2_G_00709);
   g_tmp_MinpackGL2_G_00710= hx* g_tmp_vpotx_00057;
   tmp_MinpackGL2_G_00710= hx* tmp_vpotx_00057;
   g_tmp_cos_00040= g_tmp_MinpackGL2_G_00710.* (-sin(tmp_MinpackGL2_G_00710));
   tmp_cos_00040= cos(tmp_MinpackGL2_G_00710);
   g_tmp_MinpackGL2_G_00711= g_tmp_MinpackGL2_G_00708.* tmp_cos_00040+ tmp_MinpackGL2_G_00708.* g_tmp_cos_00040;
   tmp_MinpackGL2_G_00711= tmp_MinpackGL2_G_00708.* tmp_cos_00040;
   g_tmp_MinpackGL2_G_00712= g_tmp_MinpackGL2_G_00706+ g_tmp_MinpackGL2_G_00711;
   tmp_MinpackGL2_G_00712= tmp_MinpackGL2_G_00706+ tmp_MinpackGL2_G_00711;
   g_tmp_MinpackGL2_G_00713= g_fkinx1.* tmp_MinpackGL2_G_00712+ fkinx1.* g_tmp_MinpackGL2_G_00712;
   tmp_MinpackGL2_G_00713= fkinx1.* tmp_MinpackGL2_G_00712;
   tmp_MinpackGL2_G_00714= 2: ny;
   g_tmp_y_00045= g_y(1, tmp_MinpackGL2_G_00714);
   tmp_y_00045= y(1, tmp_MinpackGL2_G_00714);
   g_tmp_MinpackGL2_G_00715= hx* g_tmp_y_00045;
   tmp_MinpackGL2_G_00715= hx* tmp_y_00045;
   tmp_MinpackGL2_G_00716= 2: ny;
   g_tmp_vpotx_00058= g_vpotx(1, tmp_MinpackGL2_G_00716);
   tmp_vpotx_00058= vpotx(1, tmp_MinpackGL2_G_00716);
   g_tmp_MinpackGL2_G_00717= hx* g_tmp_vpotx_00058;
   tmp_MinpackGL2_G_00717= hx* tmp_vpotx_00058;
   g_tmp_sin_00041= g_tmp_MinpackGL2_G_00717.* cos(tmp_MinpackGL2_G_00717);
   tmp_sin_00041= sin(tmp_MinpackGL2_G_00717);
   g_tmp_MinpackGL2_G_00718= g_tmp_MinpackGL2_G_00715.* tmp_sin_00041+ tmp_MinpackGL2_G_00715.* g_tmp_sin_00041;
   tmp_MinpackGL2_G_00718= tmp_MinpackGL2_G_00715.* tmp_sin_00041;
   tmp_MinpackGL2_G_00719= 2: ny;
   g_tmp_x_00046= g_x(1, tmp_MinpackGL2_G_00719);
   tmp_x_00046= x(1, tmp_MinpackGL2_G_00719);
   g_tmp_MinpackGL2_G_00720= hx* g_tmp_x_00046;
   tmp_MinpackGL2_G_00720= hx* tmp_x_00046;
   tmp_MinpackGL2_G_00721= 2: ny;
   g_tmp_vpotx_00059= g_vpotx(1, tmp_MinpackGL2_G_00721);
   tmp_vpotx_00059= vpotx(1, tmp_MinpackGL2_G_00721);
   g_tmp_MinpackGL2_G_00722= hx* g_tmp_vpotx_00059;
   tmp_MinpackGL2_G_00722= hx* tmp_vpotx_00059;
   g_tmp_cos_00041= g_tmp_MinpackGL2_G_00722.* (-sin(tmp_MinpackGL2_G_00722));
   tmp_cos_00041= cos(tmp_MinpackGL2_G_00722);
   g_tmp_MinpackGL2_G_00723= g_tmp_MinpackGL2_G_00720.* tmp_cos_00041+ tmp_MinpackGL2_G_00720.* g_tmp_cos_00041;
   tmp_MinpackGL2_G_00723= tmp_MinpackGL2_G_00720.* tmp_cos_00041;
   g_tmp_MinpackGL2_G_00724= g_tmp_MinpackGL2_G_00718- g_tmp_MinpackGL2_G_00723;
   tmp_MinpackGL2_G_00724= tmp_MinpackGL2_G_00718- tmp_MinpackGL2_G_00723;
   g_tmp_MinpackGL2_G_00725= g_fkinx2.* tmp_MinpackGL2_G_00724+ fkinx2.* g_tmp_MinpackGL2_G_00724;
   tmp_MinpackGL2_G_00725= fkinx2.* tmp_MinpackGL2_G_00724;
   g_gradax(1, 2: ny)= g_tmp_gradax_00003+ g_tmp_MinpackGL2_G_00701+ g_tmp_MinpackGL2_G_00713+ g_tmp_MinpackGL2_G_00725;
   gradax(1, 2: ny)= tmp_gradax_00003+ tmp_MinpackGL2_G_00701+ tmp_MinpackGL2_G_00713+ tmp_MinpackGL2_G_00725; 
   tmp_MinpackGL2_G_00726= 2: ny;
   g_tmp_graday_00003= g_graday(1, tmp_MinpackGL2_G_00726);
   tmp_graday_00003= graday(1, tmp_MinpackGL2_G_00726);
   g_tmp_MinpackGL2_G_00727= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00727= ffield/ hx;
   tmp_MinpackGL2_G_00728= 2: ny;
   g_tmp_x_00047= g_x(1, tmp_MinpackGL2_G_00728);
   tmp_x_00047= x(1, tmp_MinpackGL2_G_00728);
   g_tmp_MinpackGL2_G_00729= hy* g_tmp_x_00047;
   tmp_MinpackGL2_G_00729= hy* tmp_x_00047;
   tmp_MinpackGL2_G_00730= 2: ny;
   g_tmp_vpoty_00056= g_vpoty(1, tmp_MinpackGL2_G_00730);
   tmp_vpoty_00056= vpoty(1, tmp_MinpackGL2_G_00730);
   g_tmp_MinpackGL2_G_00731= hy* g_tmp_vpoty_00056;
   tmp_MinpackGL2_G_00731= hy* tmp_vpoty_00056;
   g_tmp_sin_00042= g_tmp_MinpackGL2_G_00731.* cos(tmp_MinpackGL2_G_00731);
   tmp_sin_00042= sin(tmp_MinpackGL2_G_00731);
   g_tmp_MinpackGL2_G_00732= g_tmp_MinpackGL2_G_00729.* tmp_sin_00042+ tmp_MinpackGL2_G_00729.* g_tmp_sin_00042;
   tmp_MinpackGL2_G_00732= tmp_MinpackGL2_G_00729.* tmp_sin_00042;
   tmp_MinpackGL2_G_00733= 2: ny;
   g_tmp_y_00046= g_y(1, tmp_MinpackGL2_G_00733);
   tmp_y_00046= y(1, tmp_MinpackGL2_G_00733);
   g_tmp_MinpackGL2_G_00734= hy* g_tmp_y_00046;
   tmp_MinpackGL2_G_00734= hy* tmp_y_00046;
   tmp_MinpackGL2_G_00735= 2: ny;
   g_tmp_vpoty_00057= g_vpoty(1, tmp_MinpackGL2_G_00735);
   tmp_vpoty_00057= vpoty(1, tmp_MinpackGL2_G_00735);
   g_tmp_MinpackGL2_G_00736= hy* g_tmp_vpoty_00057;
   tmp_MinpackGL2_G_00736= hy* tmp_vpoty_00057;
   g_tmp_cos_00042= g_tmp_MinpackGL2_G_00736.* (-sin(tmp_MinpackGL2_G_00736));
   tmp_cos_00042= cos(tmp_MinpackGL2_G_00736);
   g_tmp_MinpackGL2_G_00737= g_tmp_MinpackGL2_G_00734.* tmp_cos_00042+ tmp_MinpackGL2_G_00734.* g_tmp_cos_00042;
   tmp_MinpackGL2_G_00737= tmp_MinpackGL2_G_00734.* tmp_cos_00042;
   g_tmp_MinpackGL2_G_00738= g_tmp_MinpackGL2_G_00732+ g_tmp_MinpackGL2_G_00737;
   tmp_MinpackGL2_G_00738= tmp_MinpackGL2_G_00732+ tmp_MinpackGL2_G_00737;
   g_tmp_MinpackGL2_G_00739= g_fkiny1.* tmp_MinpackGL2_G_00738+ fkiny1.* g_tmp_MinpackGL2_G_00738;
   tmp_MinpackGL2_G_00739= fkiny1.* tmp_MinpackGL2_G_00738;
   tmp_MinpackGL2_G_00740= 2: ny;
   g_tmp_y_00047= g_y(1, tmp_MinpackGL2_G_00740);
   tmp_y_00047= y(1, tmp_MinpackGL2_G_00740);
   g_tmp_MinpackGL2_G_00741= hy* g_tmp_y_00047;
   tmp_MinpackGL2_G_00741= hy* tmp_y_00047;
   tmp_MinpackGL2_G_00742= 2: ny;
   g_tmp_vpoty_00058= g_vpoty(1, tmp_MinpackGL2_G_00742);
   tmp_vpoty_00058= vpoty(1, tmp_MinpackGL2_G_00742);
   g_tmp_MinpackGL2_G_00743= hy* g_tmp_vpoty_00058;
   tmp_MinpackGL2_G_00743= hy* tmp_vpoty_00058;
   g_tmp_sin_00043= g_tmp_MinpackGL2_G_00743.* cos(tmp_MinpackGL2_G_00743);
   tmp_sin_00043= sin(tmp_MinpackGL2_G_00743);
   g_tmp_MinpackGL2_G_00744= g_tmp_MinpackGL2_G_00741.* tmp_sin_00043+ tmp_MinpackGL2_G_00741.* g_tmp_sin_00043;
   tmp_MinpackGL2_G_00744= tmp_MinpackGL2_G_00741.* tmp_sin_00043;
   tmp_MinpackGL2_G_00745= 2: ny;
   g_tmp_x_00048= g_x(1, tmp_MinpackGL2_G_00745);
   tmp_x_00048= x(1, tmp_MinpackGL2_G_00745);
   g_tmp_MinpackGL2_G_00746= hy* g_tmp_x_00048;
   tmp_MinpackGL2_G_00746= hy* tmp_x_00048;
   tmp_MinpackGL2_G_00747= 2: ny;
   g_tmp_vpoty_00059= g_vpoty(1, tmp_MinpackGL2_G_00747);
   tmp_vpoty_00059= vpoty(1, tmp_MinpackGL2_G_00747);
   g_tmp_MinpackGL2_G_00748= hy* g_tmp_vpoty_00059;
   tmp_MinpackGL2_G_00748= hy* tmp_vpoty_00059;
   g_tmp_cos_00043= g_tmp_MinpackGL2_G_00748.* (-sin(tmp_MinpackGL2_G_00748));
   tmp_cos_00043= cos(tmp_MinpackGL2_G_00748);
   g_tmp_MinpackGL2_G_00749= g_tmp_MinpackGL2_G_00746.* tmp_cos_00043+ tmp_MinpackGL2_G_00746.* g_tmp_cos_00043;
   tmp_MinpackGL2_G_00749= tmp_MinpackGL2_G_00746.* tmp_cos_00043;
   g_tmp_MinpackGL2_G_00750= g_tmp_MinpackGL2_G_00744- g_tmp_MinpackGL2_G_00749;
   tmp_MinpackGL2_G_00750= tmp_MinpackGL2_G_00744- tmp_MinpackGL2_G_00749;
   g_tmp_MinpackGL2_G_00751= g_fkiny2.* tmp_MinpackGL2_G_00750+ fkiny2.* g_tmp_MinpackGL2_G_00750;
   tmp_MinpackGL2_G_00751= fkiny2.* tmp_MinpackGL2_G_00750;
   g_graday(1, 2: ny)= g_tmp_graday_00003- g_tmp_MinpackGL2_G_00727+ g_tmp_MinpackGL2_G_00739+ g_tmp_MinpackGL2_G_00751;
   graday(1, 2: ny)= tmp_graday_00003- tmp_MinpackGL2_G_00727+ tmp_MinpackGL2_G_00739+ tmp_MinpackGL2_G_00751; 
   tmp_MinpackGL2_G_00752= hx* hx* sqn;
   tmp_MinpackGL2_G_00753= 2/ tmp_MinpackGL2_G_00752;
   tmp_MinpackGL2_G_00754= nx+ 1;
   tmp_MinpackGL2_G_00755= 2: ny;
   g_tmp_x_00049= g_x(tmp_MinpackGL2_G_00754, tmp_MinpackGL2_G_00755);
   tmp_x_00049= x(tmp_MinpackGL2_G_00754, tmp_MinpackGL2_G_00755);
   tmp_MinpackGL2_G_00756= 2: ny;
   g_tmp_x_00050= g_x(nx, tmp_MinpackGL2_G_00756);
   tmp_x_00050= x(nx, tmp_MinpackGL2_G_00756);
   tmp_MinpackGL2_G_00757= 2: ny;
   g_tmp_vpotx_00060= g_vpotx(nx, tmp_MinpackGL2_G_00757);
   tmp_vpotx_00060= vpotx(nx, tmp_MinpackGL2_G_00757);
   g_tmp_MinpackGL2_G_00758= hx* g_tmp_vpotx_00060;
   tmp_MinpackGL2_G_00758= hx* tmp_vpotx_00060;
   g_tmp_cos_00044= g_tmp_MinpackGL2_G_00758.* (-sin(tmp_MinpackGL2_G_00758));
   tmp_cos_00044= cos(tmp_MinpackGL2_G_00758);
   g_tmp_MinpackGL2_G_00759= g_tmp_x_00050.* tmp_cos_00044+ tmp_x_00050.* g_tmp_cos_00044;
   tmp_MinpackGL2_G_00759= tmp_x_00050.* tmp_cos_00044;
   tmp_MinpackGL2_G_00760= 2: ny;
   g_tmp_y_00048= g_y(nx, tmp_MinpackGL2_G_00760);
   tmp_y_00048= y(nx, tmp_MinpackGL2_G_00760);
   tmp_MinpackGL2_G_00761= 2: ny;
   g_tmp_vpotx_00061= g_vpotx(nx, tmp_MinpackGL2_G_00761);
   tmp_vpotx_00061= vpotx(nx, tmp_MinpackGL2_G_00761);
   g_tmp_MinpackGL2_G_00762= hx* g_tmp_vpotx_00061;
   tmp_MinpackGL2_G_00762= hx* tmp_vpotx_00061;
   g_tmp_sin_00044= g_tmp_MinpackGL2_G_00762.* cos(tmp_MinpackGL2_G_00762);
   tmp_sin_00044= sin(tmp_MinpackGL2_G_00762);
   g_tmp_MinpackGL2_G_00763= g_tmp_y_00048.* tmp_sin_00044+ tmp_y_00048.* g_tmp_sin_00044;
   tmp_MinpackGL2_G_00763= tmp_y_00048.* tmp_sin_00044;
   g_tmp_MinpackGL2_G_00764= g_tmp_x_00049- g_tmp_MinpackGL2_G_00759+ g_tmp_MinpackGL2_G_00763;
   tmp_MinpackGL2_G_00764= tmp_x_00049- tmp_MinpackGL2_G_00759+ tmp_MinpackGL2_G_00763;
   g_fkinx1= tmp_MinpackGL2_G_00753* g_tmp_MinpackGL2_G_00764;
   fkinx1= tmp_MinpackGL2_G_00753* tmp_MinpackGL2_G_00764; 
   tmp_MinpackGL2_G_00765= hx* hx* sqn;
   tmp_MinpackGL2_G_00766= 2/ tmp_MinpackGL2_G_00765;
   tmp_MinpackGL2_G_00767= nx+ 1;
   tmp_MinpackGL2_G_00768= 2: ny;
   g_tmp_y_00049= g_y(tmp_MinpackGL2_G_00767, tmp_MinpackGL2_G_00768);
   tmp_y_00049= y(tmp_MinpackGL2_G_00767, tmp_MinpackGL2_G_00768);
   tmp_MinpackGL2_G_00769= 2: ny;
   g_tmp_y_00050= g_y(nx, tmp_MinpackGL2_G_00769);
   tmp_y_00050= y(nx, tmp_MinpackGL2_G_00769);
   tmp_MinpackGL2_G_00770= 2: ny;
   g_tmp_vpotx_00062= g_vpotx(nx, tmp_MinpackGL2_G_00770);
   tmp_vpotx_00062= vpotx(nx, tmp_MinpackGL2_G_00770);
   g_tmp_MinpackGL2_G_00771= hx* g_tmp_vpotx_00062;
   tmp_MinpackGL2_G_00771= hx* tmp_vpotx_00062;
   g_tmp_cos_00045= g_tmp_MinpackGL2_G_00771.* (-sin(tmp_MinpackGL2_G_00771));
   tmp_cos_00045= cos(tmp_MinpackGL2_G_00771);
   g_tmp_MinpackGL2_G_00772= g_tmp_y_00050.* tmp_cos_00045+ tmp_y_00050.* g_tmp_cos_00045;
   tmp_MinpackGL2_G_00772= tmp_y_00050.* tmp_cos_00045;
   tmp_MinpackGL2_G_00773= 2: ny;
   g_tmp_x_00051= g_x(nx, tmp_MinpackGL2_G_00773);
   tmp_x_00051= x(nx, tmp_MinpackGL2_G_00773);
   tmp_MinpackGL2_G_00774= 2: ny;
   g_tmp_vpotx_00063= g_vpotx(nx, tmp_MinpackGL2_G_00774);
   tmp_vpotx_00063= vpotx(nx, tmp_MinpackGL2_G_00774);
   g_tmp_MinpackGL2_G_00775= hx* g_tmp_vpotx_00063;
   tmp_MinpackGL2_G_00775= hx* tmp_vpotx_00063;
   g_tmp_sin_00045= g_tmp_MinpackGL2_G_00775.* cos(tmp_MinpackGL2_G_00775);
   tmp_sin_00045= sin(tmp_MinpackGL2_G_00775);
   g_tmp_MinpackGL2_G_00776= g_tmp_x_00051.* tmp_sin_00045+ tmp_x_00051.* g_tmp_sin_00045;
   tmp_MinpackGL2_G_00776= tmp_x_00051.* tmp_sin_00045;
   g_tmp_MinpackGL2_G_00777= g_tmp_y_00049- g_tmp_MinpackGL2_G_00772- g_tmp_MinpackGL2_G_00776;
   tmp_MinpackGL2_G_00777= tmp_y_00049- tmp_MinpackGL2_G_00772- tmp_MinpackGL2_G_00776;
   g_fkinx2= tmp_MinpackGL2_G_00766* g_tmp_MinpackGL2_G_00777;
   fkinx2= tmp_MinpackGL2_G_00766* tmp_MinpackGL2_G_00777; 
   tmp_MinpackGL2_G_00778= hy* hy* sqn;
   tmp_MinpackGL2_G_00779= 2/ tmp_MinpackGL2_G_00778;
   tmp_MinpackGL2_G_00780= 2: ny;
   g_tmp_x_00052= g_x(1, tmp_MinpackGL2_G_00780);
   tmp_x_00052= x(1, tmp_MinpackGL2_G_00780);
   tmp_MinpackGL2_G_00781= ny- 1;
   tmp_MinpackGL2_G_00782= 1: tmp_MinpackGL2_G_00781;
   g_tmp_x_00053= g_x(1, tmp_MinpackGL2_G_00782);
   tmp_x_00053= x(1, tmp_MinpackGL2_G_00782);
   tmp_MinpackGL2_G_00783= ny- 1;
   tmp_MinpackGL2_G_00784= 1: tmp_MinpackGL2_G_00783;
   g_tmp_vpoty_00060= g_vpoty(1, tmp_MinpackGL2_G_00784);
   tmp_vpoty_00060= vpoty(1, tmp_MinpackGL2_G_00784);
   g_tmp_MinpackGL2_G_00785= hy* g_tmp_vpoty_00060;
   tmp_MinpackGL2_G_00785= hy* tmp_vpoty_00060;
   g_tmp_cos_00046= g_tmp_MinpackGL2_G_00785.* (-sin(tmp_MinpackGL2_G_00785));
   tmp_cos_00046= cos(tmp_MinpackGL2_G_00785);
   g_tmp_MinpackGL2_G_00786= g_tmp_x_00053.* tmp_cos_00046+ tmp_x_00053.* g_tmp_cos_00046;
   tmp_MinpackGL2_G_00786= tmp_x_00053.* tmp_cos_00046;
   tmp_MinpackGL2_G_00787= ny- 1;
   tmp_MinpackGL2_G_00788= 1: tmp_MinpackGL2_G_00787;
   g_tmp_y_00051= g_y(1, tmp_MinpackGL2_G_00788);
   tmp_y_00051= y(1, tmp_MinpackGL2_G_00788);
   tmp_MinpackGL2_G_00789= ny- 1;
   tmp_MinpackGL2_G_00790= 1: tmp_MinpackGL2_G_00789;
   g_tmp_vpoty_00061= g_vpoty(1, tmp_MinpackGL2_G_00790);
   tmp_vpoty_00061= vpoty(1, tmp_MinpackGL2_G_00790);
   g_tmp_MinpackGL2_G_00791= hy* g_tmp_vpoty_00061;
   tmp_MinpackGL2_G_00791= hy* tmp_vpoty_00061;
   g_tmp_sin_00046= g_tmp_MinpackGL2_G_00791.* cos(tmp_MinpackGL2_G_00791);
   tmp_sin_00046= sin(tmp_MinpackGL2_G_00791);
   g_tmp_MinpackGL2_G_00792= g_tmp_y_00051.* tmp_sin_00046+ tmp_y_00051.* g_tmp_sin_00046;
   tmp_MinpackGL2_G_00792= tmp_y_00051.* tmp_sin_00046;
   g_tmp_MinpackGL2_G_00793= g_tmp_x_00052- g_tmp_MinpackGL2_G_00786+ g_tmp_MinpackGL2_G_00792;
   tmp_MinpackGL2_G_00793= tmp_x_00052- tmp_MinpackGL2_G_00786+ tmp_MinpackGL2_G_00792;
   g_fkiny1= tmp_MinpackGL2_G_00779* g_tmp_MinpackGL2_G_00793;
   fkiny1= tmp_MinpackGL2_G_00779* tmp_MinpackGL2_G_00793; 
   tmp_MinpackGL2_G_00794= hy* hy* sqn;
   tmp_MinpackGL2_G_00795= 2/ tmp_MinpackGL2_G_00794;
   tmp_MinpackGL2_G_00796= 2: ny;
   g_tmp_y_00052= g_y(1, tmp_MinpackGL2_G_00796);
   tmp_y_00052= y(1, tmp_MinpackGL2_G_00796);
   tmp_MinpackGL2_G_00797= ny- 1;
   tmp_MinpackGL2_G_00798= 1: tmp_MinpackGL2_G_00797;
   g_tmp_y_00053= g_y(1, tmp_MinpackGL2_G_00798);
   tmp_y_00053= y(1, tmp_MinpackGL2_G_00798);
   tmp_MinpackGL2_G_00799= ny- 1;
   tmp_MinpackGL2_G_00800= 1: tmp_MinpackGL2_G_00799;
   g_tmp_vpoty_00062= g_vpoty(1, tmp_MinpackGL2_G_00800);
   tmp_vpoty_00062= vpoty(1, tmp_MinpackGL2_G_00800);
   g_tmp_MinpackGL2_G_00801= hy* g_tmp_vpoty_00062;
   tmp_MinpackGL2_G_00801= hy* tmp_vpoty_00062;
   g_tmp_cos_00047= g_tmp_MinpackGL2_G_00801.* (-sin(tmp_MinpackGL2_G_00801));
   tmp_cos_00047= cos(tmp_MinpackGL2_G_00801);
   g_tmp_MinpackGL2_G_00802= g_tmp_y_00053.* tmp_cos_00047+ tmp_y_00053.* g_tmp_cos_00047;
   tmp_MinpackGL2_G_00802= tmp_y_00053.* tmp_cos_00047;
   tmp_MinpackGL2_G_00803= ny- 1;
   tmp_MinpackGL2_G_00804= 1: tmp_MinpackGL2_G_00803;
   g_tmp_x_00054= g_x(1, tmp_MinpackGL2_G_00804);
   tmp_x_00054= x(1, tmp_MinpackGL2_G_00804);
   tmp_MinpackGL2_G_00805= ny- 1;
   tmp_MinpackGL2_G_00806= 1: tmp_MinpackGL2_G_00805;
   g_tmp_vpoty_00063= g_vpoty(1, tmp_MinpackGL2_G_00806);
   tmp_vpoty_00063= vpoty(1, tmp_MinpackGL2_G_00806);
   g_tmp_MinpackGL2_G_00807= hy* g_tmp_vpoty_00063;
   tmp_MinpackGL2_G_00807= hy* tmp_vpoty_00063;
   g_tmp_sin_00047= g_tmp_MinpackGL2_G_00807.* cos(tmp_MinpackGL2_G_00807);
   tmp_sin_00047= sin(tmp_MinpackGL2_G_00807);
   g_tmp_MinpackGL2_G_00808= g_tmp_x_00054.* tmp_sin_00047+ tmp_x_00054.* g_tmp_sin_00047;
   tmp_MinpackGL2_G_00808= tmp_x_00054.* tmp_sin_00047;
   g_tmp_MinpackGL2_G_00809= g_tmp_y_00052- g_tmp_MinpackGL2_G_00802- g_tmp_MinpackGL2_G_00808;
   tmp_MinpackGL2_G_00809= tmp_y_00052- tmp_MinpackGL2_G_00802- tmp_MinpackGL2_G_00808;
   g_fkiny2= tmp_MinpackGL2_G_00795* g_tmp_MinpackGL2_G_00809;
   fkiny2= tmp_MinpackGL2_G_00795* tmp_MinpackGL2_G_00809; 
   sfac= sin(2* pi* vornum* (1: ny- 1)/ ny); 
   cfac= cos(2* pi* vornum* (1: ny- 1)/ ny); 
   tmp_MinpackGL2_G_00810= 2: ny;
   g_tmp_gradx_00005= g_gradx(1, tmp_MinpackGL2_G_00810);
   tmp_gradx_00005= gradx(1, tmp_MinpackGL2_G_00810);
   g_tmp_MinpackGL2_G_00811= cfac.* g_fkinx1;
   tmp_MinpackGL2_G_00811= cfac.* fkinx1;
   g_tmp_MinpackGL2_G_00812= sfac.* g_fkinx2;
   tmp_MinpackGL2_G_00812= sfac.* fkinx2;
   g_gradx(1, 2: ny)= g_tmp_gradx_00005+ g_tmp_MinpackGL2_G_00811+ g_tmp_MinpackGL2_G_00812+ g_fkiny1;
   gradx(1, 2: ny)= tmp_gradx_00005+ tmp_MinpackGL2_G_00811+ tmp_MinpackGL2_G_00812+ fkiny1; 
   tmp_MinpackGL2_G_00813= 2: ny;
   g_tmp_grady_00005= g_grady(1, tmp_MinpackGL2_G_00813);
   tmp_grady_00005= grady(1, tmp_MinpackGL2_G_00813);
   g_tmp_MinpackGL2_G_00814= sfac.* g_fkinx1;
   tmp_MinpackGL2_G_00814= sfac.* fkinx1;
   g_tmp_MinpackGL2_G_00815= cfac.* g_fkinx2;
   tmp_MinpackGL2_G_00815= cfac.* fkinx2;
   g_grady(1, 2: ny)= g_tmp_grady_00005- g_tmp_MinpackGL2_G_00814+ g_tmp_MinpackGL2_G_00815+ g_fkiny2;
   grady(1, 2: ny)= tmp_grady_00005- tmp_MinpackGL2_G_00814+ tmp_MinpackGL2_G_00815+ fkiny2; 
   tmp_MinpackGL2_G_00816= ny- 1;
   tmp_MinpackGL2_G_00817= 1: tmp_MinpackGL2_G_00816;
   g_tmp_vpotx_00064= g_vpotx(1, tmp_MinpackGL2_G_00817);
   tmp_vpotx_00064= vpotx(1, tmp_MinpackGL2_G_00817);
   tmp_MinpackGL2_G_00818= 2: ny;
   g_tmp_vpotx_00065= g_vpotx(1, tmp_MinpackGL2_G_00818);
   tmp_vpotx_00065= vpotx(1, tmp_MinpackGL2_G_00818);
   g_tmp_MinpackGL2_G_00819= g_tmp_vpotx_00064- g_tmp_vpotx_00065;
   tmp_MinpackGL2_G_00819= tmp_vpotx_00064- tmp_vpotx_00065;
   g_tmp_MinpackGL2_G_00820= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00819), (tmp_MinpackGL2_G_00819), hy);
   tmp_MinpackGL2_G_00820= tmp_MinpackGL2_G_00819/ hy;
   tmp_MinpackGL2_G_00821= ny- 1;
   tmp_MinpackGL2_G_00822= 1: tmp_MinpackGL2_G_00821;
   g_tmp_vpoty_00064= g_vpoty(2, tmp_MinpackGL2_G_00822);
   tmp_vpoty_00064= vpoty(2, tmp_MinpackGL2_G_00822);
   tmp_MinpackGL2_G_00823= ny- 1;
   tmp_MinpackGL2_G_00824= 1: tmp_MinpackGL2_G_00823;
   g_tmp_vpoty_00065= g_vpoty(1, tmp_MinpackGL2_G_00824);
   tmp_vpoty_00065= vpoty(1, tmp_MinpackGL2_G_00824);
   g_tmp_MinpackGL2_G_00825= g_tmp_vpoty_00064- g_tmp_vpoty_00065;
   tmp_MinpackGL2_G_00825= tmp_vpoty_00064- tmp_vpoty_00065;
   g_tmp_MinpackGL2_G_00826= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00825), (tmp_MinpackGL2_G_00825), hx);
   tmp_MinpackGL2_G_00826= tmp_MinpackGL2_G_00825/ hx;
   g_tmp_MinpackGL2_G_00827= g_tmp_MinpackGL2_G_00820+ g_tmp_MinpackGL2_G_00826;
   tmp_MinpackGL2_G_00827= tmp_MinpackGL2_G_00820+ tmp_MinpackGL2_G_00826;
   tmp_MinpackGL2_G_00828= tkappa^ 2;
   tmp_MinpackGL2_G_00829= 2* tmp_MinpackGL2_G_00828;
   tmp_MinpackGL2_G_00830= tmp_MinpackGL2_G_00829/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00827* tmp_MinpackGL2_G_00830;
   ffield= tmp_MinpackGL2_G_00827* tmp_MinpackGL2_G_00830; 
   tmp_MinpackGL2_G_00831= 2: ny;
   g_tmp_gradax_00004= g_gradax(1, tmp_MinpackGL2_G_00831);
   tmp_gradax_00004= gradax(1, tmp_MinpackGL2_G_00831);
   g_tmp_MinpackGL2_G_00832= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00832= ffield/ hy;
   g_gradax(1, 2: ny)= g_tmp_gradax_00004- g_tmp_MinpackGL2_G_00832;
   gradax(1, 2: ny)= tmp_gradax_00004- tmp_MinpackGL2_G_00832; 
   tmp_MinpackGL2_G_00833= 2: ny;
   g_tmp_vpotx_00066= g_vpotx(nx, tmp_MinpackGL2_G_00833);
   tmp_vpotx_00066= vpotx(nx, tmp_MinpackGL2_G_00833);
   tmp_MinpackGL2_G_00834= ny+ 1;
   tmp_MinpackGL2_G_00835= 3: tmp_MinpackGL2_G_00834;
   g_tmp_vpotx_00067= g_vpotx(nx, tmp_MinpackGL2_G_00835);
   tmp_vpotx_00067= vpotx(nx, tmp_MinpackGL2_G_00835);
   g_tmp_MinpackGL2_G_00836= g_tmp_vpotx_00066- g_tmp_vpotx_00067;
   tmp_MinpackGL2_G_00836= tmp_vpotx_00066- tmp_vpotx_00067;
   g_tmp_MinpackGL2_G_00837= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00836), (tmp_MinpackGL2_G_00836), hy);
   tmp_MinpackGL2_G_00837= tmp_MinpackGL2_G_00836/ hy;
   tmp_MinpackGL2_G_00838= nx+ 1;
   tmp_MinpackGL2_G_00839= 2: ny;
   g_tmp_vpoty_00066= g_vpoty(tmp_MinpackGL2_G_00838, tmp_MinpackGL2_G_00839);
   tmp_vpoty_00066= vpoty(tmp_MinpackGL2_G_00838, tmp_MinpackGL2_G_00839);
   tmp_MinpackGL2_G_00840= 2: ny;
   g_tmp_vpoty_00067= g_vpoty(nx, tmp_MinpackGL2_G_00840);
   tmp_vpoty_00067= vpoty(nx, tmp_MinpackGL2_G_00840);
   g_tmp_MinpackGL2_G_00841= g_tmp_vpoty_00066- g_tmp_vpoty_00067;
   tmp_MinpackGL2_G_00841= tmp_vpoty_00066- tmp_vpoty_00067;
   g_tmp_MinpackGL2_G_00842= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00841), (tmp_MinpackGL2_G_00841), hx);
   tmp_MinpackGL2_G_00842= tmp_MinpackGL2_G_00841/ hx;
   g_tmp_MinpackGL2_G_00843= g_tmp_MinpackGL2_G_00837+ g_tmp_MinpackGL2_G_00842;
   tmp_MinpackGL2_G_00843= tmp_MinpackGL2_G_00837+ tmp_MinpackGL2_G_00842;
   tmp_MinpackGL2_G_00844= tkappa^ 2;
   tmp_MinpackGL2_G_00845= 2* tmp_MinpackGL2_G_00844;
   tmp_MinpackGL2_G_00846= tmp_MinpackGL2_G_00845/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00843* tmp_MinpackGL2_G_00846;
   ffield= tmp_MinpackGL2_G_00843* tmp_MinpackGL2_G_00846; 
   tmp_MinpackGL2_G_00847= 2: ny;
   g_tmp_graday_00004= g_graday(1, tmp_MinpackGL2_G_00847);
   tmp_graday_00004= graday(1, tmp_MinpackGL2_G_00847);
   g_tmp_MinpackGL2_G_00848= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00848= ffield/ hx;
   g_graday(1, 2: ny)= g_tmp_graday_00004+ g_tmp_MinpackGL2_G_00848;
   graday(1, 2: ny)= tmp_graday_00004+ tmp_MinpackGL2_G_00848; 
   
   %    Kinetic Energy Part, at origin (only needed in zero field).
   
   tmp_MinpackGL2_G_00849= hx* hx* sqn;
   tmp_MinpackGL2_G_00850= 2/ tmp_MinpackGL2_G_00849;
   g_tmp_x_00055= g_x(2, 1);
   tmp_x_00055= x(2, 1);
   g_tmp_x_00056= g_x(1, 1);
   tmp_x_00056= x(1, 1);
   g_tmp_vpotx_00068= g_vpotx(1, 1);
   tmp_vpotx_00068= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00851= hx* g_tmp_vpotx_00068;
   tmp_MinpackGL2_G_00851= hx* tmp_vpotx_00068;
   g_tmp_cos_00048= g_tmp_MinpackGL2_G_00851.* (-sin(tmp_MinpackGL2_G_00851));
   tmp_cos_00048= cos(tmp_MinpackGL2_G_00851);
   g_tmp_MinpackGL2_G_00852= g_tmp_x_00056* tmp_cos_00048+ tmp_x_00056* g_tmp_cos_00048;
   tmp_MinpackGL2_G_00852= tmp_x_00056* tmp_cos_00048;
   g_tmp_y_00054= g_y(1, 1);
   tmp_y_00054= y(1, 1);
   g_tmp_vpotx_00069= g_vpotx(1, 1);
   tmp_vpotx_00069= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00853= hx* g_tmp_vpotx_00069;
   tmp_MinpackGL2_G_00853= hx* tmp_vpotx_00069;
   g_tmp_sin_00048= g_tmp_MinpackGL2_G_00853.* cos(tmp_MinpackGL2_G_00853);
   tmp_sin_00048= sin(tmp_MinpackGL2_G_00853);
   g_tmp_MinpackGL2_G_00854= g_tmp_y_00054* tmp_sin_00048+ tmp_y_00054* g_tmp_sin_00048;
   tmp_MinpackGL2_G_00854= tmp_y_00054* tmp_sin_00048;
   g_tmp_MinpackGL2_G_00855= g_tmp_x_00055- g_tmp_MinpackGL2_G_00852+ g_tmp_MinpackGL2_G_00854;
   tmp_MinpackGL2_G_00855= tmp_x_00055- tmp_MinpackGL2_G_00852+ tmp_MinpackGL2_G_00854;
   g_fkinx1= tmp_MinpackGL2_G_00850* g_tmp_MinpackGL2_G_00855;
   fkinx1= tmp_MinpackGL2_G_00850* tmp_MinpackGL2_G_00855; 
   tmp_MinpackGL2_G_00856= hx* hx* sqn;
   tmp_MinpackGL2_G_00857= 2/ tmp_MinpackGL2_G_00856;
   g_tmp_y_00055= g_y(2, 1);
   tmp_y_00055= y(2, 1);
   g_tmp_y_00056= g_y(1, 1);
   tmp_y_00056= y(1, 1);
   g_tmp_vpotx_00070= g_vpotx(1, 1);
   tmp_vpotx_00070= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00858= hx* g_tmp_vpotx_00070;
   tmp_MinpackGL2_G_00858= hx* tmp_vpotx_00070;
   g_tmp_cos_00049= g_tmp_MinpackGL2_G_00858.* (-sin(tmp_MinpackGL2_G_00858));
   tmp_cos_00049= cos(tmp_MinpackGL2_G_00858);
   g_tmp_MinpackGL2_G_00859= g_tmp_y_00056* tmp_cos_00049+ tmp_y_00056* g_tmp_cos_00049;
   tmp_MinpackGL2_G_00859= tmp_y_00056* tmp_cos_00049;
   g_tmp_x_00057= g_x(1, 1);
   tmp_x_00057= x(1, 1);
   g_tmp_vpotx_00071= g_vpotx(1, 1);
   tmp_vpotx_00071= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00860= hx* g_tmp_vpotx_00071;
   tmp_MinpackGL2_G_00860= hx* tmp_vpotx_00071;
   g_tmp_sin_00049= g_tmp_MinpackGL2_G_00860.* cos(tmp_MinpackGL2_G_00860);
   tmp_sin_00049= sin(tmp_MinpackGL2_G_00860);
   g_tmp_MinpackGL2_G_00861= g_tmp_x_00057* tmp_sin_00049+ tmp_x_00057* g_tmp_sin_00049;
   tmp_MinpackGL2_G_00861= tmp_x_00057* tmp_sin_00049;
   g_tmp_MinpackGL2_G_00862= g_tmp_y_00055- g_tmp_MinpackGL2_G_00859- g_tmp_MinpackGL2_G_00861;
   tmp_MinpackGL2_G_00862= tmp_y_00055- tmp_MinpackGL2_G_00859- tmp_MinpackGL2_G_00861;
   g_fkinx2= tmp_MinpackGL2_G_00857* g_tmp_MinpackGL2_G_00862;
   fkinx2= tmp_MinpackGL2_G_00857* tmp_MinpackGL2_G_00862; 
   tmp_MinpackGL2_G_00863= hy* hy* sqn;
   tmp_MinpackGL2_G_00864= 2/ tmp_MinpackGL2_G_00863;
   g_tmp_x_00058= g_x(1, 2);
   tmp_x_00058= x(1, 2);
   g_tmp_x_00059= g_x(1, 1);
   tmp_x_00059= x(1, 1);
   g_tmp_vpoty_00068= g_vpoty(1, 1);
   tmp_vpoty_00068= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00865= hy* g_tmp_vpoty_00068;
   tmp_MinpackGL2_G_00865= hy* tmp_vpoty_00068;
   g_tmp_cos_00050= g_tmp_MinpackGL2_G_00865.* (-sin(tmp_MinpackGL2_G_00865));
   tmp_cos_00050= cos(tmp_MinpackGL2_G_00865);
   g_tmp_MinpackGL2_G_00866= g_tmp_x_00059* tmp_cos_00050+ tmp_x_00059* g_tmp_cos_00050;
   tmp_MinpackGL2_G_00866= tmp_x_00059* tmp_cos_00050;
   g_tmp_y_00057= g_y(1, 1);
   tmp_y_00057= y(1, 1);
   g_tmp_vpoty_00069= g_vpoty(1, 1);
   tmp_vpoty_00069= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00867= hy* g_tmp_vpoty_00069;
   tmp_MinpackGL2_G_00867= hy* tmp_vpoty_00069;
   g_tmp_sin_00050= g_tmp_MinpackGL2_G_00867.* cos(tmp_MinpackGL2_G_00867);
   tmp_sin_00050= sin(tmp_MinpackGL2_G_00867);
   g_tmp_MinpackGL2_G_00868= g_tmp_y_00057* tmp_sin_00050+ tmp_y_00057* g_tmp_sin_00050;
   tmp_MinpackGL2_G_00868= tmp_y_00057* tmp_sin_00050;
   g_tmp_MinpackGL2_G_00869= g_tmp_x_00058- g_tmp_MinpackGL2_G_00866+ g_tmp_MinpackGL2_G_00868;
   tmp_MinpackGL2_G_00869= tmp_x_00058- tmp_MinpackGL2_G_00866+ tmp_MinpackGL2_G_00868;
   g_fkiny1= tmp_MinpackGL2_G_00864* g_tmp_MinpackGL2_G_00869;
   fkiny1= tmp_MinpackGL2_G_00864* tmp_MinpackGL2_G_00869; 
   tmp_MinpackGL2_G_00870= hy* hy* sqn;
   tmp_MinpackGL2_G_00871= 2/ tmp_MinpackGL2_G_00870;
   g_tmp_y_00058= g_y(1, 2);
   tmp_y_00058= y(1, 2);
   g_tmp_y_00059= g_y(1, 1);
   tmp_y_00059= y(1, 1);
   g_tmp_vpoty_00070= g_vpoty(1, 1);
   tmp_vpoty_00070= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00872= hy* g_tmp_vpoty_00070;
   tmp_MinpackGL2_G_00872= hy* tmp_vpoty_00070;
   g_tmp_cos_00051= g_tmp_MinpackGL2_G_00872.* (-sin(tmp_MinpackGL2_G_00872));
   tmp_cos_00051= cos(tmp_MinpackGL2_G_00872);
   g_tmp_MinpackGL2_G_00873= g_tmp_y_00059* tmp_cos_00051+ tmp_y_00059* g_tmp_cos_00051;
   tmp_MinpackGL2_G_00873= tmp_y_00059* tmp_cos_00051;
   g_tmp_x_00060= g_x(1, 1);
   tmp_x_00060= x(1, 1);
   g_tmp_vpoty_00071= g_vpoty(1, 1);
   tmp_vpoty_00071= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00874= hy* g_tmp_vpoty_00071;
   tmp_MinpackGL2_G_00874= hy* tmp_vpoty_00071;
   g_tmp_sin_00051= g_tmp_MinpackGL2_G_00874.* cos(tmp_MinpackGL2_G_00874);
   tmp_sin_00051= sin(tmp_MinpackGL2_G_00874);
   g_tmp_MinpackGL2_G_00875= g_tmp_x_00060* tmp_sin_00051+ tmp_x_00060* g_tmp_sin_00051;
   tmp_MinpackGL2_G_00875= tmp_x_00060* tmp_sin_00051;
   g_tmp_MinpackGL2_G_00876= g_tmp_y_00058- g_tmp_MinpackGL2_G_00873- g_tmp_MinpackGL2_G_00875;
   tmp_MinpackGL2_G_00876= tmp_y_00058- tmp_MinpackGL2_G_00873- tmp_MinpackGL2_G_00875;
   g_fkiny2= tmp_MinpackGL2_G_00871* g_tmp_MinpackGL2_G_00876;
   fkiny2= tmp_MinpackGL2_G_00871* tmp_MinpackGL2_G_00876; 
   g_tmp_vpotx_00072= g_vpotx(1, 1);
   tmp_vpotx_00072= vpotx(1, 1);
   g_tmp_vpotx_00073= g_vpotx(1, 2);
   tmp_vpotx_00073= vpotx(1, 2);
   g_tmp_MinpackGL2_G_00877= g_tmp_vpotx_00072- g_tmp_vpotx_00073;
   tmp_MinpackGL2_G_00877= tmp_vpotx_00072- tmp_vpotx_00073;
   g_tmp_MinpackGL2_G_00878= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00877), (tmp_MinpackGL2_G_00877), hy);
   tmp_MinpackGL2_G_00878= tmp_MinpackGL2_G_00877/ hy;
   g_tmp_vpoty_00072= g_vpoty(2, 1);
   tmp_vpoty_00072= vpoty(2, 1);
   g_tmp_vpoty_00073= g_vpoty(1, 1);
   tmp_vpoty_00073= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00879= g_tmp_vpoty_00072- g_tmp_vpoty_00073;
   tmp_MinpackGL2_G_00879= tmp_vpoty_00072- tmp_vpoty_00073;
   g_tmp_MinpackGL2_G_00880= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00879), (tmp_MinpackGL2_G_00879), hx);
   tmp_MinpackGL2_G_00880= tmp_MinpackGL2_G_00879/ hx;
   g_tmp_MinpackGL2_G_00881= g_tmp_MinpackGL2_G_00878+ g_tmp_MinpackGL2_G_00880;
   tmp_MinpackGL2_G_00881= tmp_MinpackGL2_G_00878+ tmp_MinpackGL2_G_00880;
   tmp_MinpackGL2_G_00882= tkappa^ 2;
   tmp_MinpackGL2_G_00883= 2* tmp_MinpackGL2_G_00882;
   tmp_MinpackGL2_G_00884= tmp_MinpackGL2_G_00883/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00881* tmp_MinpackGL2_G_00884;
   ffield= tmp_MinpackGL2_G_00881* tmp_MinpackGL2_G_00884; 
   g_tmp_gradx_00006= g_gradx(1, 1);
   tmp_gradx_00006= gradx(1, 1);
   g_tmp_vpotx_00074= g_vpotx(1, 1);
   tmp_vpotx_00074= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00885= hx* g_tmp_vpotx_00074;
   tmp_MinpackGL2_G_00885= hx* tmp_vpotx_00074;
   g_tmp_cos_00052= g_tmp_MinpackGL2_G_00885.* (-sin(tmp_MinpackGL2_G_00885));
   tmp_cos_00052= cos(tmp_MinpackGL2_G_00885);
   g_tmp_MinpackGL2_G_00886= g_tmp_cos_00052* fkinx1+ tmp_cos_00052* g_fkinx1;
   tmp_MinpackGL2_G_00886= tmp_cos_00052* fkinx1;
   g_tmp_vpotx_00075= g_vpotx(1, 1);
   tmp_vpotx_00075= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00887= hx* g_tmp_vpotx_00075;
   tmp_MinpackGL2_G_00887= hx* tmp_vpotx_00075;
   g_tmp_sin_00052= g_tmp_MinpackGL2_G_00887.* cos(tmp_MinpackGL2_G_00887);
   tmp_sin_00052= sin(tmp_MinpackGL2_G_00887);
   g_tmp_MinpackGL2_G_00888= g_tmp_sin_00052* fkinx2+ tmp_sin_00052* g_fkinx2;
   tmp_MinpackGL2_G_00888= tmp_sin_00052* fkinx2;
   g_tmp_vpoty_00074= g_vpoty(1, 1);
   tmp_vpoty_00074= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00889= hy* g_tmp_vpoty_00074;
   tmp_MinpackGL2_G_00889= hy* tmp_vpoty_00074;
   g_tmp_cos_00053= g_tmp_MinpackGL2_G_00889.* (-sin(tmp_MinpackGL2_G_00889));
   tmp_cos_00053= cos(tmp_MinpackGL2_G_00889);
   g_tmp_MinpackGL2_G_00890= g_tmp_cos_00053* fkiny1+ tmp_cos_00053* g_fkiny1;
   tmp_MinpackGL2_G_00890= tmp_cos_00053* fkiny1;
   g_tmp_vpoty_00075= g_vpoty(1, 1);
   tmp_vpoty_00075= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00891= hy* g_tmp_vpoty_00075;
   tmp_MinpackGL2_G_00891= hy* tmp_vpoty_00075;
   g_tmp_sin_00053= g_tmp_MinpackGL2_G_00891.* cos(tmp_MinpackGL2_G_00891);
   tmp_sin_00053= sin(tmp_MinpackGL2_G_00891);
   g_tmp_MinpackGL2_G_00892= g_tmp_sin_00053* fkiny2+ tmp_sin_00053* g_fkiny2;
   tmp_MinpackGL2_G_00892= tmp_sin_00053* fkiny2;
   g_gradx(1, 1)= g_tmp_gradx_00006- g_tmp_MinpackGL2_G_00886- g_tmp_MinpackGL2_G_00888- g_tmp_MinpackGL2_G_00890- g_tmp_MinpackGL2_G_00892;
   gradx(1, 1)= tmp_gradx_00006- tmp_MinpackGL2_G_00886- tmp_MinpackGL2_G_00888- tmp_MinpackGL2_G_00890- tmp_MinpackGL2_G_00892; 
   g_tmp_grady_00006= g_grady(1, 1);
   tmp_grady_00006= grady(1, 1);
   g_tmp_vpotx_00076= g_vpotx(1, 1);
   tmp_vpotx_00076= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00893= hx* g_tmp_vpotx_00076;
   tmp_MinpackGL2_G_00893= hx* tmp_vpotx_00076;
   g_tmp_sin_00054= g_tmp_MinpackGL2_G_00893.* cos(tmp_MinpackGL2_G_00893);
   tmp_sin_00054= sin(tmp_MinpackGL2_G_00893);
   g_tmp_MinpackGL2_G_00894= g_tmp_sin_00054* fkinx1+ tmp_sin_00054* g_fkinx1;
   tmp_MinpackGL2_G_00894= tmp_sin_00054* fkinx1;
   g_tmp_vpotx_00077= g_vpotx(1, 1);
   tmp_vpotx_00077= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00895= hx* g_tmp_vpotx_00077;
   tmp_MinpackGL2_G_00895= hx* tmp_vpotx_00077;
   g_tmp_cos_00054= g_tmp_MinpackGL2_G_00895.* (-sin(tmp_MinpackGL2_G_00895));
   tmp_cos_00054= cos(tmp_MinpackGL2_G_00895);
   g_tmp_MinpackGL2_G_00896= g_tmp_cos_00054* fkinx2+ tmp_cos_00054* g_fkinx2;
   tmp_MinpackGL2_G_00896= tmp_cos_00054* fkinx2;
   g_tmp_vpoty_00076= g_vpoty(1, 1);
   tmp_vpoty_00076= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00897= hy* g_tmp_vpoty_00076;
   tmp_MinpackGL2_G_00897= hy* tmp_vpoty_00076;
   g_tmp_sin_00055= g_tmp_MinpackGL2_G_00897.* cos(tmp_MinpackGL2_G_00897);
   tmp_sin_00055= sin(tmp_MinpackGL2_G_00897);
   g_tmp_MinpackGL2_G_00898= g_tmp_sin_00055* fkiny1+ tmp_sin_00055* g_fkiny1;
   tmp_MinpackGL2_G_00898= tmp_sin_00055* fkiny1;
   g_tmp_vpoty_00077= g_vpoty(1, 1);
   tmp_vpoty_00077= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00899= hy* g_tmp_vpoty_00077;
   tmp_MinpackGL2_G_00899= hy* tmp_vpoty_00077;
   g_tmp_cos_00055= g_tmp_MinpackGL2_G_00899.* (-sin(tmp_MinpackGL2_G_00899));
   tmp_cos_00055= cos(tmp_MinpackGL2_G_00899);
   g_tmp_MinpackGL2_G_00900= g_tmp_cos_00055* fkiny2+ tmp_cos_00055* g_fkiny2;
   tmp_MinpackGL2_G_00900= tmp_cos_00055* fkiny2;
   g_grady(1, 1)= g_tmp_grady_00006+ g_tmp_MinpackGL2_G_00894- g_tmp_MinpackGL2_G_00896+ g_tmp_MinpackGL2_G_00898- g_tmp_MinpackGL2_G_00900;
   grady(1, 1)= tmp_grady_00006+ tmp_MinpackGL2_G_00894- tmp_MinpackGL2_G_00896+ tmp_MinpackGL2_G_00898- tmp_MinpackGL2_G_00900; 
   g_tmp_gradax_00005= g_gradax(1, 1);
   tmp_gradax_00005= gradax(1, 1);
   g_tmp_MinpackGL2_G_00901= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00901= ffield/ hy;
   g_tmp_x_00061= g_x(1, 1);
   tmp_x_00061= x(1, 1);
   g_tmp_vpotx_00078= g_vpotx(1, 1);
   tmp_vpotx_00078= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00902= hx* g_tmp_vpotx_00078;
   tmp_MinpackGL2_G_00902= hx* tmp_vpotx_00078;
   g_tmp_sin_00056= g_tmp_MinpackGL2_G_00902.* cos(tmp_MinpackGL2_G_00902);
   tmp_sin_00056= sin(tmp_MinpackGL2_G_00902);
   g_tmp_MinpackGL2_G_00903= hx* g_tmp_x_00061* tmp_sin_00056+ hx* tmp_x_00061* g_tmp_sin_00056;
   tmp_MinpackGL2_G_00903= hx* tmp_x_00061* tmp_sin_00056;
   g_tmp_y_00060= g_y(1, 1);
   tmp_y_00060= y(1, 1);
   g_tmp_vpotx_00079= g_vpotx(1, 1);
   tmp_vpotx_00079= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00904= hx* g_tmp_vpotx_00079;
   tmp_MinpackGL2_G_00904= hx* tmp_vpotx_00079;
   g_tmp_cos_00056= g_tmp_MinpackGL2_G_00904.* (-sin(tmp_MinpackGL2_G_00904));
   tmp_cos_00056= cos(tmp_MinpackGL2_G_00904);
   g_tmp_MinpackGL2_G_00905= hx* g_tmp_y_00060* tmp_cos_00056+ hx* tmp_y_00060* g_tmp_cos_00056;
   tmp_MinpackGL2_G_00905= hx* tmp_y_00060* tmp_cos_00056;
   g_tmp_MinpackGL2_G_00906= g_tmp_MinpackGL2_G_00903+ g_tmp_MinpackGL2_G_00905;
   tmp_MinpackGL2_G_00906= tmp_MinpackGL2_G_00903+ tmp_MinpackGL2_G_00905;
   g_tmp_MinpackGL2_G_00907= g_fkinx1* tmp_MinpackGL2_G_00906+ fkinx1* g_tmp_MinpackGL2_G_00906;
   tmp_MinpackGL2_G_00907= fkinx1* tmp_MinpackGL2_G_00906;
   g_tmp_y_00061= g_y(1, 1);
   tmp_y_00061= y(1, 1);
   g_tmp_vpotx_00080= g_vpotx(1, 1);
   tmp_vpotx_00080= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00908= hx* g_tmp_vpotx_00080;
   tmp_MinpackGL2_G_00908= hx* tmp_vpotx_00080;
   g_tmp_sin_00057= g_tmp_MinpackGL2_G_00908.* cos(tmp_MinpackGL2_G_00908);
   tmp_sin_00057= sin(tmp_MinpackGL2_G_00908);
   g_tmp_MinpackGL2_G_00909= hx* g_tmp_y_00061* tmp_sin_00057+ hx* tmp_y_00061* g_tmp_sin_00057;
   tmp_MinpackGL2_G_00909= hx* tmp_y_00061* tmp_sin_00057;
   g_tmp_x_00062= g_x(1, 1);
   tmp_x_00062= x(1, 1);
   g_tmp_vpotx_00081= g_vpotx(1, 1);
   tmp_vpotx_00081= vpotx(1, 1);
   g_tmp_MinpackGL2_G_00910= hx* g_tmp_vpotx_00081;
   tmp_MinpackGL2_G_00910= hx* tmp_vpotx_00081;
   g_tmp_cos_00057= g_tmp_MinpackGL2_G_00910.* (-sin(tmp_MinpackGL2_G_00910));
   tmp_cos_00057= cos(tmp_MinpackGL2_G_00910);
   g_tmp_MinpackGL2_G_00911= hx* g_tmp_x_00062* tmp_cos_00057+ hx* tmp_x_00062* g_tmp_cos_00057;
   tmp_MinpackGL2_G_00911= hx* tmp_x_00062* tmp_cos_00057;
   g_tmp_MinpackGL2_G_00912= g_tmp_MinpackGL2_G_00909- g_tmp_MinpackGL2_G_00911;
   tmp_MinpackGL2_G_00912= tmp_MinpackGL2_G_00909- tmp_MinpackGL2_G_00911;
   g_tmp_MinpackGL2_G_00913= g_fkinx2* tmp_MinpackGL2_G_00912+ fkinx2* g_tmp_MinpackGL2_G_00912;
   tmp_MinpackGL2_G_00913= fkinx2* tmp_MinpackGL2_G_00912;
   g_gradax(1, 1)= g_tmp_gradax_00005+ g_tmp_MinpackGL2_G_00901+ g_tmp_MinpackGL2_G_00907+ g_tmp_MinpackGL2_G_00913;
   gradax(1, 1)= tmp_gradax_00005+ tmp_MinpackGL2_G_00901+ tmp_MinpackGL2_G_00907+ tmp_MinpackGL2_G_00913; 
   g_tmp_graday_00005= g_graday(1, 1);
   tmp_graday_00005= graday(1, 1);
   g_tmp_MinpackGL2_G_00914= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00914= ffield/ hx;
   g_tmp_x_00063= g_x(1, 1);
   tmp_x_00063= x(1, 1);
   g_tmp_vpoty_00078= g_vpoty(1, 1);
   tmp_vpoty_00078= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00915= hy* g_tmp_vpoty_00078;
   tmp_MinpackGL2_G_00915= hy* tmp_vpoty_00078;
   g_tmp_sin_00058= g_tmp_MinpackGL2_G_00915.* cos(tmp_MinpackGL2_G_00915);
   tmp_sin_00058= sin(tmp_MinpackGL2_G_00915);
   g_tmp_MinpackGL2_G_00916= hy* g_tmp_x_00063* tmp_sin_00058+ hy* tmp_x_00063* g_tmp_sin_00058;
   tmp_MinpackGL2_G_00916= hy* tmp_x_00063* tmp_sin_00058;
   g_tmp_y_00062= g_y(1, 1);
   tmp_y_00062= y(1, 1);
   g_tmp_vpoty_00079= g_vpoty(1, 1);
   tmp_vpoty_00079= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00917= hy* g_tmp_vpoty_00079;
   tmp_MinpackGL2_G_00917= hy* tmp_vpoty_00079;
   g_tmp_cos_00058= g_tmp_MinpackGL2_G_00917.* (-sin(tmp_MinpackGL2_G_00917));
   tmp_cos_00058= cos(tmp_MinpackGL2_G_00917);
   g_tmp_MinpackGL2_G_00918= hy* g_tmp_y_00062* tmp_cos_00058+ hy* tmp_y_00062* g_tmp_cos_00058;
   tmp_MinpackGL2_G_00918= hy* tmp_y_00062* tmp_cos_00058;
   g_tmp_MinpackGL2_G_00919= g_tmp_MinpackGL2_G_00916+ g_tmp_MinpackGL2_G_00918;
   tmp_MinpackGL2_G_00919= tmp_MinpackGL2_G_00916+ tmp_MinpackGL2_G_00918;
   g_tmp_MinpackGL2_G_00920= g_fkiny1* tmp_MinpackGL2_G_00919+ fkiny1* g_tmp_MinpackGL2_G_00919;
   tmp_MinpackGL2_G_00920= fkiny1* tmp_MinpackGL2_G_00919;
   g_tmp_y_00063= g_y(1, 1);
   tmp_y_00063= y(1, 1);
   g_tmp_vpoty_00080= g_vpoty(1, 1);
   tmp_vpoty_00080= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00921= hy* g_tmp_vpoty_00080;
   tmp_MinpackGL2_G_00921= hy* tmp_vpoty_00080;
   g_tmp_sin_00059= g_tmp_MinpackGL2_G_00921.* cos(tmp_MinpackGL2_G_00921);
   tmp_sin_00059= sin(tmp_MinpackGL2_G_00921);
   g_tmp_MinpackGL2_G_00922= hy* g_tmp_y_00063* tmp_sin_00059+ hy* tmp_y_00063* g_tmp_sin_00059;
   tmp_MinpackGL2_G_00922= hy* tmp_y_00063* tmp_sin_00059;
   g_tmp_x_00064= g_x(1, 1);
   tmp_x_00064= x(1, 1);
   g_tmp_vpoty_00081= g_vpoty(1, 1);
   tmp_vpoty_00081= vpoty(1, 1);
   g_tmp_MinpackGL2_G_00923= hy* g_tmp_vpoty_00081;
   tmp_MinpackGL2_G_00923= hy* tmp_vpoty_00081;
   g_tmp_cos_00059= g_tmp_MinpackGL2_G_00923.* (-sin(tmp_MinpackGL2_G_00923));
   tmp_cos_00059= cos(tmp_MinpackGL2_G_00923);
   g_tmp_MinpackGL2_G_00924= hy* g_tmp_x_00064* tmp_cos_00059+ hy* tmp_x_00064* g_tmp_cos_00059;
   tmp_MinpackGL2_G_00924= hy* tmp_x_00064* tmp_cos_00059;
   g_tmp_MinpackGL2_G_00925= g_tmp_MinpackGL2_G_00922- g_tmp_MinpackGL2_G_00924;
   tmp_MinpackGL2_G_00925= tmp_MinpackGL2_G_00922- tmp_MinpackGL2_G_00924;
   g_tmp_MinpackGL2_G_00926= g_fkiny2* tmp_MinpackGL2_G_00925+ fkiny2* g_tmp_MinpackGL2_G_00925;
   tmp_MinpackGL2_G_00926= fkiny2* tmp_MinpackGL2_G_00925;
   g_graday(1, 1)= g_tmp_graday_00005- g_tmp_MinpackGL2_G_00914+ g_tmp_MinpackGL2_G_00920+ g_tmp_MinpackGL2_G_00926;
   graday(1, 1)= tmp_graday_00005- tmp_MinpackGL2_G_00914+ tmp_MinpackGL2_G_00920+ tmp_MinpackGL2_G_00926; 
   tmp_MinpackGL2_G_00927= hx* hx* sqn;
   tmp_MinpackGL2_G_00928= 2/ tmp_MinpackGL2_G_00927;
   tmp_MinpackGL2_G_00929= nx+ 1;
   g_tmp_x_00065= g_x(tmp_MinpackGL2_G_00929, 1);
   tmp_x_00065= x(tmp_MinpackGL2_G_00929, 1);
   g_tmp_x_00066= g_x(nx, 1);
   tmp_x_00066= x(nx, 1);
   g_tmp_vpotx_00082= g_vpotx(nx, 1);
   tmp_vpotx_00082= vpotx(nx, 1);
   g_tmp_MinpackGL2_G_00930= hx* g_tmp_vpotx_00082;
   tmp_MinpackGL2_G_00930= hx* tmp_vpotx_00082;
   g_tmp_cos_00060= g_tmp_MinpackGL2_G_00930.* (-sin(tmp_MinpackGL2_G_00930));
   tmp_cos_00060= cos(tmp_MinpackGL2_G_00930);
   g_tmp_MinpackGL2_G_00931= g_tmp_x_00066* tmp_cos_00060+ tmp_x_00066* g_tmp_cos_00060;
   tmp_MinpackGL2_G_00931= tmp_x_00066* tmp_cos_00060;
   g_tmp_y_00064= g_y(nx, 1);
   tmp_y_00064= y(nx, 1);
   g_tmp_vpotx_00083= g_vpotx(nx, 1);
   tmp_vpotx_00083= vpotx(nx, 1);
   g_tmp_MinpackGL2_G_00932= hx* g_tmp_vpotx_00083;
   tmp_MinpackGL2_G_00932= hx* tmp_vpotx_00083;
   g_tmp_sin_00060= g_tmp_MinpackGL2_G_00932.* cos(tmp_MinpackGL2_G_00932);
   tmp_sin_00060= sin(tmp_MinpackGL2_G_00932);
   g_tmp_MinpackGL2_G_00933= g_tmp_y_00064* tmp_sin_00060+ tmp_y_00064* g_tmp_sin_00060;
   tmp_MinpackGL2_G_00933= tmp_y_00064* tmp_sin_00060;
   g_tmp_MinpackGL2_G_00934= g_tmp_x_00065- g_tmp_MinpackGL2_G_00931+ g_tmp_MinpackGL2_G_00933;
   tmp_MinpackGL2_G_00934= tmp_x_00065- tmp_MinpackGL2_G_00931+ tmp_MinpackGL2_G_00933;
   g_fkinx1= tmp_MinpackGL2_G_00928* g_tmp_MinpackGL2_G_00934;
   fkinx1= tmp_MinpackGL2_G_00928* tmp_MinpackGL2_G_00934; 
   tmp_MinpackGL2_G_00935= hx* hx* sqn;
   tmp_MinpackGL2_G_00936= 2/ tmp_MinpackGL2_G_00935;
   tmp_MinpackGL2_G_00937= nx+ 1;
   g_tmp_y_00065= g_y(tmp_MinpackGL2_G_00937, 1);
   tmp_y_00065= y(tmp_MinpackGL2_G_00937, 1);
   g_tmp_y_00066= g_y(nx, 1);
   tmp_y_00066= y(nx, 1);
   g_tmp_vpotx_00084= g_vpotx(nx, 1);
   tmp_vpotx_00084= vpotx(nx, 1);
   g_tmp_MinpackGL2_G_00938= hx* g_tmp_vpotx_00084;
   tmp_MinpackGL2_G_00938= hx* tmp_vpotx_00084;
   g_tmp_cos_00061= g_tmp_MinpackGL2_G_00938.* (-sin(tmp_MinpackGL2_G_00938));
   tmp_cos_00061= cos(tmp_MinpackGL2_G_00938);
   g_tmp_MinpackGL2_G_00939= g_tmp_y_00066* tmp_cos_00061+ tmp_y_00066* g_tmp_cos_00061;
   tmp_MinpackGL2_G_00939= tmp_y_00066* tmp_cos_00061;
   g_tmp_x_00067= g_x(nx, 1);
   tmp_x_00067= x(nx, 1);
   g_tmp_vpotx_00085= g_vpotx(nx, 1);
   tmp_vpotx_00085= vpotx(nx, 1);
   g_tmp_MinpackGL2_G_00940= hx* g_tmp_vpotx_00085;
   tmp_MinpackGL2_G_00940= hx* tmp_vpotx_00085;
   g_tmp_sin_00061= g_tmp_MinpackGL2_G_00940.* cos(tmp_MinpackGL2_G_00940);
   tmp_sin_00061= sin(tmp_MinpackGL2_G_00940);
   g_tmp_MinpackGL2_G_00941= g_tmp_x_00067* tmp_sin_00061+ tmp_x_00067* g_tmp_sin_00061;
   tmp_MinpackGL2_G_00941= tmp_x_00067* tmp_sin_00061;
   g_tmp_MinpackGL2_G_00942= g_tmp_y_00065- g_tmp_MinpackGL2_G_00939- g_tmp_MinpackGL2_G_00941;
   tmp_MinpackGL2_G_00942= tmp_y_00065- tmp_MinpackGL2_G_00939- tmp_MinpackGL2_G_00941;
   g_fkinx2= tmp_MinpackGL2_G_00936* g_tmp_MinpackGL2_G_00942;
   fkinx2= tmp_MinpackGL2_G_00936* tmp_MinpackGL2_G_00942; 
   tmp_MinpackGL2_G_00943= hy* hy* sqn;
   tmp_MinpackGL2_G_00944= 2/ tmp_MinpackGL2_G_00943;
   tmp_MinpackGL2_G_00945= ny+ 1;
   g_tmp_x_00068= g_x(1, tmp_MinpackGL2_G_00945);
   tmp_x_00068= x(1, tmp_MinpackGL2_G_00945);
   g_tmp_x_00069= g_x(1, ny);
   tmp_x_00069= x(1, ny);
   g_tmp_vpoty_00082= g_vpoty(1, ny);
   tmp_vpoty_00082= vpoty(1, ny);
   g_tmp_MinpackGL2_G_00946= hy* g_tmp_vpoty_00082;
   tmp_MinpackGL2_G_00946= hy* tmp_vpoty_00082;
   g_tmp_cos_00062= g_tmp_MinpackGL2_G_00946.* (-sin(tmp_MinpackGL2_G_00946));
   tmp_cos_00062= cos(tmp_MinpackGL2_G_00946);
   g_tmp_MinpackGL2_G_00947= g_tmp_x_00069* tmp_cos_00062+ tmp_x_00069* g_tmp_cos_00062;
   tmp_MinpackGL2_G_00947= tmp_x_00069* tmp_cos_00062;
   g_tmp_y_00067= g_y(1, ny);
   tmp_y_00067= y(1, ny);
   g_tmp_vpoty_00083= g_vpoty(1, ny);
   tmp_vpoty_00083= vpoty(1, ny);
   g_tmp_MinpackGL2_G_00948= hy* g_tmp_vpoty_00083;
   tmp_MinpackGL2_G_00948= hy* tmp_vpoty_00083;
   g_tmp_sin_00062= g_tmp_MinpackGL2_G_00948.* cos(tmp_MinpackGL2_G_00948);
   tmp_sin_00062= sin(tmp_MinpackGL2_G_00948);
   g_tmp_MinpackGL2_G_00949= g_tmp_y_00067* tmp_sin_00062+ tmp_y_00067* g_tmp_sin_00062;
   tmp_MinpackGL2_G_00949= tmp_y_00067* tmp_sin_00062;
   g_tmp_MinpackGL2_G_00950= g_tmp_x_00068- g_tmp_MinpackGL2_G_00947+ g_tmp_MinpackGL2_G_00949;
   tmp_MinpackGL2_G_00950= tmp_x_00068- tmp_MinpackGL2_G_00947+ tmp_MinpackGL2_G_00949;
   g_fkiny1= tmp_MinpackGL2_G_00944* g_tmp_MinpackGL2_G_00950;
   fkiny1= tmp_MinpackGL2_G_00944* tmp_MinpackGL2_G_00950; 
   tmp_MinpackGL2_G_00951= hy* hy* sqn;
   tmp_MinpackGL2_G_00952= 2/ tmp_MinpackGL2_G_00951;
   tmp_MinpackGL2_G_00953= ny+ 1;
   g_tmp_y_00068= g_y(1, tmp_MinpackGL2_G_00953);
   tmp_y_00068= y(1, tmp_MinpackGL2_G_00953);
   g_tmp_y_00069= g_y(1, ny);
   tmp_y_00069= y(1, ny);
   g_tmp_vpoty_00084= g_vpoty(1, ny);
   tmp_vpoty_00084= vpoty(1, ny);
   g_tmp_MinpackGL2_G_00954= hy* g_tmp_vpoty_00084;
   tmp_MinpackGL2_G_00954= hy* tmp_vpoty_00084;
   g_tmp_cos_00063= g_tmp_MinpackGL2_G_00954.* (-sin(tmp_MinpackGL2_G_00954));
   tmp_cos_00063= cos(tmp_MinpackGL2_G_00954);
   g_tmp_MinpackGL2_G_00955= g_tmp_y_00069* tmp_cos_00063+ tmp_y_00069* g_tmp_cos_00063;
   tmp_MinpackGL2_G_00955= tmp_y_00069* tmp_cos_00063;
   g_tmp_x_00070= g_x(1, ny);
   tmp_x_00070= x(1, ny);
   g_tmp_vpoty_00085= g_vpoty(1, ny);
   tmp_vpoty_00085= vpoty(1, ny);
   g_tmp_MinpackGL2_G_00956= hy* g_tmp_vpoty_00085;
   tmp_MinpackGL2_G_00956= hy* tmp_vpoty_00085;
   g_tmp_sin_00063= g_tmp_MinpackGL2_G_00956.* cos(tmp_MinpackGL2_G_00956);
   tmp_sin_00063= sin(tmp_MinpackGL2_G_00956);
   g_tmp_MinpackGL2_G_00957= g_tmp_x_00070* tmp_sin_00063+ tmp_x_00070* g_tmp_sin_00063;
   tmp_MinpackGL2_G_00957= tmp_x_00070* tmp_sin_00063;
   g_tmp_MinpackGL2_G_00958= g_tmp_y_00068- g_tmp_MinpackGL2_G_00955- g_tmp_MinpackGL2_G_00957;
   tmp_MinpackGL2_G_00958= tmp_y_00068- tmp_MinpackGL2_G_00955- tmp_MinpackGL2_G_00957;
   g_fkiny2= tmp_MinpackGL2_G_00952* g_tmp_MinpackGL2_G_00958;
   fkiny2= tmp_MinpackGL2_G_00952* tmp_MinpackGL2_G_00958; 
   g_tmp_gradx_00007= g_gradx(1, 1);
   tmp_gradx_00007= gradx(1, 1);
   g_gradx(1, 1)= g_tmp_gradx_00007+ g_fkinx1+ g_fkiny1;
   gradx(1, 1)= tmp_gradx_00007+ fkinx1+ fkiny1; 
   g_tmp_grady_00007= g_grady(1, 1);
   tmp_grady_00007= grady(1, 1);
   g_grady(1, 1)= g_tmp_grady_00007+ g_fkinx2+ g_fkiny2;
   grady(1, 1)= tmp_grady_00007+ fkinx2+ fkiny2; 
   g_tmp_vpotx_00086= g_vpotx(1, ny);
   tmp_vpotx_00086= vpotx(1, ny);
   tmp_MinpackGL2_G_00959= ny+ 1;
   g_tmp_vpotx_00087= g_vpotx(1, tmp_MinpackGL2_G_00959);
   tmp_vpotx_00087= vpotx(1, tmp_MinpackGL2_G_00959);
   g_tmp_MinpackGL2_G_00960= g_tmp_vpotx_00086- g_tmp_vpotx_00087;
   tmp_MinpackGL2_G_00960= tmp_vpotx_00086- tmp_vpotx_00087;
   g_tmp_MinpackGL2_G_00961= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00960), (tmp_MinpackGL2_G_00960), hy);
   tmp_MinpackGL2_G_00961= tmp_MinpackGL2_G_00960/ hy;
   g_tmp_vpoty_00086= g_vpoty(2, ny);
   tmp_vpoty_00086= vpoty(2, ny);
   g_tmp_vpoty_00087= g_vpoty(1, ny);
   tmp_vpoty_00087= vpoty(1, ny);
   g_tmp_MinpackGL2_G_00962= g_tmp_vpoty_00086- g_tmp_vpoty_00087;
   tmp_MinpackGL2_G_00962= tmp_vpoty_00086- tmp_vpoty_00087;
   g_tmp_MinpackGL2_G_00963= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00962), (tmp_MinpackGL2_G_00962), hx);
   tmp_MinpackGL2_G_00963= tmp_MinpackGL2_G_00962/ hx;
   g_tmp_MinpackGL2_G_00964= g_tmp_MinpackGL2_G_00961+ g_tmp_MinpackGL2_G_00963;
   tmp_MinpackGL2_G_00964= tmp_MinpackGL2_G_00961+ tmp_MinpackGL2_G_00963;
   tmp_MinpackGL2_G_00965= tkappa^ 2;
   tmp_MinpackGL2_G_00966= 2* tmp_MinpackGL2_G_00965;
   tmp_MinpackGL2_G_00967= tmp_MinpackGL2_G_00966/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00964* tmp_MinpackGL2_G_00967;
   ffield= tmp_MinpackGL2_G_00964* tmp_MinpackGL2_G_00967; 
   g_tmp_gradax_00006= g_gradax(1, 1);
   tmp_gradax_00006= gradax(1, 1);
   g_tmp_MinpackGL2_G_00968= adimat_g_mrdivide1(g_ffield, ffield, hy);
   tmp_MinpackGL2_G_00968= ffield/ hy;
   g_gradax(1, 1)= g_tmp_gradax_00006- g_tmp_MinpackGL2_G_00968;
   gradax(1, 1)= tmp_gradax_00006- tmp_MinpackGL2_G_00968; 
   g_tmp_vpotx_00088= g_vpotx(nx, 1);
   tmp_vpotx_00088= vpotx(nx, 1);
   g_tmp_vpotx_00089= g_vpotx(nx, 2);
   tmp_vpotx_00089= vpotx(nx, 2);
   g_tmp_MinpackGL2_G_00969= g_tmp_vpotx_00088- g_tmp_vpotx_00089;
   tmp_MinpackGL2_G_00969= tmp_vpotx_00088- tmp_vpotx_00089;
   g_tmp_MinpackGL2_G_00970= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00969), (tmp_MinpackGL2_G_00969), hy);
   tmp_MinpackGL2_G_00970= tmp_MinpackGL2_G_00969/ hy;
   tmp_MinpackGL2_G_00971= nx+ 1;
   g_tmp_vpoty_00088= g_vpoty(tmp_MinpackGL2_G_00971, 1);
   tmp_vpoty_00088= vpoty(tmp_MinpackGL2_G_00971, 1);
   g_tmp_vpoty_00089= g_vpoty(nx, 1);
   tmp_vpoty_00089= vpoty(nx, 1);
   g_tmp_MinpackGL2_G_00972= g_tmp_vpoty_00088- g_tmp_vpoty_00089;
   tmp_MinpackGL2_G_00972= tmp_vpoty_00088- tmp_vpoty_00089;
   g_tmp_MinpackGL2_G_00973= adimat_g_mrdivide1((g_tmp_MinpackGL2_G_00972), (tmp_MinpackGL2_G_00972), hx);
   tmp_MinpackGL2_G_00973= tmp_MinpackGL2_G_00972/ hx;
   g_tmp_MinpackGL2_G_00974= g_tmp_MinpackGL2_G_00970+ g_tmp_MinpackGL2_G_00973;
   tmp_MinpackGL2_G_00974= tmp_MinpackGL2_G_00970+ tmp_MinpackGL2_G_00973;
   tmp_MinpackGL2_G_00975= tkappa^ 2;
   tmp_MinpackGL2_G_00976= 2* tmp_MinpackGL2_G_00975;
   tmp_MinpackGL2_G_00977= tmp_MinpackGL2_G_00976/ sqn;
   g_ffield= g_tmp_MinpackGL2_G_00974* tmp_MinpackGL2_G_00977;
   ffield= tmp_MinpackGL2_G_00974* tmp_MinpackGL2_G_00977; 
   g_tmp_graday_00006= g_graday(1, 1);
   tmp_graday_00006= graday(1, 1);
   g_tmp_MinpackGL2_G_00978= adimat_g_mrdivide1(g_ffield, ffield, hx);
   tmp_MinpackGL2_G_00978= ffield/ hx;
   g_graday(1, 1)= g_tmp_graday_00006+ g_tmp_MinpackGL2_G_00978;
   graday(1, 1)= tmp_graday_00006+ tmp_MinpackGL2_G_00978; 
   
   % Unpack work array and assign to output
   
   g_fgrad= [g_gradx, g_grady, g_gradax, g_graday];
   fgrad= [gradx, grady, gradax, graday]; 
   g_tmp_fgrad_00000= g_fgrad(: );
   tmp_fgrad_00000= fgrad(: );
   g_fgrad= g_tmp_fgrad_00000;
   fgrad= tmp_fgrad_00000; 

end
